@@ -28,11 +28,10 @@ export * from './number-format';
 export * from './time-format';
 export * from './dimension';
 export * from './color';
-export * from './style';
+export * from './theme';
 export * from './validator';
 export * from './chart';
 export * from './chart-composition';
-export * from './components';
 export * from './math-expression';
 export * from './ui-overrides';
 export * from './hooks';
