@@ -30,7 +30,8 @@ export type TimeColumnConfigKey =
   | '__time_col'
   | '__time_grain'
   | '__time_range'
-  | '__granularity';
+  | '__granularity'
+  | '__time_compare';
 
 export type AppliedTimeExtras = Partial<
   Record<TimeColumnConfigKey, keyof QueryObject>
