@@ -17,6 +17,7 @@
  * under the License.
  */
 
+import { VizType } from '@superset-ui/core';
 import { WordCloudFormData } from '../src';
 import buildQuery from '../src/plugin/buildQuery';
 
@@ -25,7 +26,7 @@ describe('WordCloud buildQuery', () => {
     datasource: '5__table',
     granularity_sqla: 'ds',
     series: 'foo',
-    viz_type: 'word_cloud',
+    viz_type: VizType.WordCloud,
   };
 
   it('should build columns from series in form data', () => {
