@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import 'jest-enzyme';
 import './shim';
 // eslint-disable-next-line no-restricted-syntax -- whole React import is required for mocking React module in tests.
 import React from 'react';
+// eslint-disable-next-line no-restricted-imports
 import { configure as configureTestingLibrary } from '@testing-library/react';
 import { matchers } from '@emotion/jest';
 
