@@ -19,8 +19,8 @@
 import { normalizeTimestamp, QueryState, t } from '@superset-ui/core';
 import { isEqual, omit } from 'lodash';
 import { shallowEqual } from 'react-redux';
+import { now } from '@superset-ui/core/utils/dates';
 import * as actions from '../actions/sqlLab';
-import { now } from '../../utils/dates';
 import {
   addToObject,
   alterInObject,
@@ -135,7 +135,7 @@ export default function sqlLabReducer(state = {}, action) {
       };
       let newState = removeFromArr(state, 'queryEditors', queryEditor);
       // List of remaining queryEditor ids
-      const qeIds = newState.queryEditors.map(qe => qe.id);
+      const qeIds = newState.queryEditors.map(qe => qe.tabViewId ?? qe.id);
 
       const queries = {};
       Object.keys(state.queries).forEach(k => {
@@ -150,7 +150,8 @@ export default function sqlLabReducer(state = {}, action) {
 
       // Remove associated table schemas
       const tables = state.tables.filter(
-        table => table.queryEditorId !== queryEditor.id,
+        table =>
+          table.queryEditorId !== (queryEditor.tabViewId ?? queryEditor.id),
       );
 
       newState = {
@@ -167,7 +168,9 @@ export default function sqlLabReducer(state = {}, action) {
         },
         destroyedQueryEditors: {
           ...newState.destroyedQueryEditors,
-          [queryEditor.id]: Date.now(),
+          ...(!queryEditor.inLocalStorage && {
+            [queryEditor.tabViewId ?? queryEditor.id]: Date.now(),
+          }),
         },
       };
       return newState;
@@ -187,30 +190,42 @@ export default function sqlLabReducer(state = {}, action) {
     },
     [actions.MERGE_TABLE]() {
       const at = { ...action.table };
-      let existingTable;
-      state.tables.forEach(xt => {
-        if (
+      const existingTableIndex = state.tables.findIndex(
+        xt =>
           xt.dbId === at.dbId &&
           xt.queryEditorId === at.queryEditorId &&
           xt.catalog === at.catalog &&
           xt.schema === at.schema &&
-          xt.name === at.name
-        ) {
-          existingTable = xt;
-        }
-      });
-      if (existingTable) {
+          xt.name === at.name,
+      );
+      if (existingTableIndex >= 0) {
         if (action.query) {
           at.dataPreviewQueryId = action.query.id;
         }
-        if (existingTable.initialized) {
-          at.id = existingTable.id;
-        }
-        return alterInArr(state, 'tables', existingTable, at);
+        return {
+          ...state,
+          tables: [
+            ...state.tables.slice(0, existingTableIndex),
+            {
+              ...state.tables[existingTableIndex],
+              ...at,
+              ...(state.tables[existingTableIndex].initialized && {
+                id: state.tables[existingTableIndex].id,
+              }),
+            },
+            ...state.tables.slice(existingTableIndex + 1),
+          ],
+          ...(at.expanded && {
+            activeSouthPaneTab: at.id,
+          }),
+        };
       }
       // for new table, associate Id of query for data preview
       at.dataPreviewQueryId = null;
-      let newState = addToArr(state, 'tables', at, Boolean(action.prepend));
+      let newState = {
+        ...addToArr(state, 'tables', at, Boolean(action.prepend)),
+        ...(at.expanded && { activeSouthPaneTab: at.id }),
+      };
       if (action.query) {
         newState = alterInArr(newState, 'tables', at, {
           dataPreviewQueryId: action.query.id,
@@ -245,7 +260,6 @@ export default function sqlLabReducer(state = {}, action) {
         ...state,
         queries,
         tables: newTables,
-        activeSouthPaneTab: action.newQuery.id,
       };
     },
     [actions.COLLAPSE_TABLE]() {
@@ -253,9 +267,18 @@ export default function sqlLabReducer(state = {}, action) {
     },
     [actions.REMOVE_TABLES]() {
       const tableIds = action.tables.map(table => table.id);
+      const tables = state.tables.filter(table => !tableIds.includes(table.id));
+
       return {
         ...state,
-        tables: state.tables.filter(table => !tableIds.includes(table.id)),
+        tables,
+        ...(tableIds.includes(state.activeSouthPaneTab) && {
+          activeSouthPaneTab:
+            tables.find(
+              ({ queryEditorId }) =>
+                queryEditorId === action.tables[0].queryEditorId,
+            )?.id ?? 'Results',
+        }),
       };
     },
     [actions.COST_ESTIMATE_STARTED]() {
@@ -299,10 +322,17 @@ export default function sqlLabReducer(state = {}, action) {
     },
     [actions.START_QUERY]() {
       let newState = { ...state };
+      let sqlEditorId;
       if (action.query.sqlEditorId) {
+        const queryEditorByTabId = getFromArr(
+          state.queryEditors,
+          action.query.sqlEditorId,
+          'tabViewId',
+        );
+        sqlEditorId = queryEditorByTabId?.id ?? action.query.sqlEditorId;
         const qe = {
-          ...getFromArr(state.queryEditors, action.query.sqlEditorId),
-          ...(action.query.sqlEditorId === state.unsavedQueryEditor.id &&
+          ...getFromArr(state.queryEditors, sqlEditorId),
+          ...(sqlEditorId === state.unsavedQueryEditor.id &&
             state.unsavedQueryEditor),
         };
         if (qe.latestQueryId && state.queries[qe.latestQueryId]) {
@@ -315,8 +345,6 @@ export default function sqlLabReducer(state = {}, action) {
           const queries = { ...state.queries, [q.id]: q };
           newState = { ...state, queries };
         }
-      } else {
-        newState.activeSouthPaneTab = action.query.id;
       }
       newState = addToObject(newState, 'queries', action.query);
 
@@ -327,7 +355,7 @@ export default function sqlLabReducer(state = {}, action) {
           {
             latestQueryId: action.query.id,
           },
-          action.query.sqlEditorId,
+          sqlEditorId,
           action.query.isDataPreview,
         ),
       };
@@ -366,6 +394,7 @@ export default function sqlLabReducer(state = {}, action) {
         results: action.results,
         rows: action?.results?.query?.rows || 0,
         state: QueryState.Success,
+        executedSql: action?.results?.query?.executedSql,
         limitingFactor: action?.results?.query?.limitingFactor,
         tempSchema: action?.results?.query?.tempSchema,
         tempTable: action?.results?.query?.tempTable,
@@ -479,12 +508,6 @@ export default function sqlLabReducer(state = {}, action) {
         action.newTable,
       );
     },
-    [actions.MIGRATE_TAB_HISTORY]() {
-      const tabHistory = state.tabHistory.map(tabId =>
-        tabId === action.oldId ? action.newId : tabId,
-      );
-      return { ...state, tabHistory };
-    },
     [actions.MIGRATE_QUERY]() {
       const query = {
         ...state.queries[action.queryId],
