@@ -240,11 +240,13 @@ describe('sqlLabReducer', () => {
       );
     });
     it('should migrate query editor by new query editor id', () => {
+      const { length } = newState.queryEditors;
       const index = newState.queryEditors.findIndex(({ id }) => id === qe.id);
       const newQueryEditor = {
         ...qe,
-        id: 'updatedNewId',
+        tabViewId: 'updatedNewId',
         schema: 'updatedSchema',
+        inLocalStorage: false,
       };
       const action = {
         type: actions.MIGRATE_QUERY_EDITOR,
@@ -252,20 +254,18 @@ describe('sqlLabReducer', () => {
         newQueryEditor,
       };
       newState = sqlLabReducer(newState, action);
-      expect(newState.queryEditors[index].id).toEqual('updatedNewId');
+      expect(newState.queryEditors[index].id).toEqual(qe.id);
+      expect(newState.queryEditors[index].tabViewId).toEqual('updatedNewId');
       expect(newState.queryEditors[index]).toEqual(newQueryEditor);
-    });
-    it('should migrate tab history by new query editor id', () => {
-      expect(newState.tabHistory).toContain(qe.id);
-      const action = {
-        type: actions.MIGRATE_TAB_HISTORY,
-        oldId: qe.id,
-        newId: 'updatedNewId',
+      const removeAction = {
+        type: actions.REMOVE_QUERY_EDITOR,
+        queryEditor: newQueryEditor,
       };
-      newState = sqlLabReducer(newState, action);
-
-      expect(newState.tabHistory).toContain('updatedNewId');
-      expect(newState.tabHistory).not.toContain(qe.id);
+      newState = sqlLabReducer(newState, removeAction);
+      expect(newState.queryEditors).toHaveLength(length - 1);
+      expect(Object.keys(newState.destroyedQueryEditors)).toContain(
+        newQueryEditor.tabViewId,
+      );
     });
     it('should clear the destroyed query editors', () => {
       const expectedQEId = '1233289';
@@ -367,6 +367,93 @@ describe('sqlLabReducer', () => {
       newState = sqlLabReducer(newState, action);
       expect(newState.tables).toHaveLength(0);
     });
+    test('should set activeSouthPaneTab when adding expanded table', () => {
+      const expandedTable = {
+        ...table,
+        id: 'expanded_table_id',
+        name: 'expanded_table',
+        expanded: true,
+      };
+      const action = {
+        type: actions.MERGE_TABLE,
+        table: expandedTable,
+      };
+      newState = sqlLabReducer(initialState, action);
+      expect(newState.tables).toHaveLength(1);
+      expect(newState.activeSouthPaneTab).toBe(expandedTable.id);
+    });
+    test('should not set activeSouthPaneTab when adding collapsed table', () => {
+      const collapsedTable = {
+        ...table,
+        id: 'collapsed_table_id',
+        name: 'collapsed_table',
+        expanded: false,
+      };
+      const action = {
+        type: actions.MERGE_TABLE,
+        table: collapsedTable,
+      };
+      newState = sqlLabReducer(initialState, action);
+      expect(newState.tables).toHaveLength(1);
+      expect(newState.activeSouthPaneTab).toBe(initialState.activeSouthPaneTab);
+    });
+    test('should set activeSouthPaneTab when merging existing table with expanded=true', () => {
+      // First add a table with expanded=false
+      const collapsedTable = {
+        ...table,
+        id: 'existing_table_id',
+        name: 'existing_table',
+        expanded: false,
+      };
+      const addAction = {
+        type: actions.MERGE_TABLE,
+        table: collapsedTable,
+      };
+      newState = sqlLabReducer(initialState, addAction);
+      const previousActiveSouthPaneTab = newState.activeSouthPaneTab;
+
+      // Now merge the same table with expanded=true
+      const expandedTable = {
+        ...collapsedTable,
+        expanded: true,
+      };
+      const mergeAction = {
+        type: actions.MERGE_TABLE,
+        table: expandedTable,
+      };
+      newState = sqlLabReducer(newState, mergeAction);
+      expect(newState.tables).toHaveLength(1);
+      expect(newState.activeSouthPaneTab).toBe(expandedTable.id);
+      expect(newState.activeSouthPaneTab).not.toBe(previousActiveSouthPaneTab);
+    });
+    test('should not set activeSouthPaneTab when merging existing table with expanded=false', () => {
+      // First add a table with expanded=true
+      const expandedTable = {
+        ...table,
+        id: 'existing_table_id_2',
+        name: 'existing_table_2',
+        expanded: true,
+      };
+      const addAction = {
+        type: actions.MERGE_TABLE,
+        table: expandedTable,
+      };
+      newState = sqlLabReducer(initialState, addAction);
+      expect(newState.activeSouthPaneTab).toBe(expandedTable.id);
+
+      // Now merge the same table with expanded=false
+      const collapsedTable = {
+        ...expandedTable,
+        expanded: false,
+      };
+      const mergeAction = {
+        type: actions.MERGE_TABLE,
+        table: collapsedTable,
+      };
+      newState = sqlLabReducer(newState, mergeAction);
+      expect(newState.tables).toHaveLength(1);
+      expect(newState.activeSouthPaneTab).toBe(expandedTable.id);
+    });
   });
   describe('Run Query', () => {
     const DENORMALIZED_CHANGED_ON = '2023-06-26T07:53:05.439';
