@@ -18,26 +18,20 @@
  */
 import { t } from '@superset-ui/core';
 
-import { ErrorMessageComponentProps } from './types';
-import ErrorAlert from './ErrorAlert';
+import type { ErrorMessageComponentProps } from './types';
+import { ErrorAlert } from './ErrorAlert';
 
-function DatasetNotFoundErrorMessage({
+export function DatasetNotFoundErrorMessage({
   error,
-  source = 'dashboard',
   subtitle,
 }: ErrorMessageComponentProps) {
   const { level, message } = error;
-
   return (
     <ErrorAlert
-      title={t('Missing dataset')}
-      subtitle={subtitle}
-      level={level}
-      source={source}
-      copyText={message}
-      body={null}
+      errorType={t('Missing dataset')}
+      message={subtitle}
+      description={message}
+      type={level}
     />
   );
 }
-
-export default DatasetNotFoundErrorMessage;
