@@ -20,10 +20,19 @@
 import { render, screen } from 'spec/helpers/testing-library';
 import BuilderComponentPane from '.';
 
-jest.mock('src/dashboard/containers/SliceAdder');
+jest.mock('src/dashboard/containers/SliceAdder', () => () => (
+  <div data-test="mock-slice-adder" />
+));
 
 test('BuilderComponentPane has correct tabs in correct order', () => {
-  render(<BuilderComponentPane topOffset={115} />);
+  render(<BuilderComponentPane topOffset={115} />, {
+    useRedux: true,
+    initialState: {
+      dashboardState: {
+        nativeFiltersBarOpen: false,
+      },
+    },
+  });
   const tabs = screen.getAllByRole('tab');
   expect(tabs).toHaveLength(2);
   expect(tabs[0]).toHaveTextContent('Charts');
