@@ -18,15 +18,23 @@
  */
 import { MouseEventHandler, FC } from 'react';
 
-import Icons from 'src/components/Icons';
+import { Icons } from '@superset-ui/core/components/Icons';
+import type { IconType } from '@superset-ui/core/components/Icons/types';
 import IconButton from './IconButton';
 
 type DeleteComponentButtonProps = {
   onDelete: MouseEventHandler<HTMLDivElement>;
+  iconSize?: IconType['iconSize'];
 };
 
 const DeleteComponentButton: FC<DeleteComponentButtonProps> = ({
   onDelete,
-}) => <IconButton onClick={onDelete} icon={<Icons.Trash iconSize="xl" />} />;
+  iconSize,
+}) => (
+  <IconButton
+    onClick={onDelete}
+    icon={<Icons.DeleteOutlined iconSize={iconSize ?? 'l'} />}
+  />
+);
 
 export default DeleteComponentButton;
