@@ -18,6 +18,7 @@
  */
 import { t } from '@superset-ui/core';
 
+import { Icons } from '@superset-ui/core/components';
 import { TABS_TYPE } from '../../../util/componentTypes';
 import { NEW_TABS_ID } from '../../../util/constants';
 import DraggableNewComponent from './DraggableNewComponent';
@@ -28,7 +29,7 @@ export default function DraggableNewTabs() {
       id={NEW_TABS_ID}
       type={TABS_TYPE}
       label={t('Tabs')}
-      className="fa fa-window-restore"
+      IconComponent={Icons.DownSquareOutlined}
     />
   );
 }
