@@ -24,7 +24,15 @@ import { useCrossFiltersScopingModal } from './useCrossFiltersScopingModal';
 
 test('Renders modal after calling method open', async () => {
   const { result } = renderHook(() => useCrossFiltersScopingModal(), {
-    wrapper: createWrapper(),
+    wrapper: createWrapper({
+      initialState: {
+        dashboardLayout: {
+          present: {},
+          past: [],
+          future: [],
+        },
+      },
+    }),
   });
 
   const [openModal, Modal] = result.current;
@@ -34,6 +42,13 @@ test('Renders modal after calling method open', async () => {
 
   const { getByText } = render(result.current[1] as ReactElement, {
     useRedux: true,
+    initialState: {
+      dashboardLayout: {
+        present: {},
+        past: [],
+        future: [],
+      },
+    },
   });
 
   expect(getByText('Cross-filtering scoping')).toBeInTheDocument();
