@@ -16,8 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import userEvent from '@testing-library/user-event';
-import { render, screen } from 'spec/helpers/testing-library';
+import { render, screen, userEvent } from 'spec/helpers/testing-library';
 import { FilterInput } from '.';
 
 jest.mock('lodash/debounce', () => ({
@@ -30,8 +29,8 @@ test('Render a FilterInput', async () => {
   render(<FilterInput onChangeHandler={onChangeHandler} />);
   expect(await screen.findByRole('textbox')).toBeInTheDocument();
 
-  expect(onChangeHandler).toBeCalledTimes(0);
+  expect(onChangeHandler).toHaveBeenCalledTimes(0);
   userEvent.type(screen.getByRole('textbox'), 'test');
 
-  expect(onChangeHandler).toBeCalledTimes(4);
+  expect(onChangeHandler).toHaveBeenCalledTimes(4);
 });
