@@ -18,9 +18,14 @@
  */
 import * as redux from 'react-redux';
 import sinon from 'sinon';
-import { shallow } from 'enzyme';
+import {
+  act,
+  render,
+  screen,
+  userEvent,
+  waitFor,
+} from 'spec/helpers/testing-library';
 import thunk from 'redux-thunk';
-import { Provider } from 'react-redux';
 import configureStore from 'redux-mock-store';
 
 import AdhocFilter from 'src/explore/components/controls/FilterControl/AdhocFilter';
@@ -30,10 +35,7 @@ import {
   OPERATOR_ENUM_TO_OPERATOR_TYPE,
 } from 'src/explore/constants';
 import AdhocMetric from 'src/explore/components/controls/MetricControl/AdhocMetric';
-import { render, screen, act, waitFor } from '@testing-library/react';
-import { supersetTheme, FeatureFlag, ThemeProvider } from '@superset-ui/core';
-import * as uiCore from '@superset-ui/core';
-import userEvent from '@testing-library/user-event';
+import { FeatureFlag, isFeatureEnabled } from '@superset-ui/core';
 import fetchMock from 'fetch-mock';
 
 import { TestDataset } from '@superset-ui/chart-controls';
@@ -133,20 +135,24 @@ function setup(overrides?: Record<string, any>) {
     ...overrides,
     validHandler,
   };
-  const wrapper = shallow(
-    <AdhocFilterEditPopoverSimpleTabContent {...props} />,
-  );
-  return { wrapper, props };
+  render(<AdhocFilterEditPopoverSimpleTabContent {...props} />);
+  return props;
 }
 
+jest.mock('@superset-ui/core', () => ({
+  ...jest.requireActual('@superset-ui/core'),
+  isFeatureEnabled: jest.fn(),
+}));
+
+const mockedIsFeatureEnabled = isFeatureEnabled as jest.Mock;
+
 describe('AdhocFilterEditPopoverSimpleTabContent', () => {
-  it('renders the simple tab form', () => {
-    const { wrapper } = setup();
-    expect(wrapper).toExist();
+  it('can render the simple tab form', () => {
+    expect(() => setup()).not.toThrow();
   });
 
   it('shows boolean only operators when subject is boolean', () => {
-    const { props } = setup({
+    const props = setup({
       adhocFilter: new AdhocFilter({
         expressionType: ExpressionTypes.Simple,
         subject: 'value',
@@ -174,7 +180,7 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
     ].map(operator => expect(isOperatorRelevant(operator, 'value')).toBe(true));
   });
   it('shows boolean only operators when subject is number', () => {
-    const { props } = setup({
+    const props = setup({
       adhocFilter: new AdhocFilter({
         expressionType: ExpressionTypes.Simple,
         subject: 'value',
@@ -203,7 +209,7 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
   });
 
   it('will convert from individual comparator to array if the operator changes to multi', () => {
-    const { props } = setup();
+    const props = setup();
     const { onOperatorChange } = useSimpleTabFilterProps(props);
     onOperatorChange(Operators.In);
     expect(props.onChange.calledOnce).toBe(true);
@@ -212,7 +218,7 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
   });
 
   it('will convert from array to individual comparators if the operator changes from multi', () => {
-    const { props } = setup({
+    const props = setup({
       adhocFilter: simpleMultiAdhocFilter,
     });
     const { onOperatorChange } = useSimpleTabFilterProps(props);
@@ -228,7 +234,7 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
   });
 
   it('passes the new adhocFilter to onChange after onComparatorChange', () => {
-    const { props } = setup();
+    const props = setup();
     const { onComparatorChange } = useSimpleTabFilterProps(props);
     onComparatorChange('20');
     expect(props.onChange.calledOnce).toBe(true);
@@ -238,13 +244,13 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
   });
 
   it('will filter operators for table datasources', () => {
-    const { props } = setup({ datasource: { type: 'table' } });
+    const props = setup({ datasource: { type: 'table' } });
     const { isOperatorRelevant } = useSimpleTabFilterProps(props);
     expect(isOperatorRelevant(Operators.Like, 'value')).toBe(true);
   });
 
   it('will show LATEST PARTITION operator', () => {
-    const { props } = setup({
+    const props = setup({
       datasource: {
         type: 'table',
         datasource_name: 'table1',
@@ -263,7 +269,7 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
       expressionType: ExpressionTypes.Simple,
       subject: 'ds',
     });
-    const { props } = setup({
+    const props = setup({
       datasource: {
         type: 'table',
         datasource_name: 'table1',
@@ -288,7 +294,7 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
     );
   });
   it('will not display boolean operators when column type is string', () => {
-    const { props } = setup({
+    const props = setup({
       datasource: {
         type: 'table',
         datasource_name: 'table1',
@@ -304,7 +310,7 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
     });
   });
   it('will display boolean operators when column is an expression', () => {
-    const { props } = setup({
+    const props = setup({
       datasource: {
         type: 'table',
         datasource_name: 'table1',
@@ -324,26 +330,26 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
       expect(isOperatorRelevant(operator, 'value')).toBe(true);
     });
   });
-  it('sets comparator to true when operator is IS_TRUE', () => {
-    const { props } = setup();
+  it('sets comparator to undefined when operator is IS_TRUE', () => {
+    const props = setup();
     const { onOperatorChange } = useSimpleTabFilterProps(props);
     onOperatorChange(Operators.IsTrue);
     expect(props.onChange.calledOnce).toBe(true);
     expect(props.onChange.lastCall.args[0].operatorId).toBe(Operators.IsTrue);
-    expect(props.onChange.lastCall.args[0].operator).toBe('==');
-    expect(props.onChange.lastCall.args[0].comparator).toBe(true);
+    expect(props.onChange.lastCall.args[0].operator).toBe('IS TRUE');
+    expect(props.onChange.lastCall.args[0].comparator).toBe(undefined);
   });
-  it('sets comparator to false when operator is IS_FALSE', () => {
-    const { props } = setup();
+  it('sets comparator to undefined when operator is IS_FALSE', () => {
+    const props = setup();
     const { onOperatorChange } = useSimpleTabFilterProps(props);
     onOperatorChange(Operators.IsFalse);
     expect(props.onChange.calledOnce).toBe(true);
     expect(props.onChange.lastCall.args[0].operatorId).toBe(Operators.IsFalse);
-    expect(props.onChange.lastCall.args[0].operator).toBe('==');
-    expect(props.onChange.lastCall.args[0].comparator).toBe(false);
+    expect(props.onChange.lastCall.args[0].operator).toBe('IS FALSE');
+    expect(props.onChange.lastCall.args[0].comparator).toBe(undefined);
   });
-  it('sets comparator to null when operator is IS_NULL or IS_NOT_NULL', () => {
-    const { props } = setup();
+  it('sets comparator to undefined when operator is IS_NULL or IS_NOT_NULL', () => {
+    const props = setup();
     const { onOperatorChange } = useSimpleTabFilterProps(props);
     [Operators.IsNull, Operators.IsNotNull].forEach(op => {
       onOperatorChange(op);
@@ -352,7 +358,7 @@ describe('AdhocFilterEditPopoverSimpleTabContent', () => {
       expect(props.onChange.lastCall.args[0].operator).toBe(
         OPERATOR_ENUM_TO_OPERATOR_TYPE[op].operation,
       );
-      expect(props.onChange.lastCall.args[0].comparator).toBe(null);
+      expect(props.onChange.lastCall.args[0].comparator).toBe(undefined);
     });
   });
 });
@@ -383,25 +389,18 @@ const store = mockStore({});
 describe('AdhocFilterEditPopoverSimpleTabContent Advanced data Type Test', () => {
   const setupFilter = async (props: Props) => {
     await act(async () => {
-      render(
-        <Provider store={store}>
-          <ThemeProvider theme={supersetTheme}>
-            <AdhocFilterEditPopoverSimpleTabContent {...props} />
-          </ThemeProvider>
-          ,
-        </Provider>,
-      );
+      render(<AdhocFilterEditPopoverSimpleTabContent {...props} />, {
+        store,
+      });
     });
   };
 
   let isFeatureEnabledMock: any;
   beforeEach(async () => {
-    isFeatureEnabledMock = jest
-      .spyOn(uiCore, 'isFeatureEnabled')
-      .mockImplementation(
-        (featureFlag: FeatureFlag) =>
-          featureFlag === FeatureFlag.EnableAdvancedDataTypes,
-      );
+    isFeatureEnabledMock = mockedIsFeatureEnabled.mockImplementation(
+      (featureFlag: FeatureFlag) =>
+        featureFlag === FeatureFlag.EnableAdvancedDataTypes,
+    );
   });
 
   afterAll(() => {
@@ -545,12 +544,20 @@ describe('AdhocFilterEditPopoverSimpleTabContent Advanced data Type Test', () =>
     );
     expect(props.validHandler.lastCall.args[0]).toBe(true);
 
-    const operatorValueField = screen.getByText('1 operator(s)');
+    const operatorValueField = screen.getByRole('combobox', {
+      name: 'Select operator',
+    });
+
+    userEvent.click(operatorValueField);
 
     await act(async () => {
       userEvent.type(operatorValueField, '{enter}');
     });
 
-    expect(screen.getByText('EQUALS')).toBeTruthy();
+    expect(
+      await screen.findByText('Equal to (=)', {
+        selector: '.ant-select-selection-item',
+      }),
+    ).toBeInTheDocument();
   });
 });
