@@ -17,9 +17,9 @@
  * under the License.
  */
 import { useState, useEffect } from 'react';
-import { FAST_DEBOUNCE } from 'src/constants';
+import { Constants } from '@superset-ui/core/components';
 
-export function useDebounceValue<T>(value: T, delay = FAST_DEBOUNCE) {
+export function useDebounceValue<T>(value: T, delay = Constants.FAST_DEBOUNCE) {
   const [debouncedValue, setDebouncedValue] = useState<T>(value);
 
   useEffect(() => {
