@@ -16,7 +16,4 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import './assets/stylesheets/superset.less';
-
-// Importing Antd under its own stylesheet to prevent unintentional theming.
-import './assets/stylesheets/antd/index.less';
+import 'src/public-path';
