@@ -16,18 +16,28 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
-import { MouseEventHandler } from 'react';
+import { CSSProperties, MouseEventHandler, ReactNode } from 'react';
+import { SerializedStyles } from '@emotion/react';
 
 export interface TagType {
   id?: number;
+  className?: string;
   type?: string | number;
   editable?: boolean;
   onDelete?: (index: number) => void;
   onClick?: MouseEventHandler<HTMLSpanElement>;
-  name: string;
-  index?: number | undefined;
+  onMouseDown?: MouseEventHandler<HTMLSpanElement>;
+  onClose?: () => void;
+  color?: string;
+  name?: string;
+  index?: number;
   toolTipTitle?: string;
+  children?: ReactNode;
+  role?: string;
+  style?: CSSProperties;
+  icon?: ReactNode;
+  css?: SerializedStyles;
+  closable?: boolean;
 }
 
 export default TagType;
