@@ -20,7 +20,6 @@
 from __future__ import annotations
 
 import inspect
-import os
 from pathlib import Path
 from typing import Any, TypedDict
 
@@ -46,7 +45,13 @@ from superset.commands.database.ssh_tunnel.exceptions import (
     SSHTunnelInvalidCredentials,
     SSHTunnelMissingCredentials,
 )
+from superset.commands.database.uploaders.base import UploadFileType
 from superset.constants import PASSWORD_MASK
+from superset.databases.types import (  # pylint:disable=unused-import
+    EncryptedDict,  # noqa: F401
+    EncryptedField,
+    EncryptedString,  # noqa: F401
+)
 from superset.databases.utils import make_url_safe
 from superset.db_engine_specs import get_engine_spec
 from superset.exceptions import CertificateException, SupersetSecurityException
@@ -59,6 +64,7 @@ database_schemas_query_schema = {
     "type": "object",
     "properties": {
         "force": {"type": "boolean"},
+        "upload_allowed": {"type": "boolean"},
         "catalog": {"type": "string"},
     },
 }
@@ -101,9 +107,7 @@ allow_file_upload_description = (
 allow_ctas_description = "Allow CREATE TABLE AS option in SQL Lab"
 allow_cvas_description = "Allow CREATE VIEW AS option in SQL Lab"
 allow_dml_description = (
-    "Allow users to run non-SELECT statements "
-    "(UPDATE, DELETE, CREATE, ...) "
-    "in SQL Lab"
+    "Allow users to run non-SELECT statements (UPDATE, DELETE, CREATE, ...) in SQL Lab"
 )
 configuration_method_description = (
     "Configuration_method is used on the frontend to "
@@ -224,7 +228,7 @@ def server_cert_validator(value: str) -> str:
     return value
 
 
-def encrypted_extra_validator(value: str) -> str:
+def encrypted_extra_validator(value: str | None) -> None:
     """
     Validate that encrypted extra is a valid JSON string
     """
@@ -235,7 +239,6 @@ def encrypted_extra_validator(value: str) -> str:
             raise ValidationError(
                 [_("Field cannot be decoded by JSON. %(msg)s", msg=str(ex))]
             ) from ex
-    return value
 
 
 def extra_validator(value: str) -> str:
@@ -647,7 +650,7 @@ class TableMetadataOptionsResponseSchema(Schema):
 
 class TableMetadataColumnsResponseSchema(Schema):
     keys = fields.List(fields.String(), metadata={"description": ""})
-    longType = fields.String(
+    longType = fields.String(  # noqa: N815
         metadata={"description": "The actual backend long type for the column"}
     )
     name = fields.String(metadata={"description": "The column name"})
@@ -692,7 +695,7 @@ class TableMetadataResponseSchema(Schema):
         fields.Nested(TableMetadataColumnsResponseSchema),
         metadata={"description": "A list of columns and their metadata"},
     )
-    foreignKeys = fields.List(
+    foreignKeys = fields.List(  # noqa: N815
         fields.Nested(TableMetadataForeignKeysIndexesResponseSchema),
         metadata={"description": "A list of foreign keys and their metadata"},
     )
@@ -700,11 +703,11 @@ class TableMetadataResponseSchema(Schema):
         fields.Nested(TableMetadataForeignKeysIndexesResponseSchema),
         metadata={"description": "A list of indexes and their metadata"},
     )
-    primaryKey = fields.Nested(
+    primaryKey = fields.Nested(  # noqa: N815
         TableMetadataPrimaryKeyResponseSchema,
         metadata={"description": "Primary keys metadata"},
     )
-    selectStar = fields.String(metadata={"description": "SQL select star"})
+    selectStar = fields.String(metadata={"description": "SQL select star"})  # noqa: N815
 
 
 class TableExtraMetadataResponseSchema(Schema):
@@ -829,6 +832,7 @@ class ImportV1DatabaseExtraSchema(Schema):
     disable_drill_to_detail = fields.Boolean(required=False)
     allow_multi_catalog = fields.Boolean(required=False)
     version = fields.String(required=False, allow_none=True)
+    schema_options = fields.Dict(keys=fields.Str(), values=fields.Raw())
 
 
 class ImportV1DatabaseSchema(Schema):
@@ -850,6 +854,7 @@ class ImportV1DatabaseSchema(Schema):
     database_name = fields.String(required=True)
     sqlalchemy_uri = fields.String(required=True)
     password = fields.String(allow_none=True)
+    encrypted_extra = fields.String(allow_none=True, validate=encrypted_extra_validator)
     cache_timeout = fields.Integer(allow_none=True)
     expose_in_sqllab = fields.Boolean()
     allow_run_async = fields.Boolean()
@@ -857,6 +862,7 @@ class ImportV1DatabaseSchema(Schema):
     allow_cvas = fields.Boolean()
     allow_dml = fields.Boolean(required=False)
     allow_csv_upload = fields.Boolean()
+    impersonate_user = fields.Boolean()
     extra = fields.Nested(ImportV1DatabaseExtraSchema)
     uuid = fields.UUID(required=True)
     version = fields.String(required=True)
@@ -878,7 +884,7 @@ class ImportV1DatabaseSchema(Schema):
             raise ValidationError("Must provide a password for the database")
 
     @validates_schema
-    def validate_ssh_tunnel_credentials(
+    def validate_ssh_tunnel_credentials(  # noqa: C901
         self, data: dict[str, Any], **kwargs: Any
     ) -> None:
         """If ssh_tunnel has a masked credentials, credentials are required"""
@@ -940,20 +946,6 @@ class ImportV1DatabaseSchema(Schema):
         return
 
 
-class EncryptedField:  # pylint: disable=too-few-public-methods
-    """
-    A database field that should be stored in encrypted_extra.
-    """
-
-
-class EncryptedString(EncryptedField, fields.String):
-    pass
-
-
-class EncryptedDict(EncryptedField, fields.Dict):
-    pass
-
-
 def encrypted_field_properties(self, field: Any, **_) -> dict[str, Any]:  # type: ignore
     ret = {}
     if isinstance(field, EncryptedField):
@@ -981,9 +973,12 @@ class EngineInformationSchema(Schema):
     )
     supports_dynamic_catalog = fields.Boolean(
         metadata={
-            "description": "The database supports multiple catalogs in a single connection"
+            "description": "The database supports multiple catalogs in a single connection"  # noqa: E501
         }
     )
+    supports_oauth2 = fields.Boolean(
+        metadata={"description": "The database supports OAuth2"}
+    )
 
 
 class DatabaseConnectionSchema(Schema):
@@ -1087,20 +1082,25 @@ class DelimitedListField(fields.List):
             ) from exc
 
 
-class BaseUploadFilePostSchema(Schema):
-    _extension_config_key = ""
-
+class BaseUploadFilePostSchemaMixin(Schema):
     @validates("file")
     def validate_file_extension(self, file: FileStorage) -> None:
-        allowed_extensions = current_app.config["ALLOWED_EXTENSIONS"].intersection(
-            current_app.config[self._extension_config_key]
-        )
+        allowed_extensions = current_app.config["ALLOWED_EXTENSIONS"]
         file_suffix = Path(file.filename).suffix
-        if not file_suffix or file_suffix[1:] not in allowed_extensions:
+        if not file_suffix:
+            raise ValidationError([_("File extension is not allowed.")])
+        # Make case-insensitive comparison
+        if file_suffix[1:].lower() not in [ext.lower() for ext in allowed_extensions]:
             raise ValidationError([_("File extension is not allowed.")])
 
 
-class BaseUploadPostSchema(BaseUploadFilePostSchema):
+class UploadPostSchema(BaseUploadFilePostSchemaMixin):
+    type = fields.Enum(
+        UploadFileType,
+        required=True,
+        by_value=True,
+        metadata={"description": "File type to upload"},
+    )
     already_exists = fields.String(
         load_default="fail",
         validate=OneOf(choices=("fail", "replace", "append")),
@@ -1129,43 +1129,26 @@ class BaseUploadPostSchema(BaseUploadFilePostSchema):
         metadata={"description": "The name of the table to be created/appended"},
     )
 
-
-class ColumnarUploadPostSchema(BaseUploadPostSchema):
-    """
-    Schema for Columnar Upload
-    """
-
-    _extension_config_key = "COLUMNAR_EXTENSIONS"
-
+    # ------------
+    # CSV Schema
+    # ------------
     file = fields.Raw(
         required=True,
         metadata={
-            "description": "The Columnar file to upload",
-            "type": "string",
-            "format": "binary",
-        },
-    )
-
-
-class CSVUploadPostSchema(BaseUploadPostSchema):
-    """
-    Schema for CSV Upload
-    """
-
-    _extension_config_key = "CSV_EXTENSIONS"
-
-    file = fields.Raw(
-        required=True,
-        metadata={
-            "description": "The CSV file to upload",
+            "description": "The file to upload",
             "type": "string",
             "format": "text/csv",
         },
     )
-    delimiter = fields.String(metadata={"description": "The delimiter of the CSV file"})
+    delimiter = fields.String(
+        metadata={
+            "description": "[CSV only] The character used to separate values in the CSV"
+            " file (e.g., a comma, semicolon, or tab)."
+        }
+    )
     column_data_types = fields.String(
         metadata={
-            "description": "A dictionary with column names and "
+            "description": "[CSV only] A dictionary with column names and "
             "their data types if you need to change "
             "the defaults. Example: {'user_id':'int'}. "
             "Check Python Pandas library for supported data types"
@@ -1173,57 +1156,69 @@ class CSVUploadPostSchema(BaseUploadPostSchema):
     )
     day_first = fields.Boolean(
         metadata={
-            "description": "DD/MM format dates, international and European format"
+            "description": "[CSV only] DD/MM format dates, international and European"
+            " format"
         }
     )
     skip_blank_lines = fields.Boolean(
-        metadata={"description": "Skip blank lines in the CSV file."}
+        metadata={"description": "[CSV only] Skip blank lines in the CSV file."}
     )
     skip_initial_space = fields.Boolean(
-        metadata={"description": "Skip spaces after delimiter."}
+        metadata={"description": "[CSV only] Skip spaces after delimiter."}
     )
     column_dates = DelimitedListField(
         fields.String(),
         metadata={
-            "description": "A list of column names that should be "
+            "description": "[CSV and Excel only] A list of column names that should be "
             "parsed as dates. Example: date,timestamp"
         },
     )
     decimal_character = fields.String(
         metadata={
-            "description": "Character to recognize as decimal point. Default is '.'"
+            "description": "[CSV and Excel only] Character to recognize as decimal"
+            " point. Default is '.'"
         }
     )
     header_row = fields.Integer(
         metadata={
-            "description": "Row containing the headers to use as column names"
-            "(0 is first line of data). Leave empty if there is no header row."
+            "description": "[CSV and Excel only] Row containing the headers to use as"
+            " column names (0 is first line of data). Leave empty if"
+            " there is no header row."
         }
     )
     index_column = fields.String(
         metadata={
-            "description": "Column to use as the row labels of the dataframe. "
-            "Leave empty if no index column"
+            "description": "[CSV and Excel only] Column to use as the row labels of the"
+            " dataframe. Leave empty if no index column"
         }
     )
     null_values = DelimitedListField(
         fields.String(),
         metadata={
-            "description": "A list of strings that should be treated as null. "
-            "Examples: '' for empty strings, 'None', 'N/A',"
-            "Warning: Hive database supports only a single value"
+            "description": "[CSV and Excel only] A list of strings that should be "
+            "treated as null. Examples: '' for empty strings, 'None',"
+            " 'N/A', Warning: Hive database supports only a single value"
         },
     )
     rows_to_read = fields.Integer(
         metadata={
-            "description": "Number of rows to read from the file. "
+            "description": "[CSV and Excel only] Number of rows to read from the file. "
             "If None, reads all rows."
         },
         allow_none=True,
         validate=Range(min=1),
     )
     skip_rows = fields.Integer(
-        metadata={"description": "Number of rows to skip at start of file."}
+        metadata={
+            "description": "[CSV and Excel only] Number of rows to skip at start"
+            " of file."
+        }
+    )
+    sheet_name = fields.String(
+        metadata={
+            "description": "[Excel only]] Strings used for sheet names "
+            "(default is the first sheet)."
+        }
     )
 
     @post_load
@@ -1239,90 +1234,18 @@ class CSVUploadPostSchema(BaseUploadPostSchema):
                 ) from ex
         return data
 
-    @validates("file")
-    def validate_file_size(self, file: FileStorage) -> None:
-        file.flush()
-        size = os.fstat(file.fileno()).st_size
-        if (
-            current_app.config["CSV_UPLOAD_MAX_SIZE"] is not None
-            and size > current_app.config["CSV_UPLOAD_MAX_SIZE"]
-        ):
-            raise ValidationError([_("File size exceeds the maximum allowed size.")])
 
-
-class ExcelUploadPostSchema(BaseUploadPostSchema):
+class UploadFileMetadataPostSchema(BaseUploadFilePostSchemaMixin):
     """
-    Schema for Excel Upload
+    Schema for Upload file metadata.
     """
 
-    _extension_config_key = "EXCEL_EXTENSIONS"
-
-    file = fields.Raw(
+    type = fields.Enum(
+        UploadFileType,
         required=True,
-        metadata={
-            "description": "The Excel file to upload",
-            "type": "string",
-            "format": "binary",
-        },
+        by_value=True,
+        metadata={"description": "File type to upload"},
     )
-    sheet_name = fields.String(
-        metadata={
-            "description": "Strings used for sheet names "
-            "(default is the first sheet)."
-        }
-    )
-    column_dates = DelimitedListField(
-        fields.String(),
-        metadata={
-            "description": "A list of column names that should be "
-            "parsed as dates. Example: date,timestamp"
-        },
-    )
-    decimal_character = fields.String(
-        metadata={
-            "description": "Character to recognize as decimal point. Default is '.'"
-        }
-    )
-    header_row = fields.Integer(
-        metadata={
-            "description": "Row containing the headers to use as column names"
-            "(0 is first line of data). Leave empty if there is no header row."
-        }
-    )
-    index_column = fields.String(
-        metadata={
-            "description": "Column to use as the row labels of the dataframe. "
-            "Leave empty if no index column"
-        }
-    )
-    null_values = DelimitedListField(
-        fields.String(),
-        metadata={
-            "description": "A list of strings that should be treated as null. "
-            "Examples: '' for empty strings, 'None', 'N/A',"
-            "Warning: Hive database supports only a single value"
-        },
-    )
-    rows_to_read = fields.Integer(
-        metadata={
-            "description": "Number of rows to read from the file. "
-            "If None, reads all rows."
-        },
-        allow_none=True,
-        validate=Range(min=1),
-    )
-    skip_rows = fields.Integer(
-        metadata={"description": "Number of rows to skip at start of file."}
-    )
-
-
-class CSVMetadataUploadFilePostSchema(BaseUploadFilePostSchema):
-    """
-    Schema for CSV metadata.
-    """
-
-    _extension_config_key = "CSV_EXTENSIONS"
-
     file = fields.Raw(
         required=True,
         metadata={
@@ -1331,30 +1254,12 @@ class CSVMetadataUploadFilePostSchema(BaseUploadFilePostSchema):
             "format": "binary",
         },
     )
-    delimiter = fields.String(metadata={"description": "The delimiter of the CSV file"})
-    header_row = fields.Integer(
+    delimiter = fields.String(
         metadata={
-            "description": "Row containing the headers to use as column names"
-            "(0 is first line of data). Leave empty if there is no header row."
+            "description": "The character used to separate values in the CSV file"
+            " (e.g., a comma, semicolon, or tab)."
         }
     )
-
-
-class ExcelMetadataUploadFilePostSchema(BaseUploadFilePostSchema):
-    """
-    Schema for CSV metadata.
-    """
-
-    _extension_config_key = "EXCEL_EXTENSIONS"
-
-    file = fields.Raw(
-        required=True,
-        metadata={
-            "description": "The file to upload",
-            "type": "string",
-            "format": "binary",
-        },
-    )
     header_row = fields.Integer(
         metadata={
             "description": "Row containing the headers to use as column names"
@@ -1363,23 +1268,6 @@ class ExcelMetadataUploadFilePostSchema(BaseUploadFilePostSchema):
     )
 
 
-class ColumnarMetadataUploadFilePostSchema(BaseUploadFilePostSchema):
-    """
-    Schema for CSV metadata.
-    """
-
-    _extension_config_key = "COLUMNAR_EXTENSIONS"
-
-    file = fields.Raw(
-        required=True,
-        metadata={
-            "description": "The file to upload",
-            "type": "string",
-            "format": "binary",
-        },
-    )
-
-
 class UploadFileMetadataItemSchema(Schema):
     sheet_name = fields.String(metadata={"description": "The name of the sheet"})
     column_names = fields.List(
