@@ -22,12 +22,16 @@ Create Date: 2018-05-09 23:45:14.296283
 
 """
 
+import logging
+
+import sqlalchemy as sa  # noqa: E402
+from alembic import op  # noqa: E402
+
 # revision identifiers, used by Alembic.
 revision = "e502db2af7be"
 down_revision = "5ccf602336a0"
 
-import sqlalchemy as sa  # noqa: E402
-from alembic import op  # noqa: E402
+logger = logging.getLogger("alembic.env")
 
 
 def upgrade():
@@ -38,4 +42,4 @@ def downgrade():
     try:
         op.drop_column("tables", "template_params")
     except Exception as ex:
-        logging.warning(str(ex))  # noqa: F821
+        logger.warning(str(ex))
