@@ -22,36 +22,38 @@ Create Date: 2022-04-01 14:38:09.499483
 
 """
 
+import os
+from datetime import datetime
+from typing import Optional, Union
+from uuid import uuid4
+
+import sqlalchemy as sa
+from alembic import op
+from sqlalchemy import select
+from sqlalchemy.exc import NoSuchModuleError
+from sqlalchemy.ext.declarative import declarative_base, declared_attr
+from sqlalchemy.orm import backref, relationship, Session
+from sqlalchemy.schema import UniqueConstraint
+from sqlalchemy.sql import functions as func
+from sqlalchemy.sql.expression import and_, or_
+from sqlalchemy_utils import UUIDType
+
+from superset.connectors.sqla.models import ADDITIVE_METRIC_TYPES_LOWER
+from superset.connectors.sqla.utils import (
+    get_identifier_quoter,
+)
+from superset.databases.utils import make_url_safe
+from superset.db_engine_specs import BaseEngineSpec, get_engine_spec
+from superset.extensions import encrypted_field_factory
+from superset.migrations.shared.utils import assign_uuids
+from superset.sql.parse import SQLScript, Table
+from superset.utils import json
+from superset.utils.core import MediumText
+
 # revision identifiers, used by Alembic.
 revision = "a9422eeaae74"
 down_revision = "ad07e4fdbaba"
 
-import os  # noqa: E402
-from datetime import datetime  # noqa: E402
-from typing import Optional, Union  # noqa: E402
-from uuid import uuid4  # noqa: E402
-
-import sqlalchemy as sa  # noqa: E402
-from alembic import op  # noqa: E402
-from sqlalchemy import select  # noqa: E402
-from sqlalchemy.ext.declarative import declarative_base, declared_attr  # noqa: E402
-from sqlalchemy.orm import backref, relationship, Session  # noqa: E402
-from sqlalchemy.schema import UniqueConstraint  # noqa: E402
-from sqlalchemy.sql import functions as func  # noqa: E402
-from sqlalchemy.sql.expression import and_, or_  # noqa: E402
-from sqlalchemy_utils import UUIDType  # noqa: E402
-
-from superset.connectors.sqla.models import ADDITIVE_METRIC_TYPES_LOWER  # noqa: E402
-from superset.connectors.sqla.utils import (  # noqa: E402
-    get_dialect_name,
-    get_identifier_quoter,
-)
-from superset.extensions import encrypted_field_factory  # noqa: E402
-from superset.migrations.shared.utils import assign_uuids  # noqa: E402
-from superset.sql_parse import extract_table_references, Table  # noqa: E402
-from superset.utils import json  # noqa: E402
-from superset.utils.core import MediumText  # noqa: E402
-
 Base = declarative_base()
 SHOW_PROGRESS = os.environ.get("SHOW_PROGRESS") == "1"
 UNKNOWN_TYPE = "UNKNOWN"
@@ -62,6 +64,20 @@ user_table = sa.Table(
 )
 
 
+def get_db_engine_spec(sqlalchemy_uri: str) -> type[BaseEngineSpec]:
+    """
+    Return the DB engine spec associated with a given SQLAlchemy URL.
+    """
+    url = make_url_safe(sqlalchemy_uri)
+    backend = url.get_backend_name()
+    try:
+        driver = url.get_driver_name()
+    except NoSuchModuleError:
+        driver = None
+
+    return get_engine_spec(backend, driver)
+
+
 class UUIDMixin:
     uuid = sa.Column(
         UUIDType(binary=True), primary_key=False, unique=True, default=uuid4
@@ -80,11 +96,11 @@ class AuxiliaryColumnsMixin(UUIDMixin):
     )
 
     @declared_attr
-    def created_by_fk(cls):
+    def created_by_fk(cls):  # noqa: N805
         return sa.Column(sa.Integer, sa.ForeignKey("ab_user.id"), nullable=True)
 
     @declared_attr
-    def changed_by_fk(cls):
+    def changed_by_fk(cls):  # noqa: N805
         return sa.Column(sa.Integer, sa.ForeignKey("ab_user.id"), nullable=True)
 
 
@@ -324,7 +340,7 @@ def copy_tables(session: Session) -> None:
                 # Tables need different uuid than datasets, since they are different
                 # entities. When INSERT FROM SELECT, we must provide a value for `uuid`,
                 # otherwise it'd use the default generated on Python side, which
-                # will cause duplicate values. They will be replaced by `assign_uuids` later.
+                # will cause duplicate values. They will be replaced by `assign_uuids` later.  # noqa: E501
                 SqlaTable.uuid,
                 SqlaTable.id.label("sqlatable_id"),
                 SqlaTable.created_on,
@@ -502,7 +518,7 @@ def copy_metrics(session: Session) -> None:
     )
 
 
-def postprocess_datasets(session: Session) -> None:
+def postprocess_datasets(session: Session) -> None:  # noqa: C901
     """
     Postprocess datasets after insertion to
       - Quote table names for physical datasets (if needed)
@@ -593,11 +609,18 @@ def postprocess_datasets(session: Session) -> None:
                 updated = True
 
             if not is_physical and drivername and expression:
-                table_refrences = extract_table_references(
-                    expression, get_dialect_name(drivername), show_warning=False
-                )
+                db_engine_spec = get_db_engine_spec(sqlalchemy_uri)
+                parsed_script = SQLScript(expression, db_engine_spec.engine)
+                table_references = {
+                    table
+                    for statement in parsed_script.statements
+                    for table in statement.tables
+                }
                 found_tables = find_tables(
-                    session, database_id, schema, table_refrences
+                    session,
+                    database_id,
+                    schema,
+                    table_references,
                 )
                 if found_tables:
                     op.bulk_insert(
@@ -620,7 +643,7 @@ def postprocess_datasets(session: Session) -> None:
         print("")
 
 
-def postprocess_columns(session: Session) -> None:
+def postprocess_columns(session: Session) -> None:  # noqa: C901
     """
     At this step, we will
       - Add engine specific quotes to `expression` of physical columns
@@ -809,7 +832,7 @@ def postprocess_columns(session: Session) -> None:
                             updates["expression"] = quoted_expression
                 # duplicate physical columns for tables
                 physical_columns.append(
-                    dict(
+                    dict(  # noqa: C408
                         created_on=created_on,
                         changed_on=changed_on,
                         changed_by_fk=changed_by_fk,
@@ -867,15 +890,17 @@ new_tables: sa.Table = [
 
 
 def reset_postgres_id_sequence(table: str) -> None:
+    """Reset PostgreSQL sequence ID for a table's id column."""
     op.execute(
-        f"""
+        """
         SELECT setval(
-            pg_get_serial_sequence('{table}', 'id'),
+            pg_get_serial_sequence(:table, 'id'),
             COALESCE(max(id) + 1, 1),
             false
         )
-        FROM {table};
-    """
+        FROM :table;
+        """,
+        {"table": table},
     )
 
 
@@ -903,7 +928,7 @@ def upgrade() -> None:
     assign_uuids(NewTable, session)
 
     print(">> Drop intermediate columns...")
-    # These columns are are used during migration, as datasets are independent of tables once created,
+    # These columns are are used during migration, as datasets are independent of tables once created,  # noqa: E501
     # dataset columns also the same to table columns.
     with op.batch_alter_table(NewTable.__tablename__) as batch_op:
         batch_op.drop_column("sqlatable_id")
