@@ -17,7 +17,7 @@
 import logging
 from typing import Any
 
-from flask import request, Response
+from flask import current_app, request, Response
 from flask_appbuilder.api import expose, protect, rison, safe
 from flask_appbuilder.models.sqla.interface import SQLAInterface
 from marshmallow import ValidationError
@@ -109,7 +109,6 @@ class TagRestApi(BaseSupersetModelRestApi):
         "created_on_delta_humanized",
         "created_by.first_name",
         "created_by.last_name",
-        "created_by",
     ]
 
     base_related_field_filters = {
@@ -146,8 +145,8 @@ class TagRestApi(BaseSupersetModelRestApi):
         """Deterministic string representation of the API instance for etag_cache."""
         return (
             "Superset.tags.api.TagRestApi@v"
-            f'{self.appbuilder.app.config["VERSION_STRING"]}'
-            f'{self.appbuilder.app.config["VERSION_SHA"]}'
+            f"{current_app.config['VERSION_STRING']}"
+            f"{current_app.config['VERSION_SHA']}"
         )
 
     @expose("/", methods=("POST",))
@@ -583,9 +582,9 @@ class TagRestApi(BaseSupersetModelRestApi):
             if tag_ids:
                 # priotize using ids for lookups vs. names mainly using this
                 # for backward compatibility
-                tagged_objects = TagDAO.get_tagged_objects_by_tag_id(tag_ids, types)
+                tagged_objects = TagDAO.get_tagged_objects_by_tag_ids(tag_ids, types)
             else:
-                tagged_objects = TagDAO.get_tagged_objects_for_tags(tags, types)
+                tagged_objects = TagDAO.get_tagged_objects_by_tag_names(tags, types)
 
             result = [
                 self.object_entity_response_schema.dump(tagged_object)
@@ -653,8 +652,7 @@ class TagRestApi(BaseSupersetModelRestApi):
     @safe
     @statsd_metrics
     @event_logger.log_this_with_context(
-        action=lambda self, *args, **kwargs: f"{self.__class__.__name__}"
-        f".add_favorite",
+        action=lambda self, *args, **kwargs: f"{self.__class__.__name__}.add_favorite",
         log_to_statsd=False,
     )
     def add_favorite(self, pk: int) -> Response:
