@@ -14,25 +14,48 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-# isort:skip_file
-"""Unit tests for Superset"""
 
-import unittest
 import copy
+import time
+import unittest
+from contextlib import contextmanager
 from datetime import datetime
 from io import BytesIO
-import time
 from typing import Any, Optional
 from unittest import mock
 from zipfile import ZipFile
 
-from flask import Response
+import pytest
+from flask import g, Response
 from flask.ctx import AppContext
-from tests.integration_tests.conftest import with_feature_flags
+
 from superset.charts.data.api import ChartDataRestApi
+from superset.commands.chart.data.get_data_command import ChartDataCommand
+from superset.common.chart_data import ChartDataResultFormat, ChartDataResultType
+from superset.connectors.sqla.models import SqlaTable, TableColumn
+from superset.constants import CACHE_DISABLED_TIMEOUT
+from superset.errors import SupersetErrorType
+from superset.extensions import async_query_manager_factory, db
+from superset.models.annotations import AnnotationLayer
+from superset.models.slice import Slice
 from superset.models.sql_lab import Query
+from superset.superset_typing import AdhocColumn
+from superset.utils import json
+from superset.utils.core import (
+    AdhocMetricExpressionType,
+    AnnotationType,
+    backend,
+    ExtraFiltersReasonType,
+    get_example_default_schema,
+)
+from superset.utils.database import get_example_database, get_main_database
+from tests.common.query_context_generator import ANNOTATION_LAYERS
+from tests.conftest import with_config
+from tests.integration_tests.annotation_layers.fixtures import (
+    create_annotation_layers,  # noqa: F401
+)
 from tests.integration_tests.base_tests import SupersetTestCase, test_client
-from tests.integration_tests.annotation_layers.fixtures import create_annotation_layers  # noqa: F401
+from tests.integration_tests.conftest import with_feature_flags
 from tests.integration_tests.constants import (
     ADMIN_USERNAME,
     GAMMA_NO_CSV_USERNAME,
@@ -42,37 +65,13 @@ from tests.integration_tests.fixtures.birth_names_dashboard import (
     load_birth_names_dashboard_with_slices,  # noqa: F401
     load_birth_names_data,  # noqa: F401
 )
-from tests.integration_tests.test_app import app
 from tests.integration_tests.fixtures.energy_dashboard import (
-    load_energy_table_with_slice,  # noqa: F401
     load_energy_table_data,  # noqa: F401
+    load_energy_table_with_slice,  # noqa: F401
 )
-import pytest
-from superset.models.slice import Slice
-
-from superset.commands.chart.data.get_data_command import ChartDataCommand
-from superset.connectors.sqla.models import TableColumn, SqlaTable
-from superset.errors import SupersetErrorType
-from superset.extensions import async_query_manager_factory, db
-from superset.models.annotations import AnnotationLayer
-from superset.superset_typing import AdhocColumn
-from superset.utils.core import (
-    AnnotationType,
-    backend,
-    get_example_default_schema,
-    AdhocMetricExpressionType,
-    ExtraFiltersReasonType,
-)
-from superset.utils import json
-from superset.utils.database import get_example_database, get_main_database
-from superset.common.chart_data import ChartDataResultFormat, ChartDataResultType
-
-from tests.common.query_context_generator import ANNOTATION_LAYERS
 from tests.integration_tests.fixtures.query_context import get_query_context
-
 from tests.integration_tests.test_app import app  # noqa: F811
 
-
 CHART_DATA_URI = "api/v1/chart/data"
 CHARTS_FIXTURE_COUNT = 10
 ADHOC_COLUMN_FIXTURE: AdhocColumn = {
@@ -124,7 +123,7 @@ class BaseTestChartDataApi(SupersetTestCase):
                                 GROUP BY name
                                 ORDER BY sum__num DESC
                                 LIMIT 100) AS inner__query
-                        """
+                        """  # noqa: S608
         resp = self.run_sql(sql, client_id, raise_on_error=True)
         db.session.query(Query).delete()
         db.session.commit()
@@ -138,6 +137,32 @@ class BaseTestChartDataApi(SupersetTestCase):
                 )
         return name
 
+    @contextmanager
+    def set_column_groupby_false(self, column_name: str):
+        """
+        Context manager to temporarily set a column's groupby property to false.
+        """
+        birth_names_table = self.get_birth_names_dataset()
+        target_column = None
+        original_groupby_value = None
+
+        for col in birth_names_table.columns:
+            if col.column_name == column_name:
+                target_column = col
+                original_groupby_value = col.groupby
+                break
+
+        if target_column:
+            target_column.groupby = False
+            db.session.commit()
+
+        try:
+            yield target_column
+        finally:
+            if target_column and original_groupby_value is not False:
+                target_column.groupby = original_groupby_value
+                db.session.commit()
+
 
 @pytest.mark.chart_data_flow
 class TestPostChartDataApi(BaseTestChartDataApi):
@@ -229,10 +254,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         assert rv.json["result"][0]["rowcount"] == expected_row_count
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    @mock.patch(
-        "superset.common.query_context_factory.config",
-        {**app.config, "ROW_LIMIT": 7},
-    )
+    @with_config({"ROW_LIMIT": 7})
     def test_without_row_limit__row_count_as_default_row_limit(self):
         # arrange
         expected_row_count = 7
@@ -243,10 +265,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         self.assert_row_count(rv, expected_row_count)
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    @mock.patch(
-        "superset.common.query_context_factory.config",
-        {**app.config, "SAMPLES_ROW_LIMIT": 5},
-    )
+    @with_config({"SAMPLES_ROW_LIMIT": 5})
     def test_as_samples_without_row_limit__row_count_as_default_samples_row_limit(self):
         # arrange
         expected_row_count = 5
@@ -263,7 +282,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     @mock.patch(
-        "superset.utils.core.current_app.config",
+        "flask.current_app.config",
         {**app.config, "SQL_MAX_ROW": 10},
     )
     def test_with_row_limit_bigger_then_sql_max_row__rowcount_as_sql_max_row(self):
@@ -279,7 +298,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     @mock.patch(
-        "superset.utils.core.current_app.config",
+        "flask.current_app.config",
         {**app.config, "SQL_MAX_ROW": 5},
     )
     def test_as_samples_with_row_limit_bigger_then_sql_max_row_rowcount_as_sql_max_row(
@@ -295,10 +314,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         assert "GROUP BY" not in rv.json["result"][0]["query"]
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    @mock.patch(
-        "superset.common.query_actions.config",
-        {**app.config, "SAMPLES_ROW_LIMIT": 5, "SQL_MAX_ROW": 15},
-    )
+    @with_config({"SAMPLES_ROW_LIMIT": 5, "SQL_MAX_ROW": 15})
     def test_with_row_limit_as_samples__rowcount_as_row_limit(self):
         expected_row_count = 10
         self.query_context_payload["result_type"] = ChartDataResultType.SAMPLES
@@ -471,19 +487,16 @@ class TestPostChartDataApi(BaseTestChartDataApi):
             "__time_origin": "now",
         }
         rv = self.post_assert_metric(CHART_DATA_URI, self.query_context_payload, "data")
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         data = json.loads(rv.data.decode("utf-8"))
-        self.assertEqual(
-            data["result"][0]["applied_filters"],
-            [
-                {"column": "gender"},
-                {"column": "num"},
-                {"column": "name"},
-                {"column": "__time_range"},
-            ],
-        )
+        assert data["result"][0]["applied_filters"] == [
+            {"column": "gender"},
+            {"column": "num"},
+            {"column": "name"},
+            {"column": "__time_range"},
+        ]
         expected_row_count = self.get_expected_row_count("client_id_2")
-        self.assertEqual(data["result"][0]["rowcount"], expected_row_count)
+        assert data["result"][0]["rowcount"] == expected_row_count
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_with_in_op_filter__data_is_returned(self):
@@ -533,7 +546,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
                 dttm_col.type,
                 dttm,
             )
-            self.assertIn(dttm_expression, result["query"])
+            assert dttm_expression in result["query"]
         else:
             raise Exception("ds column not found")
 
@@ -563,16 +576,16 @@ class TestPostChartDataApi(BaseTestChartDataApi):
             }
         ]
         rv = self.post_assert_metric(CHART_DATA_URI, self.query_context_payload, "data")
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         response_payload = json.loads(rv.data.decode("utf-8"))
         result = response_payload["result"][0]
         row = result["data"][0]
-        self.assertIn("__timestamp", row)
-        self.assertIn("sum__num", row)
-        self.assertIn("sum__num__yhat", row)
-        self.assertIn("sum__num__yhat_upper", row)
-        self.assertIn("sum__num__yhat_lower", row)
-        self.assertEqual(result["rowcount"], 103)
+        assert "__timestamp" in row
+        assert "sum__num" in row
+        assert "sum__num__yhat" in row
+        assert "sum__num__yhat_upper" in row
+        assert "sum__num__yhat_lower" in row
+        assert result["rowcount"] == 103
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_chart_data_invalid_post_processing(self):
@@ -668,7 +681,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         ]
         rv = self.post_assert_metric(CHART_DATA_URI, self.query_context_payload, "data")
 
-        assert rv.status_code == 400
+        assert rv.status_code == 422
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_with_invalid_having_parameter_closing_and_comment__400(self):
@@ -718,6 +731,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         if get_example_database().backend != "presto":
             assert "('boy' = 'boy')" in result
 
+    @unittest.skip("Extremely flaky test on MySQL")
     @with_feature_flags(GLOBAL_ASYNC_QUERIES=True)
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_chart_data_async(self):
@@ -729,11 +743,11 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         time.sleep(1)
         rv = self.post_assert_metric(CHART_DATA_URI, self.query_context_payload, "data")
         time.sleep(1)
-        self.assertEqual(rv.status_code, 202)
+        assert rv.status_code == 202
         time.sleep(1)
         data = json.loads(rv.data.decode("utf-8"))
         keys = list(data.keys())
-        self.assertCountEqual(
+        self.assertCountEqual(  # noqa: PT009
             keys, ["channel_id", "job_id", "user_id", "status", "errors", "result_url"]
         )
 
@@ -763,10 +777,10 @@ class TestPostChartDataApi(BaseTestChartDataApi):
             rv = self.post_assert_metric(
                 CHART_DATA_URI, self.query_context_payload, "data"
             )
-            self.assertEqual(rv.status_code, 200)
+            assert rv.status_code == 200
             data = json.loads(rv.data.decode("utf-8"))
             patched_run.assert_called_once_with(force_cached=True)
-            self.assertEqual(data, {"result": [{"query": "select * from foo"}]})
+            assert data == {"result": [{"query": "select * from foo"}]}
 
     @with_feature_flags(GLOBAL_ASYNC_QUERIES=True)
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
@@ -778,7 +792,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         async_query_manager_factory.init_app(app)
         self.query_context_payload["result_type"] = "results"
         rv = self.post_assert_metric(CHART_DATA_URI, self.query_context_payload, "data")
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
 
     @with_feature_flags(GLOBAL_ASYNC_QUERIES=True)
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
@@ -792,7 +806,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
             app.config["GLOBAL_ASYNC_QUERIES_JWT_COOKIE_NAME"], "foo"
         )
         rv = test_client.post(CHART_DATA_URI, json=self.query_context_payload)
-        self.assertEqual(rv.status_code, 401)
+        assert rv.status_code == 401
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_chart_data_rowcount(self):
@@ -834,7 +848,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_with_series_limit(self):
-        SERIES_LIMIT = 5
+        SERIES_LIMIT = 5  # noqa: N806
         self.query_context_payload["queries"][0]["columns"] = ["state", "name"]
         self.query_context_payload["queries"][0]["series_columns"] = ["name"]
         self.query_context_payload["queries"][0]["series_limit"] = SERIES_LIMIT
@@ -845,10 +859,8 @@ class TestPostChartDataApi(BaseTestChartDataApi):
 
         unique_names = {row["name"] for row in data}
         self.maxDiff = None
-        self.assertEqual(len(unique_names), SERIES_LIMIT)
-        self.assertEqual(
-            {column for column in data[0].keys()}, {"state", "name", "sum__num"}
-        )
+        assert len(unique_names) == SERIES_LIMIT
+        assert set(data[0]) == {"state", "name", "sum__num"}
 
     @pytest.mark.usefixtures(
         "create_annotation_layers", "load_birth_names_dashboard_with_slices"
@@ -887,10 +899,10 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         annotation_layers.append(event)
 
         rv = self.post_assert_metric(CHART_DATA_URI, self.query_context_payload, "data")
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         data = json.loads(rv.data.decode("utf-8"))
         # response should only contain interval and event data, not formula
-        self.assertEqual(len(data["result"][0]["annotation_data"]), 2)
+        assert len(data["result"][0]["annotation_data"]) == 2
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_with_virtual_table_with_colons_as_datasource(self):
@@ -939,7 +951,7 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         assert rv.status_code == 200
         result = rv.json["result"][0]
         data = result["data"]
-        assert {col for col in data[0].keys()} == {"foo", "bar", "state", "count"}
+        assert set(data[0]) == {"foo", "bar", "state", "count"}
         # make sure results and query parameters are unescaped
         assert {row["foo"] for row in data} == {":foo"}
         assert {row["bar"] for row in data} == {":bar:"}
@@ -988,6 +1000,73 @@ class TestPostChartDataApi(BaseTestChartDataApi):
         assert "name" in result["query"]
         assert list(result["data"][0].keys()) == ["name", "num divide by 10"]
 
+    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    def test_drill_by_allowed_column(self):
+        """
+        Chart data API: Test that user can drill by column with
+        isDimension set to True
+        """
+        request_payload = self.query_context_payload
+        request_payload["queries"][0]["columns"] = ["name"]
+        rv = self.post_assert_metric(CHART_DATA_URI, request_payload, "data")
+        assert rv.status_code == 200
+
+    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    def test_drill_by_disallowed_column_regular_user(self):
+        """
+        Chart data API: Test that user can still drill by column with
+        isDimension set to False (given the dataset access)
+        """
+        with self.set_column_groupby_false("num_girls"):
+            self.query_context_payload["queries"][0]["columns"] = ["num_girls"]
+            rv = self.post_assert_metric(
+                CHART_DATA_URI, self.query_context_payload, "data"
+            )
+            assert rv.status_code == 200
+
+    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    @mock.patch("superset.security.manager.SupersetSecurityManager.has_guest_access")
+    @mock.patch("superset.security.manager.SupersetSecurityManager.is_guest_user")
+    @with_feature_flags(EMBEDDED_SUPERSET=True)
+    def test_embedded_user_drill_by_allowed_column(
+        self, mock_is_guest_user, mock_has_guest_access
+    ):
+        """
+        Chart data API: Test that embedded user can drill by column with
+        isDimension set to True.
+        """
+        g.user.rls = []
+        mock_has_guest_access.return_value = True
+        mock_is_guest_user.return_value = True
+        request_payload = self.query_context_payload
+        request_payload["queries"][0]["columns"] = ["name"]
+        rv = self.post_assert_metric(CHART_DATA_URI, request_payload, "data")
+        assert rv.status_code == 200
+
+    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    @mock.patch("superset.security.manager.SupersetSecurityManager.has_guest_access")
+    @mock.patch("superset.security.manager.SupersetSecurityManager.is_guest_user")
+    @with_feature_flags(EMBEDDED_SUPERSET=True)
+    def test_embedded_user_drill_by_disallowed_column(
+        self, mock_is_guest_user, mock_has_guest_access
+    ):
+        """
+        Chart data API: Test that embedded user can't drill by column with
+        isDimension set to False.
+        """
+        self.logout()
+        self.login(GAMMA_USERNAME)
+
+        with self.set_column_groupby_false("num_girls"):
+            g.user.rls = []
+            mock_has_guest_access.return_value = True
+            mock_is_guest_user.return_value = True
+            self.query_context_payload["queries"][0]["columns"] = ["num_girls"]
+            rv = self.post_assert_metric(
+                CHART_DATA_URI, self.query_context_payload, "data"
+            )
+            assert rv.status_code == 403
+
 
 @pytest.mark.chart_data_flow
 class TestGetChartDataApi(BaseTestChartDataApi):
@@ -1183,8 +1262,8 @@ class TestGetChartDataApi(BaseTestChartDataApi):
             data = json.loads(rv.data.decode("utf-8"))
 
         expected_row_count = self.get_expected_row_count("client_id_3")
-        self.assertEqual(rv.status_code, 200)
-        self.assertEqual(data["result"][0]["rowcount"], expected_row_count)
+        assert rv.status_code == 200
+        assert data["result"][0]["rowcount"] == expected_row_count
 
     @with_feature_flags(GLOBAL_ASYNC_QUERIES=True)
     @mock.patch("superset.charts.data.api.QueryContextCacheLoader")
@@ -1201,8 +1280,8 @@ class TestGetChartDataApi(BaseTestChartDataApi):
         )
         data = json.loads(rv.data.decode("utf-8"))
 
-        self.assertEqual(rv.status_code, 422)
-        self.assertEqual(data["message"], "Error loading data from cache")
+        assert rv.status_code == 422
+        assert data["message"] == "Error loading data from cache"
 
     @with_feature_flags(GLOBAL_ASYNC_QUERIES=True)
     @mock.patch("superset.charts.data.api.QueryContextCacheLoader")
@@ -1230,7 +1309,7 @@ class TestGetChartDataApi(BaseTestChartDataApi):
                 f"{CHART_DATA_URI}/test-cache-key",
             )
 
-        self.assertEqual(rv.status_code, 401)
+        assert rv.status_code == 401
 
     @with_feature_flags(GLOBAL_ASYNC_QUERIES=True)
     def test_chart_data_cache_key_error(self):
@@ -1243,7 +1322,7 @@ class TestGetChartDataApi(BaseTestChartDataApi):
             f"{CHART_DATA_URI}/test-cache-key", "data_from_cache"
         )
 
-        self.assertEqual(rv.status_code, 404)
+        assert rv.status_code == 404
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_chart_data_with_adhoc_column(self):
@@ -1259,7 +1338,7 @@ class TestGetChartDataApi(BaseTestChartDataApi):
         response_payload = json.loads(rv.data.decode("utf-8"))
         result = response_payload["result"][0]
         data = result["data"]
-        assert {column for column in data[0].keys()} == {"male_or_female", "sum__num"}
+        assert set(data[0]) == {"male_or_female", "sum__num"}
         unique_genders = {row["male_or_female"] for row in data}
         assert unique_genders == {"male", "female"}
         assert result["applied_filters"] == [{"column": "male_or_female"}]
@@ -1279,7 +1358,7 @@ class TestGetChartDataApi(BaseTestChartDataApi):
         response_payload = json.loads(rv.data.decode("utf-8"))
         result = response_payload["result"][0]
         data = result["data"]
-        assert {column for column in data[0].keys()} == {"male_or_female", "sum__num"}
+        assert set(data[0]) == {"male_or_female", "sum__num"}
         unique_genders = {row["male_or_female"] for row in data}
         assert unique_genders == {"male", "female"}
         assert result["applied_filters"] == [{"column": "male_or_female"}]
@@ -1290,8 +1369,60 @@ class TestGetChartDataApi(BaseTestChartDataApi):
             }
         ]
 
+    @mock.patch("superset.security.manager.SupersetSecurityManager.has_guest_access")
+    @mock.patch("superset.security.manager.SupersetSecurityManager.is_guest_user")
+    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    def test_chart_data_as_guest_user(self, is_guest_user, has_guest_access):
+        """
+        Chart data API: Test response does not inlcude the SQL query for embedded
+        users.
+        """
+        g.user.rls = []
+        is_guest_user.return_value = True
+        has_guest_access.return_value = True
 
-@pytest.fixture()
+        rv = self.client.post(CHART_DATA_URI, json=self.query_context_payload)
+        data = json.loads(rv.data.decode("utf-8"))
+        result = data["result"]
+        excluded_key = "query"
+        assert all([excluded_key not in query for query in result])  # noqa: C419
+
+    def test_chart_data_table_chart_with_time_grain_filter(self):
+        """
+        Chart data API: Test that a table chart that's not using a temporal column can
+        still receive a time grain filter (for Jinja purposes).
+        """
+        metric_def = {
+            "aggregate": None,
+            "column": None,
+            "datasourceWarning": False,
+            "expressionType": "SQL",
+            "hasCustomLabel": True,
+            "label": "test",
+            "optionName": "metric_1eef4v0fryc_m7tm09g1hu",
+            "sqlExpression": "'{{ time_grain }}'",
+        }
+        self.query_context_payload["queries"][0]["columns"] = []
+        self.query_context_payload["queries"][0]["metrics"] = [metric_def]
+        self.query_context_payload["queries"][0]["row_limit"] = 1
+        self.query_context_payload["queries"][0]["extras"] = {
+            "where": "",
+            "having": "",
+            "time_grain_sqla": "PT5M",
+        }
+        self.query_context_payload["queries"][0]["orderby"] = [[metric_def, True]]
+        del self.query_context_payload["queries"][0]["granularity"]
+        del self.query_context_payload["queries"][0]["time_range"]
+        self.query_context_payload["queries"][0]["filters"] = []
+
+        rv = self.client.post(CHART_DATA_URI, json=self.query_context_payload)
+        data = json.loads(rv.data.decode("utf-8"))
+        result = data["result"][0]
+        assert "PT5M" in result["query"]
+        assert result["data"] == [{"test": "PT5M"}]
+
+
+@pytest.fixture
 def physical_query_context(physical_dataset) -> dict[str, Any]:
     return {
         "datasource": {
@@ -1311,7 +1442,7 @@ def physical_query_context(physical_dataset) -> dict[str, Any]:
 
 
 @mock.patch(
-    "superset.common.query_context_processor.config",
+    "flask.current_app.config",
     {
         **app.config,
         "CACHE_DEFAULT_TIMEOUT": 1234,
@@ -1346,7 +1477,7 @@ def test_time_filter_with_grain(test_client, login_as_admin, physical_query_cont
     backend = get_example_database().backend
     if backend == "sqlite":
         assert (
-            "DATETIME(col5, 'start of day',             -strftime('%w', col5) || ' days') >="
+            "DATETIME(col5, 'start of day',             -strftime('%w', col5) || ' days') >="  # noqa: E501
             in query
         )
     elif backend == "mysql":
@@ -1358,7 +1489,7 @@ def test_time_filter_with_grain(test_client, login_as_admin, physical_query_cont
 
 
 def test_force_cache_timeout(test_client, login_as_admin, physical_query_context):
-    physical_query_context["custom_cache_timeout"] = -1
+    physical_query_context["custom_cache_timeout"] = CACHE_DISABLED_TIMEOUT
     test_client.post(CHART_DATA_URI, json=physical_query_context)
     rv = test_client.post(CHART_DATA_URI, json=physical_query_context)
     assert rv.json["result"][0]["cached_dttm"] is None
@@ -1366,7 +1497,7 @@ def test_force_cache_timeout(test_client, login_as_admin, physical_query_context
 
 
 @mock.patch(
-    "superset.common.query_context_processor.config",
+    "flask.current_app.config",
     {
         **app.config,
         "CACHE_DEFAULT_TIMEOUT": 100000,
@@ -1411,7 +1542,7 @@ def test_chart_cache_timeout(
 
 
 @mock.patch(
-    "superset.common.query_context_processor.config",
+    "flask.current_app.config",
     {
         **app.config,
         "DATA_CACHE_CONFIG": {
@@ -1438,7 +1569,7 @@ def test_chart_cache_timeout_not_present(
 
 
 @mock.patch(
-    "superset.common.query_context_processor.config",
+    "flask.current_app.config",
     {
         **app.config,
         "DATA_CACHE_CONFIG": {
