@@ -42,19 +42,16 @@ from superset.connectors.sqla.models import SqlaTable
 from superset.db_engine_specs.base import BaseEngineSpec
 from superset.db_engine_specs.mssql import MssqlEngineSpec
 from superset.exceptions import SupersetException
-from superset.extensions import async_query_manager_factory, cache_manager
+from superset.extensions import cache_manager
 from superset.models import core as models
-from superset.models.cache import CacheKey
 from superset.models.dashboard import Dashboard
 from superset.models.slice import Slice
 from superset.models.sql_lab import Query
 from superset.result_set import SupersetResultSet
-from superset.sql_parse import Table
+from superset.sql.parse import Table
 from superset.utils import core as utils, json
 from superset.utils.core import backend
 from superset.utils.database import get_example_database
-from superset.views.database.views import DatabaseView
-from tests.integration_tests.conftest import with_feature_flags
 from tests.integration_tests.constants import ADMIN_USERNAME, GAMMA_USERNAME
 from tests.integration_tests.fixtures.birth_names_dashboard import (
     load_birth_names_dashboard_with_slices,  # noqa: F401
@@ -80,7 +77,7 @@ def cleanup():
     db.session.query(Query).delete()
     db.session.query(models.Log).delete()
     db.session.commit()
-    yield
+    return
 
 
 class TestCore(SupersetTestCase):
@@ -88,11 +85,9 @@ class TestCore(SupersetTestCase):
         self.table_ids = {
             tbl.table_name: tbl.id for tbl in (db.session.query(SqlaTable).all())
         }
-        self.original_unsafe_db_setting = app.config["PREVENT_UNSAFE_DB_CONNECTIONS"]
 
     def tearDown(self):
         db.session.query(Query).delete()
-        app.config["PREVENT_UNSAFE_DB_CONNECTIONS"] = self.original_unsafe_db_setting
         super().tearDown()
 
     def insert_dashboard_created_by(self, username: str) -> Dashboard:
@@ -105,25 +100,13 @@ class TestCore(SupersetTestCase):
         )
         return dashboard
 
-    @pytest.fixture()
+    @pytest.fixture
     def insert_dashboard_created_by_gamma(self):
         dashboard = self.insert_dashboard_created_by("gamma")
         yield dashboard
         db.session.delete(dashboard)
         db.session.commit()
 
-    def test_login(self):
-        resp = self.get_resp("/login/", data=dict(username="admin", password="general"))
-        self.assertNotIn("User confirmation needed", resp)
-
-        resp = self.get_resp("/logout/", follow_redirects=True)
-        self.assertIn("User confirmation needed", resp)
-
-        resp = self.get_resp(
-            "/login/", data=dict(username="admin", password="wrongPassword")
-        )
-        self.assertIn("User confirmation needed", resp)
-
     def test_dashboard_endpoint(self):
         self.login(ADMIN_USERNAME)
         resp = self.client.get("/superset/dashboard/-1/")
@@ -135,10 +118,10 @@ class TestCore(SupersetTestCase):
         resp = self.client.get("/superset/slice/-1/")
         assert resp.status_code == 404
 
-    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    @pytest.mark.usefixtures("load_world_bank_dashboard_with_slices")
     def test_viz_cache_key(self):
         self.login(ADMIN_USERNAME)
-        slc = self.get_slice("Top 10 Girl Name Share")
+        slc = self.get_slice("Life Expectancy VS Rural %")
 
         viz = slc.viz
         qobj = viz.query_obj()
@@ -146,27 +129,24 @@ class TestCore(SupersetTestCase):
 
         qobj["groupby"] = []
         cache_key_with_groupby = viz.cache_key(qobj)
-        self.assertNotEqual(cache_key, cache_key_with_groupby)
+        assert cache_key != cache_key_with_groupby
 
-        self.assertNotEqual(
-            viz.cache_key(qobj), viz.cache_key(qobj, time_compare="12 weeks")
-        )
+        assert viz.cache_key(qobj) != viz.cache_key(qobj, time_compare="12 weeks")
 
-        self.assertNotEqual(
-            viz.cache_key(qobj, time_compare="28 days"),
-            viz.cache_key(qobj, time_compare="12 weeks"),
+        assert viz.cache_key(qobj, time_compare="28 days") != viz.cache_key(
+            qobj, time_compare="12 weeks"
         )
 
         qobj["inner_from_dttm"] = datetime.datetime(1901, 1, 1)
 
-        self.assertEqual(cache_key_with_groupby, viz.cache_key(qobj))
+        assert cache_key_with_groupby == viz.cache_key(qobj)
 
     def test_admin_only_menu_views(self):
         def assert_admin_view_menus_in(role_name, assert_func):
             role = security_manager.find_role(role_name)
             view_menus = [p.view_menu.name for p in role.permissions]
             assert_func("ResetPasswordView", view_menus)
-            assert_func("RoleModelView", view_menus)
+            assert_func("RoleRestAPI", view_menus)
             assert_func("Security", view_menus)
             assert_func("SQL Lab", view_menus)
 
@@ -180,9 +160,9 @@ class TestCore(SupersetTestCase):
         slice_name = f"Energy Sankey"  # noqa: F541
         slice_id = self.get_slice(slice_name).id
         copy_name_prefix = "Test Sankey"
-        copy_name = f"{copy_name_prefix}[save]{random.random()}"
+        copy_name = f"{copy_name_prefix}[save]{random.random()}"  # noqa: S311
         tbl_id = self.table_ids.get("energy_usage")
-        new_slice_name = f"{copy_name_prefix}[overwrite]{random.random()}"
+        new_slice_name = f"{copy_name_prefix}[overwrite]{random.random()}"  # noqa: S311
 
         url = (
             "/superset/explore/table/{}/?slice_name={}&"
@@ -205,12 +185,16 @@ class TestCore(SupersetTestCase):
         new_slice_id = resp.json["form_data"]["slice_id"]
         slc = db.session.query(Slice).filter_by(id=new_slice_id).one()
 
-        self.assertEqual(slc.slice_name, copy_name)
+        assert slc.slice_name == copy_name
+        form_data["datasource"] = f"{tbl_id}__table"
+        form_data["slice_id"] = new_slice_id
+
+        assert slc.form_data == form_data
         form_data.pop("slice_id")  # We don't save the slice id when saving as
-        self.assertEqual(slc.viz.form_data, form_data)
 
         form_data = {
             "adhoc_filters": [],
+            "datasource": f"{tbl_id}__table",
             "viz_type": "sankey",
             "groupby": ["source"],
             "metric": "sum__value",
@@ -224,8 +208,8 @@ class TestCore(SupersetTestCase):
             data={"form_data": json.dumps(form_data)},
         )
         slc = db.session.query(Slice).filter_by(id=new_slice_id).one()
-        self.assertEqual(slc.slice_name, new_slice_name)
-        self.assertEqual(slc.viz.form_data, form_data)
+        assert slc.slice_name == new_slice_name
+        assert slc.form_data == form_data
 
         # Cleanup
         slices = (
@@ -251,7 +235,7 @@ class TestCore(SupersetTestCase):
     def test_slices(self):
         # Testing by hitting the two supported end points for all slices
         self.login(ADMIN_USERNAME)
-        Slc = Slice
+        Slc = Slice  # noqa: N806
         urls = []
         for slc in db.session.query(Slc).all():
             urls += [
@@ -261,24 +245,17 @@ class TestCore(SupersetTestCase):
             logger.info(f"[{name}]/[{method}]: {url}")
             print(f"[{name}]/[{method}]: {url}")
             resp = self.client.get(url)
-            self.assertEqual(resp.status_code, 200)
+            assert resp.status_code == 200
 
     def test_add_slice(self):
         self.login(ADMIN_USERNAME)
         # assert that /chart/add responds with 200
         url = "/chart/add"
         resp = self.client.get(url)
-        self.assertEqual(resp.status_code, 200)
-
-    def test_get_user_slices(self):
-        self.login(ADMIN_USERNAME)
-        userid = security_manager.find_user("admin").id
-        url = f"/sliceasync/api/read?_flt_0_created_by={userid}"
-        resp = self.client.get(url)
-        self.assertEqual(resp.status_code, 200)
+        assert resp.status_code == 200
 
     @pytest.mark.usefixtures("load_energy_table_with_slice")
-    def test_slices_V2(self):
+    def test_slices_V2(self):  # noqa: N802
         # Add explore-v2-beta role to admin user
         # Test all slice urls as user with explore-v2-beta role
         security_manager.add_role("explore-v2-beta")
@@ -289,11 +266,11 @@ class TestCore(SupersetTestCase):
             " user",
             "explore_beta@airbnb.com",
             security_manager.find_role("explore-v2-beta"),
-            password="general",
+            password="general",  # noqa: S106
         )
-        self.login(username="explore_beta", password="general")
+        self.login(username="explore_beta", password="general")  # noqa: S106
 
-        Slc = Slice
+        Slc = Slice  # noqa: N806
         urls = []
         for slc in db.session.query(Slc).all():
             urls += [(slc.slice_name, "slice_url", slc.slice_url)]
@@ -320,60 +297,13 @@ class TestCore(SupersetTestCase):
         def custom_password_store(uri):
             return "password_store_test"
 
-        models.custom_password_store = custom_password_store
-        conn = sqla.engine.url.make_url(database.sqlalchemy_uri_decrypted)
-        if conn_pre.password:
-            assert conn.password == "password_store_test"
-            assert conn.password != conn_pre.password
-        # Disable for password store for later tests
-        models.custom_password_store = None
-
-    def test_databaseview_edit(self):
-        # validate that sending a password-masked uri does not over-write the decrypted
-        # uri
-        self.login(ADMIN_USERNAME)
-        database = superset.utils.database.get_example_database()
-        sqlalchemy_uri_decrypted = database.sqlalchemy_uri_decrypted
-        url = f"databaseview/edit/{database.id}"
-        data = {k: database.__getattribute__(k) for k in DatabaseView.add_columns}
-        data["sqlalchemy_uri"] = database.safe_sqlalchemy_uri()
-        self.client.post(url, data=data)
-        database = superset.utils.database.get_example_database()
-        self.assertEqual(sqlalchemy_uri_decrypted, database.sqlalchemy_uri_decrypted)
-
-        # Need to clean up after ourselves
-        database.impersonate_user = False
-        database.allow_dml = False
-        database.allow_run_async = False
-        db.session.commit()
-
-    @pytest.mark.usefixtures(
-        "load_birth_names_dashboard_with_slices",
-        "load_energy_table_with_slice",
-    )
-    def test_warm_up_cache(self):
-        self.login(ADMIN_USERNAME)
-        slc = self.get_slice("Top 10 Girl Name Share")
-        data = self.get_json_resp(f"/superset/warm_up_cache?slice_id={slc.id}")
-        self.assertEqual(
-            data, [{"slice_id": slc.id, "viz_error": None, "viz_status": "success"}]
-        )
-
-        data = self.get_json_resp(
-            "/superset/warm_up_cache?table_name=energy_usage&db_name=main"
-        )
-        assert len(data) > 0
-
-        dashboard = self.get_dash_by_slug("births")
-
-        assert self.get_json_resp(
-            f"/superset/warm_up_cache?dashboard_id={dashboard.id}&slice_id={slc.id}"
-        ) == [{"slice_id": slc.id, "viz_error": None, "viz_status": "success"}]
-
-        assert self.get_json_resp(
-            f"/superset/warm_up_cache?dashboard_id={dashboard.id}&slice_id={slc.id}&extra_filters="
-            + quote(json.dumps([{"col": "name", "op": "in", "val": ["Jennifer"]}]))
-        ) == [{"slice_id": slc.id, "viz_error": None, "viz_status": "success"}]
+        with mock.patch.dict(
+            app.config, {"SQLALCHEMY_CUSTOM_PASSWORD_STORE": custom_password_store}
+        ):
+            conn = sqla.engine.url.make_url(database.sqlalchemy_uri_decrypted)
+            if conn_pre.password:
+                assert conn.password == "password_store_test"  # noqa: S105
+                assert conn.password != conn_pre.password
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_warm_up_cache_error(self) -> None:
@@ -398,47 +328,6 @@ class TestCore(SupersetTestCase):
                 }
             ]
 
-    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    def test_cache_logging(self):
-        self.login(ADMIN_USERNAME)
-        store_cache_keys = app.config["STORE_CACHE_KEYS_IN_METADATA_DB"]
-        app.config["STORE_CACHE_KEYS_IN_METADATA_DB"] = True
-        slc = self.get_slice("Top 10 Girl Name Share")
-        self.get_json_resp(f"/superset/warm_up_cache?slice_id={slc.id}")
-        ck = db.session.query(CacheKey).order_by(CacheKey.id.desc()).first()
-        assert ck.datasource_uid == f"{slc.table.id}__table"
-        db.session.delete(ck)
-        app.config["STORE_CACHE_KEYS_IN_METADATA_DB"] = store_cache_keys
-
-    @with_feature_flags(KV_STORE=False)
-    def test_kv_disabled(self):
-        self.login(ADMIN_USERNAME)
-
-        resp = self.client.get("/kv/10001/")
-        self.assertEqual(404, resp.status_code)
-
-        value = json.dumps({"data": "this is a test"})
-        resp = self.client.post("/kv/store/", data=dict(data=value))
-        self.assertEqual(resp.status_code, 404)
-
-    @with_feature_flags(KV_STORE=True)
-    def test_kv_enabled(self):
-        self.login(ADMIN_USERNAME)
-
-        resp = self.client.get("/kv/10001/")
-        self.assertEqual(404, resp.status_code)
-
-        value = json.dumps({"data": "this is a test"})
-        resp = self.client.post("/kv/store/", data=dict(data=value))
-        self.assertEqual(resp.status_code, 200)
-        kv = db.session.query(models.KeyValue).first()
-        kv_value = kv.value
-        self.assertEqual(json.loads(value), json.loads(kv_value))
-
-        resp = self.client.get(f"/kv/{kv.id}/")
-        self.assertEqual(resp.status_code, 200)
-        self.assertEqual(json.loads(value), json.loads(resp.data.decode("utf-8")))
-
     def test_gamma(self):
         self.login(GAMMA_USERNAME)
         assert "Charts" in self.get_resp("/chart/list/")
@@ -451,11 +340,11 @@ class TestCore(SupersetTestCase):
         self.login(ADMIN_USERNAME)
         sql = "SELECT '{{ 1+1 }}' as test"
         data = self.run_sql(sql, "fdaklj3ws")
-        self.assertEqual(data["data"][0]["test"], "2")
+        assert data["data"][0]["test"] == "2"
 
     def test_fetch_datasource_metadata(self):
         self.login(ADMIN_USERNAME)
-        url = "/superset/fetch_datasource_metadata?" "datasourceKey=1__table"
+        url = "/superset/fetch_datasource_metadata?datasourceKey=1__table"
         resp = self.get_json_resp(url)
         keys = [
             "name",
@@ -466,7 +355,7 @@ class TestCore(SupersetTestCase):
             "id",
         ]
         for k in keys:
-            self.assertIn(k, resp.keys())
+            assert k in resp.keys()
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_slice_id_is_always_logged_correctly_on_web_request(self):
@@ -475,7 +364,7 @@ class TestCore(SupersetTestCase):
         slc = db.session.query(Slice).filter_by(slice_name="Girls").one()
         qry = db.session.query(models.Log).filter_by(slice_id=slc.id)
         self.get_resp(slc.slice_url)
-        self.assertEqual(1, qry.count())
+        assert 1 == qry.count()
 
     def create_sample_csvfile(self, filename: str, content: list[str]) -> None:
         with open(filename, "w+") as test_file:
@@ -490,7 +379,7 @@ class TestCore(SupersetTestCase):
         database.allow_file_upload = True
         db.session.commit()
         add_datasource_page = self.get_resp("/databaseview/list/")
-        self.assertIn("Upload a CSV", add_datasource_page)
+        assert "Upload a CSV" in add_datasource_page
 
     def test_dataframe_timezone(self):
         tz = pytz.FixedOffset(60)
@@ -502,15 +391,15 @@ class TestCore(SupersetTestCase):
         df = results.to_pandas_df()
         data = dataframe.df_to_records(df)
         json_str = json.dumps(data, default=json.pessimistic_json_iso_dttm_ser)
-        self.assertDictEqual(
+        self.assertDictEqual(  # noqa: PT009
             data[0], {"data": pd.Timestamp("2017-11-18 21:53:00.219225+0100", tz=tz)}
         )
-        self.assertDictEqual(
+        self.assertDictEqual(  # noqa: PT009
             data[1], {"data": pd.Timestamp("2017-11-18 22:06:30+0100", tz=tz)}
         )
-        self.assertEqual(
-            json_str,
-            '[{"data": "2017-11-18T21:53:00.219225+01:00"}, {"data": "2017-11-18T22:06:30+01:00"}]',
+        assert (
+            json_str
+            == '[{"data": "2017-11-18T21:53:00.219225+01:00"}, {"data": "2017-11-18T22:06:30+01:00"}]'  # noqa: E501
         )
 
     def test_mssql_engine_spec_pymssql(self):
@@ -524,11 +413,12 @@ class TestCore(SupersetTestCase):
         )
         df = results.to_pandas_df()
         data = dataframe.df_to_records(df)
-        self.assertEqual(len(data), 2)
-        self.assertEqual(
-            data[0],
-            {"col1": 1, "col2": 1, "col3": pd.Timestamp("2017-10-19 23:39:16.660000")},
-        )
+        assert len(data) == 2
+        assert data[0] == {
+            "col1": 1,
+            "col2": 1,
+            "col3": pd.Timestamp("2017-10-19 23:39:16.660000"),
+        }
 
     def test_comments_in_sqlatable_query(self):
         clean_query = "SELECT\n  '/* val 1 */' AS c1,\n  '-- val 2' AS c2\nFROM tbl"
@@ -554,276 +444,19 @@ class TestCore(SupersetTestCase):
         )
         data = json.loads(rv.data.decode("utf-8"))
 
-        self.assertEqual(
-            data["errors"][0]["message"],
-            "The dataset associated with this chart no longer exists",
+        assert (
+            data["errors"][0]["message"]
+            == "The dataset associated with this chart no longer exists"
         )
 
-    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    def test_explore_json(self):
-        tbl_id = self.table_ids.get("birth_names")
-        form_data = {
-            "datasource": f"{tbl_id}__table",
-            "viz_type": "dist_bar",
-            "granularity_sqla": "ds",
-            "time_range": "No filter",
-            "metrics": ["count"],
-            "adhoc_filters": [],
-            "groupby": ["gender"],
-            "row_limit": 100,
-        }
-        self.login(ADMIN_USERNAME)
-        rv = self.client.post(
-            "/superset/explore_json/",
-            data={"form_data": json.dumps(form_data)},
-        )
-        data = json.loads(rv.data.decode("utf-8"))
-
-        self.assertEqual(rv.status_code, 200)
-        self.assertEqual(data["rowcount"], 2)
-
-    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    def test_explore_json_dist_bar_order(self):
-        tbl_id = self.table_ids.get("birth_names")
-        form_data = {
-            "datasource": f"{tbl_id}__table",
-            "viz_type": "dist_bar",
-            "url_params": {},
-            "granularity_sqla": "ds",
-            "time_range": 'DATEADD(DATETIME("2021-01-22T00:00:00"), -100, year) : 2021-01-22T00:00:00',
-            "metrics": [
-                {
-                    "expressionType": "SIMPLE",
-                    "column": {
-                        "id": 334,
-                        "column_name": "name",
-                        "verbose_name": "null",
-                        "description": "null",
-                        "expression": "",
-                        "filterable": True,
-                        "groupby": True,
-                        "is_dttm": False,
-                        "type": "VARCHAR(255)",
-                        "python_date_format": "null",
-                    },
-                    "aggregate": "COUNT",
-                    "sqlExpression": "null",
-                    "isNew": False,
-                    "hasCustomLabel": False,
-                    "label": "COUNT(name)",
-                    "optionName": "metric_xdzsijn42f9_khi4h3v3vci",
-                },
-                {
-                    "expressionType": "SIMPLE",
-                    "column": {
-                        "id": 332,
-                        "column_name": "ds",
-                        "verbose_name": "null",
-                        "description": "null",
-                        "expression": "",
-                        "filterable": True,
-                        "groupby": True,
-                        "is_dttm": True,
-                        "type": "TIMESTAMP WITHOUT TIME ZONE",
-                        "python_date_format": "null",
-                    },
-                    "aggregate": "COUNT",
-                    "sqlExpression": "null",
-                    "isNew": False,
-                    "hasCustomLabel": False,
-                    "label": "COUNT(ds)",
-                    "optionName": "metric_80g1qb9b6o7_ci5vquydcbe",
-                },
-            ],
-            "order_desc": True,
-            "adhoc_filters": [],
-            "groupby": ["name"],
-            "columns": [],
-            "row_limit": 10,
-            "color_scheme": "supersetColors",
-            "label_colors": {},
-            "show_legend": True,
-            "y_axis_format": "SMART_NUMBER",
-            "bottom_margin": "auto",
-            "x_ticks_layout": "auto",
-        }
-
-        self.login(ADMIN_USERNAME)
-        rv = self.client.post(
-            "/superset/explore_json/",
-            data={"form_data": json.dumps(form_data)},
-        )
-        data = json.loads(rv.data.decode("utf-8"))
-
-        resp = self.run_sql(
-            """
-            SELECT count(name) AS count_name, count(ds) AS count_ds
-            FROM birth_names
-            WHERE ds >= '1921-01-22 00:00:00.000000' AND ds < '2021-01-22 00:00:00.000000'
-            GROUP BY name
-            ORDER BY count_name DESC
-            LIMIT 10;
-            """,
-            client_id="client_id_1",
-            username="admin",
-        )
-        count_ds = []
-        count_name = []
-        for series in data["data"]:
-            if series["key"] == "COUNT(ds)":
-                count_ds = series["values"]
-            if series["key"] == "COUNT(name)":
-                count_name = series["values"]
-        for expected, actual_ds, actual_name in zip(resp["data"], count_ds, count_name):
-            assert expected["count_name"] == actual_name["y"]
-            assert expected["count_ds"] == actual_ds["y"]
-
-    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    @mock.patch.dict(
-        "superset.extensions.feature_flag_manager._feature_flags",
-        GLOBAL_ASYNC_QUERIES=True,
-    )
-    def test_explore_json_async(self):
-        tbl_id = self.table_ids.get("birth_names")
-        form_data = {
-            "datasource": f"{tbl_id}__table",
-            "viz_type": "dist_bar",
-            "granularity_sqla": "ds",
-            "time_range": "No filter",
-            "metrics": ["count"],
-            "adhoc_filters": [],
-            "groupby": ["gender"],
-            "row_limit": 100,
-        }
-        app._got_first_request = False
-        async_query_manager_factory.init_app(app)
-        self.login(ADMIN_USERNAME)
-        rv = self.client.post(
-            "/superset/explore_json/",
-            data={"form_data": json.dumps(form_data)},
-        )
-        data = json.loads(rv.data.decode("utf-8"))
-        keys = list(data.keys())
-
-        # If chart is cached, it will return 200, otherwise 202
-        assert rv.status_code in {200, 202}
-        if rv.status_code == 202:
-            assert keys == [
-                "channel_id",
-                "job_id",
-                "user_id",
-                "status",
-                "errors",
-                "result_url",
-            ]
-
-    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    @mock.patch.dict(
-        "superset.extensions.feature_flag_manager._feature_flags",
-        GLOBAL_ASYNC_QUERIES=True,
-    )
-    def test_explore_json_async_results_format(self):
-        tbl_id = self.table_ids.get("birth_names")
-        form_data = {
-            "datasource": f"{tbl_id}__table",
-            "viz_type": "dist_bar",
-            "granularity_sqla": "ds",
-            "time_range": "No filter",
-            "metrics": ["count"],
-            "adhoc_filters": [],
-            "groupby": ["gender"],
-            "row_limit": 100,
-        }
-        app._got_first_request = False
-        async_query_manager_factory.init_app(app)
-        self.login(ADMIN_USERNAME)
-        rv = self.client.post(
-            "/superset/explore_json/?results=true",
-            data={"form_data": json.dumps(form_data)},
-        )
-        self.assertEqual(rv.status_code, 200)
-
-    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    @mock.patch(
-        "superset.utils.cache_manager.CacheManager.cache",
-        new_callable=mock.PropertyMock,
-    )
-    @mock.patch("superset.viz.BaseViz.force_cached", new_callable=mock.PropertyMock)
-    def test_explore_json_data(self, mock_force_cached, mock_cache):
-        tbl_id = self.table_ids.get("birth_names")
-        form_data = dict(
-            {
-                "form_data": {
-                    "datasource": f"{tbl_id}__table",
-                    "viz_type": "dist_bar",
-                    "granularity_sqla": "ds",
-                    "time_range": "No filter",
-                    "metrics": ["count"],
-                    "adhoc_filters": [],
-                    "groupby": ["gender"],
-                    "row_limit": 100,
-                }
-            }
-        )
-
-        class MockCache:
-            def get(self, key):
-                return form_data
-
-            def set(self):
-                return None
-
-        mock_cache.return_value = MockCache()
-        mock_force_cached.return_value = False
-
-        self.login(ADMIN_USERNAME)
-        rv = self.client.get("/superset/explore_json/data/valid-cache-key")
-        data = json.loads(rv.data.decode("utf-8"))
-
-        self.assertEqual(rv.status_code, 200)
-        self.assertEqual(data["rowcount"], 2)
-
-    @mock.patch(
-        "superset.utils.cache_manager.CacheManager.cache",
-        new_callable=mock.PropertyMock,
-    )
-    def test_explore_json_data_no_login(self, mock_cache):
-        tbl_id = self.table_ids.get("birth_names")
-        form_data = dict(
-            {
-                "form_data": {
-                    "datasource": f"{tbl_id}__table",
-                    "viz_type": "dist_bar",
-                    "granularity_sqla": "ds",
-                    "time_range": "No filter",
-                    "metrics": ["count"],
-                    "adhoc_filters": [],
-                    "groupby": ["gender"],
-                    "row_limit": 100,
-                }
-            }
-        )
-
-        class MockCache:
-            def get(self, key):
-                return form_data
-
-            def set(self):
-                return None
-
-        mock_cache.return_value = MockCache()
-
-        rv = self.client.get("/superset/explore_json/data/valid-cache-key")
-        self.assertEqual(rv.status_code, 403)
-
     def test_explore_json_data_invalid_cache_key(self):
         self.login(ADMIN_USERNAME)
         cache_key = "invalid-cache-key"
         rv = self.client.get(f"/superset/explore_json/data/{cache_key}")
         data = json.loads(rv.data.decode("utf-8"))
 
-        self.assertEqual(rv.status_code, 404)
-        self.assertEqual(data["error"], "Cached data not found")
+        assert rv.status_code == 404
+        assert data["error"] == "Cached data not found"
 
     def test_results_default_deserialization(self):
         use_new_deserialization = False
@@ -863,14 +496,14 @@ class TestCore(SupersetTestCase):
         serialized_payload = sql_lab._serialize_payload(
             payload, use_new_deserialization
         )
-        self.assertIsInstance(serialized_payload, str)
+        assert isinstance(serialized_payload, str)
 
         query_mock = mock.Mock()
         deserialized_payload = superset.views.utils._deserialize_results_payload(
             serialized_payload, query_mock, use_new_deserialization
         )
 
-        self.assertDictEqual(deserialized_payload, payload)
+        self.assertDictEqual(deserialized_payload, payload)  # noqa: PT009
         query_mock.assert_not_called()
 
     def test_results_msgpack_deserialization(self):
@@ -911,7 +544,7 @@ class TestCore(SupersetTestCase):
         serialized_payload = sql_lab._serialize_payload(
             payload, use_new_deserialization
         )
-        self.assertIsInstance(serialized_payload, bytes)
+        assert isinstance(serialized_payload, bytes)
 
         with mock.patch.object(
             db_engine_spec, "expand_data", wraps=db_engine_spec.expand_data
@@ -925,7 +558,7 @@ class TestCore(SupersetTestCase):
             df = results.to_pandas_df()
             payload["data"] = dataframe.df_to_records(df)
 
-            self.assertDictEqual(deserialized_payload, payload)
+            self.assertDictEqual(deserialized_payload, payload)  # noqa: PT009
             expand_data.assert_called_once()
 
     @mock.patch.dict(
@@ -960,7 +593,7 @@ class TestCore(SupersetTestCase):
         ]
         for url in urls:
             data = self.get_resp(url)
-            self.assertTrue(html_string in data)
+            assert html_string in data
 
     @mock.patch.dict(
         "superset.extensions.feature_flag_manager._feature_flags",
@@ -991,7 +624,7 @@ class TestCore(SupersetTestCase):
         tab_state_id = resp["id"]
         payload = self.get_json_resp(f"/tabstateview/{tab_state_id}")
 
-        self.assertEqual(payload["label"], "Untitled Query foo")
+        assert payload["label"] == "Untitled Query foo"
 
     def test_tabstate_update(self):
         self.login(ADMIN_USERNAME)
@@ -1014,86 +647,86 @@ class TestCore(SupersetTestCase):
         client_id = "asdfasdf"
         data = {"sql": json.dumps("select 1"), "latest_query_id": json.dumps(client_id)}
         response = self.client.put(f"/tabstateview/{tab_state_id}", data=data)
-        self.assertEqual(response.status_code, 400)
+        assert response.status_code == 400
         # generate query
         db.session.add(Query(client_id=client_id, database_id=1))
         db.session.commit()
         # update tab state with a valid client_id
         response = self.client.put(f"/tabstateview/{tab_state_id}", data=data)
-        self.assertEqual(response.status_code, 200)
+        assert response.status_code == 200
         # nulls should be ok too
         data["latest_query_id"] = "null"
         response = self.client.put(f"/tabstateview/{tab_state_id}", data=data)
-        self.assertEqual(response.status_code, 200)
+        assert response.status_code == 200
 
     def test_virtual_table_explore_visibility(self):
         # test that default visibility it set to True
         database = superset.utils.database.get_example_database()
-        self.assertEqual(database.allows_virtual_table_explore, True)
+        assert database.allows_virtual_table_explore is True
 
         # test that visibility is disabled when extra is set to False
         extra = database.get_extra()
         extra["allows_virtual_table_explore"] = False
         database.extra = json.dumps(extra)
-        self.assertEqual(database.allows_virtual_table_explore, False)
+        assert database.allows_virtual_table_explore is False
 
         # test that visibility is enabled when extra is set to True
         extra = database.get_extra()
         extra["allows_virtual_table_explore"] = True
         database.extra = json.dumps(extra)
-        self.assertEqual(database.allows_virtual_table_explore, True)
+        assert database.allows_virtual_table_explore is True
 
         # test that visibility is not broken with bad values
         extra = database.get_extra()
         extra["allows_virtual_table_explore"] = "trash value"
         database.extra = json.dumps(extra)
-        self.assertEqual(database.allows_virtual_table_explore, True)
+        assert database.allows_virtual_table_explore is True
 
     def test_data_preview_visibility(self):
         # test that default visibility is allowed
         database = utils.get_example_database()
-        self.assertEqual(database.disable_data_preview, False)
+        assert database.disable_data_preview is False
 
         # test that visibility is disabled when extra is set to true
         extra = database.get_extra()
         extra["disable_data_preview"] = True
         database.extra = json.dumps(extra)
-        self.assertEqual(database.disable_data_preview, True)
+        assert database.disable_data_preview is True
 
         # test that visibility is enabled when extra is set to false
         extra = database.get_extra()
         extra["disable_data_preview"] = False
         database.extra = json.dumps(extra)
-        self.assertEqual(database.disable_data_preview, False)
+        assert database.disable_data_preview is False
 
         # test that visibility is not broken with bad values
         extra = database.get_extra()
         extra["disable_data_preview"] = "trash value"
         database.extra = json.dumps(extra)
-        self.assertEqual(database.disable_data_preview, False)
+        assert database.disable_data_preview is False
 
     def test_disable_drill_to_detail(self):
         # test that disable_drill_to_detail is False by default
         database = utils.get_example_database()
-        self.assertEqual(database.disable_drill_to_detail, False)
+        assert database.disable_drill_to_detail is False
 
         # test that disable_drill_to_detail can be set to True
         extra = database.get_extra()
         extra["disable_drill_to_detail"] = True
         database.extra = json.dumps(extra)
-        self.assertEqual(database.disable_drill_to_detail, True)
+        assert database.disable_drill_to_detail is True
 
         # test that disable_drill_to_detail can be set to False
         extra = database.get_extra()
         extra["disable_drill_to_detail"] = False
         database.extra = json.dumps(extra)
-        self.assertEqual(database.disable_drill_to_detail, False)
+        assert database.disable_drill_to_detail is False
 
         # test that disable_drill_to_detail is not broken with bad values
         extra = database.get_extra()
         extra["disable_drill_to_detail"] = "trash value"
         database.extra = json.dumps(extra)
-        self.assertEqual(database.disable_drill_to_detail, False)
+        assert database.disable_drill_to_detail is False
 
     def test_explore_database_id(self):
         database = superset.utils.database.get_example_database()
@@ -1101,13 +734,13 @@ class TestCore(SupersetTestCase):
 
         # test that explore_database_id is the regular database
         # id if none is set in the extra
-        self.assertEqual(database.explore_database_id, database.id)
+        assert database.explore_database_id == database.id
 
         # test that explore_database_id is correct if the extra is set
         extra = database.get_extra()
         extra["explore_database_id"] = explore_database.id
         database.extra = json.dumps(extra)
-        self.assertEqual(database.explore_database_id, explore_database.id)
+        assert database.explore_database_id == explore_database.id
 
     def test_get_column_names_from_metric(self):
         simple_metric = {
@@ -1145,7 +778,7 @@ class TestCore(SupersetTestCase):
 
         self.login(ADMIN_USERNAME)
         data = self.get_resp(url)
-        self.assertIn("Error message", data)
+        assert "Error message" in data
 
         # Assert we can handle a driver exception at the mutator level
         exception = SQLAlchemyError("Error message")
@@ -1155,7 +788,7 @@ class TestCore(SupersetTestCase):
 
         self.login(ADMIN_USERNAME)
         data = self.get_resp(url)
-        self.assertIn("Error message", data)
+        assert "Error message" in data
 
     @pytest.mark.skip(
         "TODO This test was wrong - 'Error message' was in the language pack"
@@ -1175,7 +808,7 @@ class TestCore(SupersetTestCase):
 
         self.login(ADMIN_USERNAME)
         data = self.get_resp(url)
-        self.assertIn("Error message", data)
+        assert "Error message" in data
 
         # Assert we can handle a driver exception at the mutator level
         exception = SQLAlchemyError("Error message")
@@ -1185,7 +818,7 @@ class TestCore(SupersetTestCase):
 
         self.login(ADMIN_USERNAME)
         data = self.get_resp(url)
-        self.assertIn("Error message", data)
+        assert "Error message" in data
 
     @pytest.mark.usefixtures("load_energy_table_with_slice")
     @mock.patch("superset.commands.explore.form_data.create.CreateFormDataCommand.run")
@@ -1199,9 +832,7 @@ class TestCore(SupersetTestCase):
         rv = self.client.get(
             f"/superset/explore/?form_data={quote(json.dumps(form_data))}"
         )
-        self.assertEqual(
-            rv.headers["Location"], f"/explore/?form_data_key={random_key}"
-        )
+        assert rv.headers["Location"] == f"/explore/?form_data_key={random_key}"
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_has_table(self):
@@ -1220,11 +851,62 @@ class TestCore(SupersetTestCase):
         self.login(ADMIN_USERNAME)
         resp = self.client.get("superset/dashboard/p/123/")
 
-        expected_url = "/superset/dashboard/1?permalink_key=123&standalone=3"
+        expected_url = "/superset/dashboard/1/?permalink_key=123&standalone=3"
 
-        self.assertEqual(resp.headers["Location"], expected_url)
+        assert resp.headers["Location"] == expected_url
         assert resp.status_code == 302
 
 
+class TestLocalePatch(SupersetTestCase):
+    MOCK_LANGUAGES = (
+        "flask.current_app.config",
+        {
+            "LANGUAGES": {
+                "es": {"flag": "es", "name": "Español"},
+            },
+        },
+    )
+
+    @mock.patch.dict(*MOCK_LANGUAGES)
+    def test_lang_redirect(self):
+        self.login(GAMMA_USERNAME)
+        referer_url = "http://localhost/explore/"
+        resp = self.client.get("/lang/es", headers={"Referer": referer_url})
+
+        assert resp.status_code == 302
+        assert resp.headers["Location"] == referer_url
+        with self.client.session_transaction() as session:
+            assert session["locale"] == "es"
+
+    @mock.patch.dict(*MOCK_LANGUAGES)
+    def test_lang_invalid_referer(self):
+        self.login(GAMMA_USERNAME)
+        referer_url = "http://someotherserver/explore/"
+        resp = self.client.get("/lang/es", headers={"Referer": referer_url})
+
+        assert resp.status_code == 302
+        assert resp.headers["Location"] == "/"
+        with self.client.session_transaction() as session:
+            assert session["locale"] == "es"
+
+    @mock.patch.dict(*MOCK_LANGUAGES)
+    def test_lang_no_referer(self):
+        self.login(GAMMA_USERNAME)
+        resp = self.client.get("/lang/es")
+
+        assert resp.status_code == 302
+        assert resp.headers["Location"] == "/"
+        with self.client.session_transaction() as session:
+            assert session["locale"] == "es"
+
+    def test_lang_invalid_locale(self):
+        self.login(GAMMA_USERNAME)
+        resp = self.client.get("/lang/es")
+
+        assert resp.status_code == 500
+        with self.client.session_transaction() as session:
+            assert session["locale"] == "en"
+
+
 if __name__ == "__main__":
     unittest.main()
