@@ -108,7 +108,7 @@ class TestDashboardRoleBasedSecurity(BaseTestDashboardSecurity):
 
         # act
         response = self.get_dashboard_view_response(dashboard_to_access)
-        assert response.status_code == 302
+        assert response.status_code == 404  # Authenticated users without access get 404
 
         request_payload = get_query_context("birth_names")
         rv = self.post_assert_metric(CHART_DATA_URI, request_payload, "data")
@@ -129,7 +129,7 @@ class TestDashboardRoleBasedSecurity(BaseTestDashboardSecurity):
         response = self.get_dashboard_view_response(dashboard_to_access)
 
         # assert
-        assert response.status_code == 302
+        assert response.status_code == 404
 
         # post
         revoke_access_to_dashboard(dashboard_to_access, new_role)  # noqa: F405
@@ -149,7 +149,7 @@ class TestDashboardRoleBasedSecurity(BaseTestDashboardSecurity):
 
         # assert redirect on regular rbac access denied
         response = self.get_dashboard_view_response(dashboard)
-        assert response.status_code == 302
+        assert response.status_code == 404
 
         request_payload = get_query_context("birth_names")
         rv = self.post_assert_metric(CHART_DATA_URI, request_payload, "data")
@@ -207,7 +207,7 @@ class TestDashboardRoleBasedSecurity(BaseTestDashboardSecurity):
 
         request_payload = get_query_context("birth_names")
         rv = self.post_assert_metric(CHART_DATA_URI, request_payload, "data")
-        self.assertEqual(rv.status_code, 403)
+        assert rv.status_code == 403
 
         # post
         revoke_access_to_dashboard(dashboard_to_access, new_role)  # noqa: F405
@@ -221,10 +221,11 @@ class TestDashboardRoleBasedSecurity(BaseTestDashboardSecurity):
         response = self.get_dashboard_view_response(dashboard_to_access)
 
         # assert
+        # Anonymous users are redirected to login instead of getting 404
         assert response.status_code == 302
 
     @pytest.mark.usefixtures("public_role_like_gamma")
-    def test_get_dashboard_view__public_user_with_dashboard_permission_can_not_access_draft(
+    def test_get_dashboard_view__public_user_with_dashboard_permission_can_not_access_draft(  # noqa: E501
         self,
     ):
         # arrange
@@ -234,6 +235,7 @@ class TestDashboardRoleBasedSecurity(BaseTestDashboardSecurity):
         response = self.get_dashboard_view_response(dashboard_to_access)
 
         # assert
+        # Anonymous users are redirected to login for unpublished dashboards
         assert response.status_code == 302
 
         # post
@@ -480,12 +482,12 @@ class TestDashboardRoleBasedSecurity(BaseTestDashboardSecurity):
 
         self.login(GAMMA_USERNAME)
         rv = self.client.post(uri, json=data)
-        self.assertEqual(rv.status_code, 403)
+        assert rv.status_code == 403
         self.logout()
 
         self.login(ADMIN_USERNAME)
         rv = self.client.post(uri, json=data)
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         response = json.loads(rv.data.decode("utf-8"))
 
         target = (
