@@ -22,8 +22,9 @@ from unittest import mock
 
 import prison
 import pytest
+from flask import current_app
 
-from superset import app, db
+from superset import db
 from superset.commands.dataset.exceptions import DatasetNotFoundError
 from superset.common.utils.query_cache_manager import QueryCacheManager
 from superset.connectors.sqla.models import (  # noqa: F401
@@ -43,12 +44,16 @@ from superset.utils.database import (  # noqa: F401
 )
 from tests.integration_tests.base_tests import db_insert_temp_object, SupersetTestCase
 from tests.integration_tests.conftest import with_feature_flags
-from tests.integration_tests.constants import ADMIN_USERNAME
+from tests.integration_tests.constants import ADMIN_USERNAME, GAMMA_USERNAME
 from tests.integration_tests.fixtures.birth_names_dashboard import (
     load_birth_names_dashboard_with_slices,  # noqa: F401
     load_birth_names_data,  # noqa: F401
 )
 from tests.integration_tests.fixtures.datasource import get_datasource_post
+from tests.integration_tests.fixtures.world_bank_dashboard import (
+    load_world_bank_dashboard_with_slices,  # noqa: F401
+    load_world_bank_data,  # noqa: F401
+)
 
 
 @contextmanager
@@ -58,10 +63,10 @@ def create_test_table_context(database: Database):
 
     with database.get_sqla_engine() as engine:
         engine.execute(
-            f"CREATE TABLE IF NOT EXISTS {full_table_name} AS SELECT 1 as first, 2 as second"
+            f"CREATE TABLE IF NOT EXISTS {full_table_name} AS SELECT 1 as first, 2 as second"  # noqa: E501
         )
-        engine.execute(f"INSERT INTO {full_table_name} (first, second) VALUES (1, 2)")
-        engine.execute(f"INSERT INTO {full_table_name} (first, second) VALUES (3, 4)")
+        engine.execute(f"INSERT INTO {full_table_name} (first, second) VALUES (1, 2)")  # noqa: S608
+        engine.execute(f"INSERT INTO {full_table_name} (first, second) VALUES (3, 4)")  # noqa: S608
 
     yield db.session
 
@@ -102,9 +107,15 @@ class TestDatasource(SupersetTestCase):
         url = f"/datasource/external_metadata/table/{tbl.id}/"
         resp = self.get_json_resp(url)
         col_names = {o.get("column_name") for o in resp}
-        self.assertEqual(
-            col_names, {"num_boys", "num", "gender", "name", "ds", "state", "num_girls"}
-        )
+        assert col_names == {
+            "num_boys",
+            "num",
+            "gender",
+            "name",
+            "ds",
+            "state",
+            "num_girls",
+        }
 
     def test_always_filter_main_dttm(self):
         database = get_example_database()
@@ -145,11 +156,11 @@ class TestDatasource(SupersetTestCase):
         with create_and_cleanup_table(table):
             table.always_filter_main_dttm = False
             result = str(table.get_sqla_query(**query_obj).sqla_query.whereclause)
-            assert "default_dttm" not in result and "additional_dttm" in result
+            assert "default_dttm" not in result and "additional_dttm" in result  # noqa: PT018
 
             table.always_filter_main_dttm = True
             result = str(table.get_sqla_query(**query_obj).sqla_query.whereclause)
-            assert "default_dttm" in result and "additional_dttm" in result
+            assert "default_dttm" in result and "additional_dttm" in result  # noqa: PT018
 
     def test_external_metadata_for_virtual_table(self):
         self.login(ADMIN_USERNAME)
@@ -176,9 +187,15 @@ class TestDatasource(SupersetTestCase):
         url = f"/datasource/external_metadata_by_name/?q={params}"
         resp = self.get_json_resp(url)
         col_names = {o.get("column_name") for o in resp}
-        self.assertEqual(
-            col_names, {"num_boys", "num", "gender", "name", "ds", "state", "num_girls"}
-        )
+        assert col_names == {
+            "num_boys",
+            "num",
+            "gender",
+            "name",
+            "ds",
+            "state",
+            "num_girls",
+        }
 
     def test_external_metadata_by_name_for_virtual_table(self):
         self.login(ADMIN_USERNAME)
@@ -200,7 +217,7 @@ class TestDatasource(SupersetTestCase):
     def test_external_metadata_by_name_for_virtual_table_uses_mutator(self):
         self.login(ADMIN_USERNAME)
         with create_and_cleanup_table() as tbl:
-            app.config["SQL_QUERY_MUTATOR"] = (
+            current_app.config["SQL_QUERY_MUTATOR"] = (
                 lambda sql, **kwargs: "SELECT 456 as intcol, 'def' as mutated_strcol"
             )
 
@@ -217,7 +234,7 @@ class TestDatasource(SupersetTestCase):
             url = f"/datasource/external_metadata_by_name/?q={params}"
             resp = self.get_json_resp(url)
             assert {o.get("column_name") for o in resp} == {"intcol", "mutated_strcol"}
-            app.config["SQL_QUERY_MUTATOR"] = None
+            current_app.config["SQL_QUERY_MUTATOR"] = None
 
     def test_external_metadata_by_name_from_sqla_inspector(self):
         self.login(ADMIN_USERNAME)
@@ -236,7 +253,7 @@ class TestDatasource(SupersetTestCase):
             url = f"/datasource/external_metadata_by_name/?q={params}"
             resp = self.get_json_resp(url)
             col_names = {o.get("column_name") for o in resp}
-            self.assertEqual(col_names, {"first", "second"})
+            assert col_names == {"first", "second"}
 
         # No databases found
         params = prison.dumps(
@@ -250,10 +267,10 @@ class TestDatasource(SupersetTestCase):
         )
         url = f"/datasource/external_metadata_by_name/?q={params}"
         resp = self.client.get(url)
-        self.assertEqual(resp.status_code, DatasetNotFoundError.status)
-        self.assertEqual(
-            json.loads(resp.data.decode("utf-8")).get("error"),
-            DatasetNotFoundError.message,
+        assert resp.status_code == DatasetNotFoundError.status
+        assert (
+            json.loads(resp.data.decode("utf-8")).get("error")
+            == DatasetNotFoundError.message
         )
 
         # No table found
@@ -268,10 +285,10 @@ class TestDatasource(SupersetTestCase):
         )
         url = f"/datasource/external_metadata_by_name/?q={params}"
         resp = self.client.get(url)
-        self.assertEqual(resp.status_code, DatasetNotFoundError.status)
-        self.assertEqual(
-            json.loads(resp.data.decode("utf-8")).get("error"),
-            DatasetNotFoundError.message,
+        assert resp.status_code == DatasetNotFoundError.status
+        assert (
+            json.loads(resp.data.decode("utf-8")).get("error")
+            == DatasetNotFoundError.message
         )
 
         # invalid query params
@@ -282,7 +299,7 @@ class TestDatasource(SupersetTestCase):
         )
         url = f"/datasource/external_metadata_by_name/?q={params}"
         resp = self.get_json_resp(url)
-        self.assertIn("error", resp)
+        assert "error" in resp
 
     def test_external_metadata_for_virtual_table_template_params(self):
         self.login(ADMIN_USERNAME)
@@ -309,7 +326,7 @@ class TestDatasource(SupersetTestCase):
         with db_insert_temp_object(table):
             url = f"/datasource/external_metadata/table/{table.id}/"
             resp = self.get_json_resp(url)
-            self.assertEqual(resp["error"], "Only `SELECT` statements are allowed")
+            assert resp["error"] == "Only `SELECT` statements are allowed"
 
     def test_external_metadata_for_multistatement_virtual_table(self):
         self.login(ADMIN_USERNAME)
@@ -323,7 +340,7 @@ class TestDatasource(SupersetTestCase):
         with db_insert_temp_object(table):
             url = f"/datasource/external_metadata/table/{table.id}/"
             resp = self.get_json_resp(url)
-            self.assertEqual(resp["error"], "Only single queries supported")
+            assert resp["error"] == "Only single queries supported"
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     @mock.patch("superset.connectors.sqla.models.SqlaTable.external_metadata")
@@ -351,7 +368,7 @@ class TestDatasource(SupersetTestCase):
             obj2 = l2_lookup.get(obj1.get(key))
             for k in obj1:
                 if k not in "id" and obj1.get(k):
-                    self.assertEqual(obj1.get(k), obj2.get(k))
+                    assert obj1.get(k) == obj2.get(k)
 
     def test_save(self):
         self.login(ADMIN_USERNAME)
@@ -360,7 +377,7 @@ class TestDatasource(SupersetTestCase):
         datasource_post = get_datasource_post()
         datasource_post["id"] = tbl_id
         datasource_post["owners"] = [1]
-        data = dict(data=json.dumps(datasource_post))
+        data = dict(data=json.dumps(datasource_post))  # noqa: C408
         resp = self.get_json_resp("/datasource/save/", data)
         for k in datasource_post:
             if k == "columns":
@@ -368,11 +385,11 @@ class TestDatasource(SupersetTestCase):
             elif k == "metrics":
                 self.compare_lists(datasource_post[k], resp[k], "metric_name")
             elif k == "database":
-                self.assertEqual(resp[k]["id"], datasource_post[k]["id"])
+                assert resp[k]["id"] == datasource_post[k]["id"]
             elif k == "owners":
-                self.assertEqual([o["id"] for o in resp[k]], datasource_post["owners"])
+                assert [o["id"] for o in resp[k]] == datasource_post["owners"]
             else:
-                self.assertEqual(resp[k], datasource_post[k])
+                assert resp[k] == datasource_post[k]
 
     def test_save_default_endpoint_validation_success(self):
         self.login(ADMIN_USERNAME)
@@ -382,12 +399,12 @@ class TestDatasource(SupersetTestCase):
         datasource_post["id"] = tbl_id
         datasource_post["owners"] = [1]
         datasource_post["default_endpoint"] = "http://localhost/superset/1"
-        data = dict(data=json.dumps(datasource_post))
+        data = dict(data=json.dumps(datasource_post))  # noqa: C408
         resp = self.client.post("/datasource/save/", data=data)
         assert resp.status_code == 200
 
     def save_datasource_from_dict(self, datasource_post):
-        data = dict(data=json.dumps(datasource_post))
+        data = dict(data=json.dumps(datasource_post))  # noqa: C408
         resp = self.get_json_resp("/datasource/save/", data)
         return resp
 
@@ -405,11 +422,11 @@ class TestDatasource(SupersetTestCase):
         new_db = self.create_fake_db()
         datasource_post["database"]["id"] = new_db.id
         resp = self.save_datasource_from_dict(datasource_post)
-        self.assertEqual(resp["database"]["id"], new_db.id)
+        assert resp["database"]["id"] == new_db.id
 
         datasource_post["database"]["id"] = db_id
         resp = self.save_datasource_from_dict(datasource_post)
-        self.assertEqual(resp["database"]["id"], db_id)
+        assert resp["database"]["id"] == db_id
 
         self.delete_fake_db()
 
@@ -439,9 +456,9 @@ class TestDatasource(SupersetTestCase):
                 },
             ]
         )
-        data = dict(data=json.dumps(datasource_post))
+        data = dict(data=json.dumps(datasource_post))  # noqa: C408
         resp = self.get_json_resp("/datasource/save/", data, raise_on_error=False)
-        self.assertIn("Duplicate column name(s): <new column>", resp["error"])
+        assert "Duplicate column name(s): <new column>" in resp["error"]
 
     def test_get_datasource(self):
         admin_user = self.get_user("admin")
@@ -451,36 +468,33 @@ class TestDatasource(SupersetTestCase):
         datasource_post = get_datasource_post()
         datasource_post["id"] = tbl.id
         datasource_post["owners"] = [admin_user.id]
-        data = dict(data=json.dumps(datasource_post))
+        data = dict(data=json.dumps(datasource_post))  # noqa: C408
         self.get_json_resp("/datasource/save/", data)
         url = f"/datasource/get/{tbl.type}/{tbl.id}/"
         resp = self.get_json_resp(url)
-        self.assertEqual(resp.get("type"), "table")
+        assert resp.get("type") == "table"
         col_names = {o.get("column_name") for o in resp["columns"]}
-        self.assertEqual(
-            col_names,
-            {
-                "num_boys",
-                "num",
-                "gender",
-                "name",
-                "ds",
-                "state",
-                "num_girls",
-                "num_california",
-            },
-        )
+        assert col_names == {
+            "num_boys",
+            "num",
+            "gender",
+            "name",
+            "ds",
+            "state",
+            "num_girls",
+            "num_california",
+        }
 
     def test_get_datasource_with_health_check(self):
         def my_check(datasource):
             return "Warning message!"
 
-        app.config["DATASET_HEALTH_CHECK"] = my_check
+        current_app.config["DATASET_HEALTH_CHECK"] = my_check
         self.login(ADMIN_USERNAME)
         tbl = self.get_table(name="birth_names")
         datasource = db.session.query(SqlaTable).filter_by(id=tbl.id).one_or_none()
         assert datasource.health_check_message == "Warning message!"
-        app.config["DATASET_HEALTH_CHECK"] = None
+        current_app.config["DATASET_HEALTH_CHECK"] = None
 
     def test_get_datasource_failed(self):
         from superset.daos.datasource import DatasourceDAO
@@ -492,7 +506,7 @@ class TestDatasource(SupersetTestCase):
 
         self.login(ADMIN_USERNAME)
         resp = self.get_json_resp("/datasource/get/table/500000/", raise_on_error=False)
-        self.assertEqual(resp.get("error"), "Datasource does not exist")
+        assert resp.get("error") == "Datasource does not exist"
 
     def test_get_datasource_invalid_datasource_failed(self):
         from superset.daos.datasource import DatasourceDAO
@@ -504,7 +518,73 @@ class TestDatasource(SupersetTestCase):
 
         self.login(ADMIN_USERNAME)
         resp = self.get_json_resp("/datasource/get/druid/500000/", raise_on_error=False)
-        self.assertEqual(resp.get("error"), "'druid' is not a valid DatasourceType")
+        assert resp.get("error") == "'druid' is not a valid DatasourceType"
+
+    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    @mock.patch(
+        "superset.security.manager.SupersetSecurityManager.get_guest_rls_filters"
+    )
+    @mock.patch("superset.security.manager.SupersetSecurityManager.is_guest_user")
+    @mock.patch("superset.security.manager.SupersetSecurityManager.has_guest_access")
+    @with_feature_flags(EMBEDDED_SUPERSET=True)
+    def test_get_samples_embedded_user(
+        self, mock_has_guest_access, mock_is_guest_user, mock_rls
+    ):
+        """
+        Embedded user can access the /samples view.
+        """
+        self.login(ADMIN_USERNAME)
+        mock_is_guest_user.return_value = True
+        mock_has_guest_access.return_value = True
+        mock_rls.return_value = []
+        tbl = self.get_table(name="birth_names")
+        dash = self.get_dash_by_slug("births")
+        uri = f"/datasource/samples?datasource_id={tbl.id}&datasource_type=table&dashboard_id={dash.id}"  # noqa: E501
+        resp = self.client.post(uri, json={})
+        assert resp.status_code == 200
+
+    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    @mock.patch(
+        "superset.security.manager.SupersetSecurityManager.get_guest_rls_filters"
+    )
+    @mock.patch("superset.security.manager.SupersetSecurityManager.is_guest_user")
+    @with_feature_flags(EMBEDDED_SUPERSET=True)
+    def test_get_samples_embedded_user_without_dash_id(
+        self, mock_is_guest_user, mock_rls
+    ):
+        """
+        Embedded user can't access the /samples view if not providing a dashboard ID.
+        """
+        self.login(GAMMA_USERNAME)
+        mock_is_guest_user.return_value = True
+        mock_rls.return_value = []
+        tbl = self.get_table(name="birth_names")
+        uri = f"/datasource/samples?datasource_id={tbl.id}&datasource_type=table"
+        resp = self.client.post(uri, json={})
+        assert resp.status_code == 403
+
+    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    @pytest.mark.usefixtures("load_world_bank_dashboard_with_slices")
+    @mock.patch(
+        "superset.security.manager.SupersetSecurityManager.get_guest_rls_filters"
+    )
+    @mock.patch("superset.security.manager.SupersetSecurityManager.is_guest_user")
+    @with_feature_flags(EMBEDDED_SUPERSET=True)
+    def test_get_samples_embedded_user_dashboard_without_dataset(
+        self, mock_is_guest_user, mock_rls
+    ):
+        """
+        Embedded user can't access the /samples view when providing a dashboard ID that
+        does not include the target dataset.
+        """
+        self.login(GAMMA_USERNAME)
+        mock_is_guest_user.return_value = True
+        mock_rls.return_value = []
+        tbl = self.get_table(name="birth_names")
+        dash = self.get_dash_by_slug("world_health")
+        uri = f"/datasource/samples?datasource_id={tbl.id}&datasource_type=table&dashboard_id={dash.id}"  # noqa: E501
+        resp = self.client.post(uri, json={})
+        assert resp.status_code == 403
 
 
 def test_get_samples(test_client, login_as_admin, virtual_dataset):
@@ -528,7 +608,7 @@ def test_get_samples(test_client, login_as_admin, virtual_dataset):
     assert rv.json["result"]["is_cached"]
 
     # 2. should read through cache data
-    uri2 = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&force=true"
+    uri2 = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&force=true"  # noqa: E501
     # feeds data
     test_client.post(uri2, json={})
     # force query
@@ -547,8 +627,8 @@ def test_get_samples(test_client, login_as_admin, virtual_dataset):
     assert "data" in rv2.json["result"]
 
     sql = (
-        f"select * from ({virtual_dataset.sql}) as tbl "
-        f'limit {app.config["SAMPLES_ROW_LIMIT"]}'
+        f"select * from ({virtual_dataset.sql}) as tbl "  # noqa: S608
+        f"limit {current_app.config['SAMPLES_ROW_LIMIT']}"
     )
     eager_samples = virtual_dataset.database.get_df(sql)
 
@@ -559,6 +639,9 @@ def test_get_samples(test_client, login_as_admin, virtual_dataset):
 
 
 def test_get_samples_with_incorrect_cc(test_client, login_as_admin, virtual_dataset):
+    if get_example_database().backend == "sqlite":
+        return
+
     TableColumn(
         column_name="DUMMY CC",
         type="VARCHAR(255)",
@@ -571,10 +654,7 @@ def test_get_samples_with_incorrect_cc(test_client, login_as_admin, virtual_data
     )
     rv = test_client.post(uri, json={})
     assert rv.status_code == 422
-
-    assert "error" in rv.json
-    if virtual_dataset.database.db_engine_spec.engine_name == "PostgreSQL":
-        assert "INCORRECT SQL" in rv.json.get("error")
+    assert rv.json["errors"][0]["error_type"] == "INVALID_SQL_ERROR"
 
 
 @with_feature_flags(ALLOW_ADHOC_SUBQUERY=True)
@@ -638,7 +718,14 @@ def test_get_samples_with_filters(test_client, login_as_admin, virtual_dataset):
         },
     )
     assert rv.status_code == 200
-    assert rv.json["result"]["colnames"] == []
+    assert rv.json["result"]["colnames"] == [
+        "col1",
+        "col2",
+        "col3",
+        "col4",
+        "col5",
+        "col6",
+    ]
     assert rv.json["result"]["rowcount"] == 0
 
 
@@ -659,7 +746,7 @@ def test_get_samples_with_time_filter(test_client, login_as_admin, physical_data
             946857600000.0,  # 2000-01-03 00:00:00
         ]
     assert rv.json["result"]["page"] == 1
-    assert rv.json["result"]["per_page"] == app.config["SAMPLES_ROW_LIMIT"]
+    assert rv.json["result"]["per_page"] == current_app.config["SAMPLES_ROW_LIMIT"]
     assert rv.json["result"]["total_count"] == 2
 
 
@@ -696,7 +783,7 @@ def test_get_samples_with_multiple_filters(
     assert "2000-01-02" in rv.json["result"]["query"]
     assert "2000-01-04" in rv.json["result"]["query"]
     assert "col3 = 1.2" in rv.json["result"]["query"]
-    assert "col4 is null" in rv.json["result"]["query"]
+    assert "col4 IS NULL" in rv.json["result"]["query"]
     assert "col2 = 'c'" in rv.json["result"]["query"]
 
 
@@ -707,18 +794,18 @@ def test_get_samples_pagination(test_client, login_as_admin, virtual_dataset):
     )
     rv = test_client.post(uri, json={})
     assert rv.json["result"]["page"] == 1
-    assert rv.json["result"]["per_page"] == app.config["SAMPLES_ROW_LIMIT"]
+    assert rv.json["result"]["per_page"] == current_app.config["SAMPLES_ROW_LIMIT"]
     assert rv.json["result"]["total_count"] == 10
 
     # 2. incorrect per_page
-    per_pages = (app.config["SAMPLES_ROW_LIMIT"] + 1, 0, "xx")
+    per_pages = (current_app.config["SAMPLES_ROW_LIMIT"] + 1, 0, "xx")
     for per_page in per_pages:
-        uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&per_page={per_page}"
+        uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&per_page={per_page}"  # noqa: E501
         rv = test_client.post(uri, json={})
         assert rv.status_code == 400
 
     # 3. incorrect page or datasource_type
-    uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&page=xx"
+    uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&page=xx"  # noqa: E501
     rv = test_client.post(uri, json={})
     assert rv.status_code == 400
 
@@ -727,14 +814,14 @@ def test_get_samples_pagination(test_client, login_as_admin, virtual_dataset):
     assert rv.status_code == 400
 
     # 4. turning pages
-    uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&per_page=2&page=1"
+    uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&per_page=2&page=1"  # noqa: E501
     rv = test_client.post(uri, json={})
     assert rv.json["result"]["page"] == 1
     assert rv.json["result"]["per_page"] == 2
     assert rv.json["result"]["total_count"] == 10
     assert [row["col1"] for row in rv.json["result"]["data"]] == [0, 1]
 
-    uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&per_page=2&page=2"
+    uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&per_page=2&page=2"  # noqa: E501
     rv = test_client.post(uri, json={})
     assert rv.json["result"]["page"] == 2
     assert rv.json["result"]["per_page"] == 2
@@ -742,7 +829,7 @@ def test_get_samples_pagination(test_client, login_as_admin, virtual_dataset):
     assert [row["col1"] for row in rv.json["result"]["data"]] == [2, 3]
 
     # 5. Exceeding the maximum pages
-    uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&per_page=2&page=6"
+    uri = f"/datasource/samples?datasource_id={virtual_dataset.id}&datasource_type=table&per_page=2&page=6"  # noqa: E501
     rv = test_client.post(uri, json={})
     assert rv.json["result"]["page"] == 6
     assert rv.json["result"]["per_page"] == 2
