@@ -15,6 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 # isort:skip_file
+import re
 from superset.utils.core import DatasourceType
 from superset.utils import json
 import unittest
@@ -34,12 +35,13 @@ from sqlalchemy.engine.url import make_url
 from sqlalchemy.types import DateTime  # noqa: F401
 
 import tests.integration_tests.test_app  # noqa: F401
-from superset import app, db as metadata_db
+from flask import current_app
+from superset import db as metadata_db
 from superset.db_engine_specs.postgres import PostgresEngineSpec  # noqa: F401
 from superset.common.db_query_status import QueryStatus
 from superset.models.core import Database
 from superset.models.slice import Slice
-from superset.sql_parse import Table
+from superset.sql.parse import Table
 from superset.utils.database import get_example_database
 
 from .base_tests import SupersetTestCase
@@ -53,28 +55,31 @@ class TestDatabaseModel(SupersetTestCase):
     @unittest.skipUnless(
         SupersetTestCase.is_module_installed("requests"), "requests not installed"
     )
+    @unittest.skipUnless(
+        SupersetTestCase.is_module_installed("pyhive"), "pyhive not installed"
+    )
     def test_database_schema_presto(self):
         sqlalchemy_uri = "presto://presto.airbnb.io:8080/hive/default"
         model = Database(database_name="test_database", sqlalchemy_uri=sqlalchemy_uri)
 
         with model.get_sqla_engine() as engine:
             db = make_url(engine.url).database
-            self.assertEqual("hive/default", db)
+            assert "hive/default" == db
 
         with model.get_sqla_engine(schema="core_db") as engine:
             db = make_url(engine.url).database
-            self.assertEqual("hive/core_db", db)
+            assert "hive/core_db" == db
 
         sqlalchemy_uri = "presto://presto.airbnb.io:8080/hive"
         model = Database(database_name="test_database", sqlalchemy_uri=sqlalchemy_uri)
 
         with model.get_sqla_engine() as engine:
             db = make_url(engine.url).database
-            self.assertEqual("hive", db)
+            assert "hive" == db
 
         with model.get_sqla_engine(schema="core_db") as engine:
             db = make_url(engine.url).database
-            self.assertEqual("hive/core_db", db)
+            assert "hive/core_db" == db
 
     def test_database_schema_postgres(self):
         sqlalchemy_uri = "postgresql+psycopg2://postgres.airbnb.io:5439/prod"
@@ -82,11 +87,11 @@ class TestDatabaseModel(SupersetTestCase):
 
         with model.get_sqla_engine() as engine:
             db = make_url(engine.url).database
-            self.assertEqual("prod", db)
+            assert "prod" == db
 
         with model.get_sqla_engine(schema="foo") as engine:
             db = make_url(engine.url).database
-            self.assertEqual("prod", db)
+            assert "prod" == db
 
     @unittest.skipUnless(
         SupersetTestCase.is_module_installed("thrift"), "thrift not installed"
@@ -100,14 +105,14 @@ class TestDatabaseModel(SupersetTestCase):
 
         with model.get_sqla_engine() as engine:
             db = make_url(engine.url).database
-            self.assertEqual("default", db)
+            assert "default" == db
 
         with model.get_sqla_engine(schema="core_db") as engine:
             db = make_url(engine.url).database
-            self.assertEqual("core_db", db)
+            assert "core_db" == db
 
     @unittest.skipUnless(
-        SupersetTestCase.is_module_installed("MySQLdb"), "mysqlclient not installed"
+        SupersetTestCase.is_module_installed("mysqlclient"), "mysqlclient not installed"
     )
     def test_database_schema_mysql(self):
         sqlalchemy_uri = "mysql://root@localhost/superset"
@@ -115,14 +120,14 @@ class TestDatabaseModel(SupersetTestCase):
 
         with model.get_sqla_engine() as engine:
             db = make_url(engine.url).database
-            self.assertEqual("superset", db)
+            assert "superset" == db
 
         with model.get_sqla_engine(schema="staging") as engine:
             db = make_url(engine.url).database
-            self.assertEqual("staging", db)
+            assert "staging" == db
 
     @unittest.skipUnless(
-        SupersetTestCase.is_module_installed("MySQLdb"), "mysqlclient not installed"
+        SupersetTestCase.is_module_installed("mysqlclient"), "mysqlclient not installed"
     )
     def test_database_impersonate_user(self):
         uri = "mysql://root@localhost"
@@ -133,14 +138,17 @@ class TestDatabaseModel(SupersetTestCase):
             model.impersonate_user = True
             with model.get_sqla_engine() as engine:
                 username = make_url(engine.url).username
-                self.assertEqual(example_user.username, username)
+                assert example_user.username == username
 
             model.impersonate_user = False
             with model.get_sqla_engine() as engine:
                 username = make_url(engine.url).username
-                self.assertNotEqual(example_user.username, username)
+                assert example_user.username != username
 
     @mock.patch("superset.models.core.create_engine")
+    @unittest.skipUnless(
+        SupersetTestCase.is_module_installed("pyhive"), "pyhive not installed"
+    )
     def test_impersonate_user_presto(self, mocked_create_engine):
         uri = "presto://localhost"
         principal_user = security_manager.find_user(username="gamma")
@@ -189,7 +197,7 @@ class TestDatabaseModel(SupersetTestCase):
             }
 
     @unittest.skipUnless(
-        SupersetTestCase.is_module_installed("MySQLdb"), "mysqlclient not installed"
+        SupersetTestCase.is_module_installed("mysqlclient"), "mysqlclient not installed"
     )
     @mock.patch("superset.models.core.create_engine")
     def test_adjust_engine_params_mysql(self, mocked_create_engine):
@@ -244,6 +252,12 @@ class TestDatabaseModel(SupersetTestCase):
             assert call_args[1]["connect_args"]["user"] == "gamma"
 
     @mock.patch("superset.models.core.create_engine")
+    @unittest.skipUnless(
+        SupersetTestCase.is_module_installed("pyhive"), "pyhive not installed"
+    )
+    @unittest.skipUnless(
+        SupersetTestCase.is_module_installed("thrift"), "thrift not installed"
+    )
     def test_impersonate_user_hive(self, mocked_create_engine):
         uri = "hive://localhost"
         principal_user = security_manager.find_user(username="gamma")
@@ -292,6 +306,9 @@ class TestDatabaseModel(SupersetTestCase):
             }
 
     @pytest.mark.usefixtures("load_energy_table_with_slice")
+    @unittest.skipUnless(
+        SupersetTestCase.is_module_installed("pyhive"), "pyhive not installed"
+    )
     def test_select_star(self):
         db = get_example_database()
         table_name = "energy_usage"
@@ -306,12 +323,12 @@ class TestDatabaseModel(SupersetTestCase):
         # TODO(bkyryliuk): unify sql generation
         if db.backend == "presto":
             assert (
-                'SELECT\n  "source" AS "source",\n  "target" AS "target",\n  "value" AS "value"\nFROM "energy_usage"\nLIMIT 100'
+                'SELECT\n  "source" AS "source",\n  "target" AS "target",\n  "value" AS "value"\nFROM "energy_usage"\nLIMIT 100'  # noqa: E501
                 in sql
             )
         elif db.backend == "hive":
             assert (
-                "SELECT\n  `source`,\n  `target`,\n  `value`\nFROM `energy_usage`\nLIMIT 100"
+                "SELECT\n  `source`,\n  `target`,\n  `value`\nFROM `energy_usage`\nLIMIT 100"  # noqa: E501
                 in sql
             )
         else:
@@ -344,20 +361,20 @@ class TestDatabaseModel(SupersetTestCase):
 
         if main_db.backend == "mysql":
             df = main_db.get_df("SELECT 1", None, None)
-            self.assertEqual(df.iat[0, 0], 1)
+            assert df.iat[0, 0] == 1
 
             df = main_db.get_df("SELECT 1;", None, None)
-            self.assertEqual(df.iat[0, 0], 1)
+            assert df.iat[0, 0] == 1
 
     def test_multi_statement(self):
         main_db = get_example_database()
 
         if main_db.backend == "mysql":
             df = main_db.get_df("USE superset; SELECT 1", None, None)
-            self.assertEqual(df.iat[0, 0], 1)
+            assert df.iat[0, 0] == 1
 
             df = main_db.get_df("USE superset; SELECT ';';", None, None)
-            self.assertEqual(df.iat[0, 0], ";")
+            assert df.iat[0, 0] == ";"
 
     @mock.patch("superset.models.core.create_engine")
     def test_get_sqla_engine(self, mocked_create_engine):
@@ -369,7 +386,7 @@ class TestDatabaseModel(SupersetTestCase):
             return_value={Exception: SupersetException}
         )
         mocked_create_engine.side_effect = Exception()
-        with self.assertRaises(SupersetException):
+        with self.assertRaises(SupersetException):  # noqa: PT027
             model._get_sqla_engine()
 
 
@@ -404,20 +421,20 @@ class TestSqlaTableModel(SupersetTestCase):
         sqla_literal = ds_col.get_timestamp_expression(None)
         compiled = f"{sqla_literal.compile()}"
         if tbl.database.backend == "mysql":
-            self.assertEqual(compiled, "from_unixtime(ds)")
+            assert compiled == "from_unixtime(ds)"
 
         ds_col.python_date_format = "epoch_s"
         sqla_literal = ds_col.get_timestamp_expression("P1D")
         compiled = f"{sqla_literal.compile()}"
         if tbl.database.backend == "mysql":
-            self.assertEqual(compiled, "DATE(from_unixtime(ds))")
+            assert compiled == "DATE(from_unixtime(ds))"
 
         prev_ds_expr = ds_col.expression
         ds_col.expression = "DATE_ADD(ds, 1)"
         sqla_literal = ds_col.get_timestamp_expression("P1D")
         compiled = f"{sqla_literal.compile()}"
         if tbl.database.backend == "mysql":
-            self.assertEqual(compiled, "DATE(from_unixtime(DATE_ADD(ds, 1)))")
+            assert compiled == "DATE(from_unixtime(DATE_ADD(ds, 1)))"
         ds_col.expression = prev_ds_expr
 
     def query_with_expr_helper(self, is_timeseries, inner_join=True):
@@ -431,11 +448,18 @@ class TestSqlaTableModel(SupersetTestCase):
             return None
         old_inner_join = spec.allows_joins
         spec.allows_joins = inner_join
-        arbitrary_gby = "state || gender || '_test'"
-        arbitrary_metric = dict(
+
+        # Use database-specific string concatenation syntax
+        arbitrary_gby = (
+            "CONCAT(state, gender, '_test')"
+            if get_example_database().backend == "mysql"
+            else "state || gender || '_test'"
+        )
+
+        arbitrary_metric = dict(  # noqa: C408
             label="arbitrary", expressionType="SQL", sqlExpression="SUM(num_boys)"
         )
-        query_obj = dict(
+        query_obj = dict(  # noqa: C408
             groupby=[arbitrary_gby, "name"],
             metrics=[arbitrary_metric],
             filter=[],
@@ -444,20 +468,20 @@ class TestSqlaTableModel(SupersetTestCase):
             granularity="ds",
             from_dttm=None,
             to_dttm=None,
-            extras=dict(time_grain_sqla="P1Y"),
+            extras=dict(time_grain_sqla="P1Y"),  # noqa: C408
             series_limit=15 if inner_join and is_timeseries else None,
         )
         qr = tbl.query(query_obj)
-        self.assertEqual(qr.status, QueryStatus.SUCCESS)
+        assert qr.status == QueryStatus.SUCCESS
         sql = qr.query
-        self.assertIn(arbitrary_gby, sql)
-        self.assertIn("name", sql)
+        assert arbitrary_gby in sql
+        assert "name" in sql
         if inner_join and is_timeseries:
-            self.assertIn("JOIN", sql.upper())
+            assert "JOIN" in sql.upper()
         else:
-            self.assertNotIn("JOIN", sql.upper())
+            assert "JOIN" not in sql.upper()
         spec.allows_joins = old_inner_join
-        self.assertFalse(qr.df.empty)
+        assert not qr.df.empty
         return qr.df
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
@@ -475,7 +499,7 @@ class TestSqlaTableModel(SupersetTestCase):
         name_list1 = canonicalize_df(df1).name.values.tolist()
         df2 = self.query_with_expr_helper(is_timeseries=True, inner_join=False)
         name_list2 = canonicalize_df(df1).name.values.tolist()
-        self.assertFalse(df2.empty)
+        assert not df2.empty
 
         assert name_list2 == name_list1
 
@@ -486,7 +510,7 @@ class TestSqlaTableModel(SupersetTestCase):
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_sql_mutator(self):
         tbl = self.get_table(name="birth_names")
-        query_obj = dict(
+        query_obj = dict(  # noqa: C408
             groupby=[],
             metrics=None,
             filter=[],
@@ -498,21 +522,21 @@ class TestSqlaTableModel(SupersetTestCase):
             extras={},
         )
         sql = tbl.get_query_str(query_obj)
-        self.assertNotIn("-- COMMENT", sql)
+        assert "-- COMMENT" not in sql
 
         def mutator(*args, **kwargs):
             return "-- COMMENT\n" + args[0]
 
-        app.config["SQL_QUERY_MUTATOR"] = mutator
+        current_app.config["SQL_QUERY_MUTATOR"] = mutator
         sql = tbl.get_query_str(query_obj)
-        self.assertIn("-- COMMENT", sql)
+        assert "-- COMMENT" in sql
 
-        app.config["SQL_QUERY_MUTATOR"] = None
+        current_app.config["SQL_QUERY_MUTATOR"] = None
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_sql_mutator_different_params(self):
         tbl = self.get_table(name="birth_names")
-        query_obj = dict(
+        query_obj = dict(  # noqa: C408
             groupby=[],
             metrics=None,
             filter=[],
@@ -524,22 +548,22 @@ class TestSqlaTableModel(SupersetTestCase):
             extras={},
         )
         sql = tbl.get_query_str(query_obj)
-        self.assertNotIn("-- COMMENT", sql)
+        assert "-- COMMENT" not in sql
 
         def mutator(sql, database=None, **kwargs):
             return "-- COMMENT\n--" + "\n" + str(database) + "\n" + sql
 
-        app.config["SQL_QUERY_MUTATOR"] = mutator
+        current_app.config["SQL_QUERY_MUTATOR"] = mutator
         mutated_sql = tbl.get_query_str(query_obj)
-        self.assertIn("-- COMMENT", mutated_sql)
-        self.assertIn(tbl.database.name, mutated_sql)
+        assert "-- COMMENT" in mutated_sql
+        assert tbl.database.name in mutated_sql
 
-        app.config["SQL_QUERY_MUTATOR"] = None
+        current_app.config["SQL_QUERY_MUTATOR"] = None
 
     def test_query_with_non_existent_metrics(self):
         tbl = self.get_table(name="birth_names")
 
-        query_obj = dict(
+        query_obj = dict(  # noqa: C408
             groupby=[],
             metrics=["invalid"],
             filter=[],
@@ -551,14 +575,14 @@ class TestSqlaTableModel(SupersetTestCase):
             extras={},
         )
 
-        with self.assertRaises(Exception) as context:
+        with self.assertRaises(Exception) as context:  # noqa: PT027
             tbl.get_query_str(query_obj)
 
-        self.assertTrue("Metric 'invalid' does not exist", context.exception)
+        assert "Metric 'invalid' does not exist", context.exception
 
     def test_query_label_without_group_by(self):
         tbl = self.get_table(name="birth_names")
-        query_obj = dict(
+        query_obj = dict(  # noqa: C408
             groupby=[],
             columns=[
                 "gender",
@@ -577,7 +601,7 @@ class TestSqlaTableModel(SupersetTestCase):
         )
 
         sql = tbl.get_query_str(query_obj)
-        self.assertRegex(sql, r'name AS ["`]?Given Name["`]?')
+        assert re.search('name AS ["`]?Given Name["`]?', sql)  # noqa: F821
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_data_for_slices_with_no_query_context(self):
