@@ -23,7 +23,7 @@ import pytest
 from flask import g
 import prison
 
-from superset import db, security_manager, app  # noqa: F401
+from superset import db, security_manager
 from superset.connectors.sqla.models import RowLevelSecurityFilter, SqlaTable
 from superset.security.guest_token import (
     GuestTokenResourceType,
@@ -33,7 +33,6 @@ from superset.utils import json
 from flask_babel import lazy_gettext as _  # noqa: F401
 from flask_appbuilder.models.sqla import filters
 from tests.integration_tests.base_tests import SupersetTestCase
-from tests.integration_tests.conftest import with_config  # noqa: F401
 from tests.integration_tests.constants import ADMIN_USERNAME
 from tests.integration_tests.fixtures.birth_names_dashboard import (
     load_birth_names_dashboard_with_slices,  # noqa: F401
@@ -56,7 +55,7 @@ class TestRowLevelSecurity(SupersetTestCase):
     """
 
     rls_entry = None
-    query_obj: dict[str, Any] = dict(
+    query_obj: dict[str, Any] = dict(  # noqa: C408
         groupby=[],
         metrics=None,
         filter=[],
@@ -153,7 +152,7 @@ class TestRowLevelSecurity(SupersetTestCase):
         db.session.delete(self.get_user("NoRlsRoleUser"))
         db.session.commit()
 
-    @pytest.fixture()
+    @pytest.fixture
     def create_dataset(self):
         with self.create_app().app_context():
             dataset = SqlaTable(database_id=1, schema=None, table_name="table1")
@@ -188,7 +187,7 @@ class TestRowLevelSecurity(SupersetTestCase):
                 "clause": "client_id=1",
             },
         )
-        self.assertEqual(rv.status_code, 201)
+        assert rv.status_code == 201
         rls1 = (
             db.session.query(RowLevelSecurityFilter).filter_by(name="rls1")
         ).one_or_none()
@@ -214,7 +213,7 @@ class TestRowLevelSecurity(SupersetTestCase):
                 "clause": "client_id=1",
             },
         )
-        self.assertEqual(rv.status_code, 422)
+        assert rv.status_code == 422
 
     @pytest.mark.usefixtures("create_dataset")
     def test_model_view_rls_add_tables_required(self):
@@ -231,7 +230,7 @@ class TestRowLevelSecurity(SupersetTestCase):
                 "clause": "client_id=1",
             },
         )
-        self.assertEqual(rv.status_code, 400)
+        assert rv.status_code == 400
         data = json.loads(rv.data.decode("utf-8"))
         assert data["message"] == {"tables": ["Shorter than minimum length 1."]}
 
@@ -268,7 +267,7 @@ class TestRowLevelSecurity(SupersetTestCase):
         # establish that the filters are grouped together correctly with
         # ANDs, ORs and parens in the correct place
         assert (
-            "WHERE ((name like 'A%' or name like 'B%') OR (name like 'Q%')) AND (gender = 'boy');"
+            "WHERE ((name like 'A%' or name like 'B%') OR (name like 'Q%')) AND (gender = 'boy');"  # noqa: E501
             in sql
         )
 
@@ -312,6 +311,105 @@ class TestRowLevelSecurity(SupersetTestCase):
             "gender = 'boy'-gender",
         ]
 
+    @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
+    def test_rls_filter_applies_to_virtual_dataset(self):
+        """
+        Test that RLS filters from underlying tables are applied to virtual
+        datasets.
+        """
+        # Get the physical birth_names table which has RLS filters
+        physical_table = self.get_table(name="birth_names")
+
+        # Create a virtual dataset that queries the birth_names table
+        virtual_dataset = SqlaTable(
+            table_name="virtual_birth_names",
+            database=physical_table.database,
+            schema=physical_table.schema,
+            sql="SELECT * FROM birth_names",
+        )
+        db.session.add(virtual_dataset)
+        db.session.commit()
+
+        try:
+            # Test as gamma user who has RLS filters
+            g.user = self.get_user(username="gamma")
+
+            # Get the SQL query for the virtual dataset
+            sql = virtual_dataset.get_query_str(self.query_obj)
+
+            # Verify that RLS filters from the physical table are applied
+            # Gamma user should have the name filters (A%, B%, Q%) and gender filter
+            # Note: SQL uses uppercase LIKE and %% escaping
+            sql_lower = sql.lower()
+            assert "name like 'a%" in sql_lower or "name like 'q%" in sql_lower, (
+                f"RLS name filters not found in virtual dataset query: {sql}"
+            )
+            assert "gender = 'boy'" in sql_lower, (
+                f"RLS gender filter not found in virtual dataset query: {sql}"
+            )
+
+            # Test as admin user who has no RLS filters
+            g.user = self.get_user(username="admin")
+            sql = virtual_dataset.get_query_str(self.query_obj)
+
+            # Admin should not have RLS filters applied
+            assert not self.NAMES_A_REGEX.search(sql)
+            assert not self.NAMES_B_REGEX.search(sql)
+            assert not self.NAMES_Q_REGEX.search(sql)
+            assert not self.BASE_FILTER_REGEX.search(sql)
+
+        finally:
+            # Cleanup
+            db.session.delete(virtual_dataset)
+            db.session.commit()
+
+    @pytest.mark.usefixtures(
+        "load_birth_names_dashboard_with_slices", "load_energy_table_with_slice"
+    )
+    def test_rls_filter_applies_to_virtual_dataset_with_join(self):
+        """
+        Test that RLS filters are applied when virtual dataset joins
+        multiple tables.
+        """
+        # Get the physical tables
+        birth_names_table = self.get_table(name="birth_names")
+        self.get_table(name="energy_usage")  # Load the table for the test
+
+        # Create a virtual dataset with a JOIN query
+        virtual_dataset = SqlaTable(
+            table_name="virtual_joined",
+            database=birth_names_table.database,
+            schema=birth_names_table.schema,
+            sql="SELECT b.name, e.value FROM birth_names b JOIN energy_usage e ON 1=1",
+        )
+        db.session.add(virtual_dataset)
+        db.session.commit()
+
+        try:
+            # Test as gamma user who has RLS filters on both tables
+            g.user = self.get_user(username="gamma")
+
+            # Get the SQL query for the virtual dataset
+            sql = virtual_dataset.get_query_str(self.query_obj)
+
+            # Verify that RLS filters from both physical tables are applied
+            # birth_names filters
+            sql_lower = sql.lower()
+            assert "name like 'a%" in sql_lower or "name like 'q%" in sql_lower, (
+                f"birth_names RLS filters not found: {sql}"
+            )
+            assert "gender = 'boy'" in sql_lower, (
+                f"birth_names gender filter not found: {sql}"
+            )
+
+            # energy_usage filter
+            assert "value > 1" in sql_lower, f"energy_usage RLS filter not found: {sql}"
+
+        finally:
+            # Cleanup
+            db.session.delete(virtual_dataset)
+            db.session.commit()
+
 
 class TestRowLevelSecurityCreateAPI(SupersetTestCase):
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
@@ -326,8 +424,8 @@ class TestRowLevelSecurityCreateAPI(SupersetTestCase):
         }
         rv = self.client.post("/api/v1/rowlevelsecurity/", json=payload)
         status_code, data = rv.status_code, json.loads(rv.data.decode("utf-8"))
-        self.assertEqual(status_code, 422)
-        self.assertEqual(data["message"], "[l'Some roles do not exist']")
+        assert status_code == 422
+        assert data["message"] == "[l'Some roles do not exist']"
 
     def test_invalid_table_failure(self):
         self.login(ADMIN_USERNAME)
@@ -340,8 +438,8 @@ class TestRowLevelSecurityCreateAPI(SupersetTestCase):
         }
         rv = self.client.post("/api/v1/rowlevelsecurity/", json=payload)
         status_code, data = rv.status_code, json.loads(rv.data.decode("utf-8"))
-        self.assertEqual(status_code, 422)
-        self.assertEqual(data["message"], "[l'Datasource does not exist']")
+        assert status_code == 422
+        assert data["message"] == "[l'Datasource does not exist']"
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_post_success(self):
@@ -357,7 +455,7 @@ class TestRowLevelSecurityCreateAPI(SupersetTestCase):
         rv = self.client.post("/api/v1/rowlevelsecurity/", json=payload)
         status_code, data = rv.status_code, json.loads(rv.data.decode("utf-8"))
 
-        self.assertEqual(status_code, 201)
+        assert status_code == 201
 
         rls = (
             db.session.query(RowLevelSecurityFilter)
@@ -366,11 +464,11 @@ class TestRowLevelSecurityCreateAPI(SupersetTestCase):
         )
 
         assert rls
-        self.assertEqual(rls.name, "rls 1")
-        self.assertEqual(rls.clause, "1=1")
-        self.assertEqual(rls.filter_type, "Base")
-        self.assertEqual(rls.tables[0].id, table.id)
-        self.assertEqual(rls.roles[0].id, 1)
+        assert rls.name == "rls 1"
+        assert rls.clause == "1=1"
+        assert rls.filter_type == "Base"
+        assert rls.tables[0].id == table.id
+        assert rls.roles[0].id == 1
 
         db.session.delete(rls)
         db.session.commit()
@@ -388,8 +486,8 @@ class TestRowLevelSecurityUpdateAPI(SupersetTestCase):
         }
         rv = self.client.put("/api/v1/rowlevelsecurity/99999999", json=payload)
         status_code, data = rv.status_code, json.loads(rv.data.decode("utf-8"))
-        self.assertEqual(status_code, 404)
-        self.assertEqual(data["message"], "Not found")
+        assert status_code == 404
+        assert data["message"] == "Not found"
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_invalid_role_failure(self):
@@ -410,8 +508,8 @@ class TestRowLevelSecurityUpdateAPI(SupersetTestCase):
         }
         rv = self.client.put(f"/api/v1/rowlevelsecurity/{rls.id}", json=payload)
         status_code, data = rv.status_code, json.loads(rv.data.decode("utf-8"))
-        self.assertEqual(status_code, 422)
-        self.assertEqual(data["message"], "[l'Some roles do not exist']")
+        assert status_code == 422
+        assert data["message"] == "[l'Some roles do not exist']"
 
         db.session.delete(rls)
         db.session.commit()
@@ -439,8 +537,8 @@ class TestRowLevelSecurityUpdateAPI(SupersetTestCase):
         }
         rv = self.client.put(f"/api/v1/rowlevelsecurity/{rls.id}", json=payload)
         status_code, data = rv.status_code, json.loads(rv.data.decode("utf-8"))
-        self.assertEqual(status_code, 422)
-        self.assertEqual(data["message"], "[l'Datasource does not exist']")
+        assert status_code == 422
+        assert data["message"] == "[l'Datasource does not exist']"
 
         db.session.delete(rls)
         db.session.commit()
@@ -472,7 +570,7 @@ class TestRowLevelSecurityUpdateAPI(SupersetTestCase):
         rv = self.client.put(f"/api/v1/rowlevelsecurity/{rls.id}", json=payload)
         status_code, _data = rv.status_code, json.loads(rv.data.decode("utf-8"))  # noqa: F841
 
-        self.assertEqual(status_code, 201)
+        assert status_code == 200
 
         rls = (
             db.session.query(RowLevelSecurityFilter)
@@ -480,11 +578,11 @@ class TestRowLevelSecurityUpdateAPI(SupersetTestCase):
             .one_or_none()
         )
 
-        self.assertEqual(rls.name, "rls put success")
-        self.assertEqual(rls.clause, "2=2")
-        self.assertEqual(rls.filter_type, "Base")
-        self.assertEqual(rls.tables[0].id, tables[1].id)
-        self.assertEqual(rls.roles[0].id, roles[1].id)
+        assert rls.name == "rls put success"
+        assert rls.clause == "2=2"
+        assert rls.filter_type == "Base"
+        assert rls.tables[0].id == tables[1].id
+        assert rls.roles[0].id == roles[1].id
 
         db.session.delete(rls)
         db.session.commit()
@@ -498,8 +596,8 @@ class TestRowLevelSecurityDeleteAPI(SupersetTestCase):
         rv = self.client.delete(f"/api/v1/rowlevelsecurity/?q={ids_to_delete}")
         status_code, data = rv.status_code, json.loads(rv.data.decode("utf-8"))
 
-        self.assertEqual(status_code, 404)
-        self.assertEqual(data["message"], "Not found")
+        assert status_code == 404
+        assert data["message"] == "Not found"
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     @pytest.mark.usefixtures("load_energy_table_with_slice")
@@ -530,8 +628,8 @@ class TestRowLevelSecurityDeleteAPI(SupersetTestCase):
         rv = self.client.delete(f"/api/v1/rowlevelsecurity/?q={ids_to_delete}")
         status_code, data = rv.status_code, json.loads(rv.data.decode("utf-8"))
 
-        self.assertEqual(status_code, 200)
-        self.assertEqual(data["message"], "Deleted 2 rules")
+        assert status_code == 200
+        assert data["message"] == "Deleted 2 rules"
 
 
 class TestRowLevelSecurityWithRelatedAPI(SupersetTestCase):
@@ -543,7 +641,7 @@ class TestRowLevelSecurityWithRelatedAPI(SupersetTestCase):
         params = prison.dumps({"page": 0, "page_size": 100})
 
         rv = self.client.get(f"/api/v1/rowlevelsecurity/related/tables?q={params}")
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         data = json.loads(rv.data.decode("utf-8"))
         result = data["result"]
 
@@ -556,12 +654,36 @@ class TestRowLevelSecurityWithRelatedAPI(SupersetTestCase):
         assert len(result) == len(db_tables)
         assert db_table_names == received_tables
 
+    def test_rls_tables_related_api_with_filter_matching_birth(self):
+        self.login(ADMIN_USERNAME)
+        # Test with filter that should match 'birth_names'
+        params = prison.dumps({"filter": "birth", "page": 0, "page_size": 100})
+        rv = self.client.get(f"/api/v1/rowlevelsecurity/related/tables?q={params}")
+        assert rv.status_code == 200
+        data = json.loads(rv.data.decode("utf-8"))
+        result = data["result"]
+        received_tables = {table["text"] for table in result}
+        # Should only return tables with 'birth' in the name
+        assert all("birth" in table_name.lower() for table_name in received_tables)
+        assert len(result) >= 1  # At least birth_names should be returned
+
+    def test_rls_tables_related_api_with_filter_no_matches(self):
+        self.login(ADMIN_USERNAME)
+        # Test with filter that should match nothing
+        params = prison.dumps({"filter": "nonexistent", "page": 0, "page_size": 100})
+        rv = self.client.get(f"/api/v1/rowlevelsecurity/related/tables?q={params}")
+        assert rv.status_code == 200
+        data = json.loads(rv.data.decode("utf-8"))
+        result = data["result"]
+        assert len(result) == 0
+        assert data["count"] == 0
+
     def test_rls_roles_related_api(self):
         self.login(ADMIN_USERNAME)
         params = prison.dumps({"page": 0, "page_size": 100})
 
         rv = self.client.get(f"/api/v1/rowlevelsecurity/related/roles?q={params}")
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         data = json.loads(rv.data.decode("utf-8"))
         result = data["result"]
 
@@ -584,7 +706,7 @@ class TestRowLevelSecurityWithRelatedAPI(SupersetTestCase):
         params = prison.dumps({"page": 0, "page_size": 10})
 
         rv = self.client.get(f"/api/v1/rowlevelsecurity/related/tables?q={params}")
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         data = json.loads(rv.data.decode("utf-8"))
         result = data["result"]
         received_tables = {table["text"].split(".")[-1] for table in result}
@@ -602,15 +724,16 @@ class TestRowLevelSecurityWithRelatedAPI(SupersetTestCase):
         def _base_filter(query):
             return query.filter_by(name="Alpha")
 
-        with mock.patch.dict(
-            "superset.views.filters.current_app.config",
-            {"EXTRA_RELATED_QUERY_FILTERS": {"role": _base_filter}},
-        ):
+        original_conf = self.app.config.get("EXTRA_RELATED_QUERY_FILTERS", {}).copy()
+        try:
+            self.app.config["EXTRA_RELATED_QUERY_FILTERS"] = {"role": _base_filter}
             rv = self.client.get("/api/v1/rowlevelsecurity/related/roles")  # noqa: F541
             assert rv.status_code == 200
             response = json.loads(rv.data.decode("utf-8"))
             response_roles = [result["text"] for result in response["result"]]
             assert response_roles == ["Alpha"]
+        finally:
+            self.app.config["EXTRA_RELATED_QUERY_FILTERS"] = original_conf
 
 
 RLS_ALICE_REGEX = re.compile(r"name = 'Alice'")
@@ -622,7 +745,7 @@ RLS_GENDER_REGEX = re.compile(r"AND \([\s\n]*gender = 'girl'[\s\n]*\)")
     EMBEDDED_SUPERSET=True,
 )
 class GuestTokenRowLevelSecurityTests(SupersetTestCase):
-    query_obj: dict[str, Any] = dict(
+    query_obj: dict[str, Any] = dict(  # noqa: C408
         groupby=[],
         metrics=None,
         filter=[],
@@ -664,7 +787,7 @@ class GuestTokenRowLevelSecurityTests(SupersetTestCase):
         tbl = self.get_table(name="birth_names")
         sql = tbl.get_query_str(self.query_obj)
 
-        self.assertRegex(sql, RLS_ALICE_REGEX)
+        assert re.search(RLS_ALICE_REGEX, sql)
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_rls_filter_does_not_alter_unrelated_query(self):
@@ -679,7 +802,7 @@ class GuestTokenRowLevelSecurityTests(SupersetTestCase):
         tbl = self.get_table(name="birth_names")
         sql = tbl.get_query_str(self.query_obj)
 
-        self.assertNotRegex(sql, RLS_ALICE_REGEX)
+        assert not re.search(RLS_ALICE_REGEX, sql)
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_multiple_rls_filters_are_unionized(self):
@@ -695,8 +818,8 @@ class GuestTokenRowLevelSecurityTests(SupersetTestCase):
         tbl = self.get_table(name="birth_names")
         sql = tbl.get_query_str(self.query_obj)
 
-        self.assertRegex(sql, RLS_ALICE_REGEX)
-        self.assertRegex(sql, RLS_GENDER_REGEX)
+        assert re.search(RLS_ALICE_REGEX, sql)
+        assert re.search(RLS_GENDER_REGEX, sql)
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     @pytest.mark.usefixtures("load_energy_table_with_slice")
@@ -709,8 +832,8 @@ class GuestTokenRowLevelSecurityTests(SupersetTestCase):
         births_sql = births.get_query_str(self.query_obj)
         energy_sql = energy.get_query_str(self.query_obj)
 
-        self.assertRegex(births_sql, RLS_ALICE_REGEX)
-        self.assertRegex(energy_sql, RLS_ALICE_REGEX)
+        assert re.search(RLS_ALICE_REGEX, births_sql)
+        assert re.search(RLS_ALICE_REGEX, energy_sql)
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_dataset_id_can_be_string(self):
@@ -721,4 +844,4 @@ class GuestTokenRowLevelSecurityTests(SupersetTestCase):
         )
         sql = dataset.get_query_str(self.query_obj)
 
-        self.assertRegex(sql, RLS_ALICE_REGEX)
+        assert re.search(RLS_ALICE_REGEX, sql)
