@@ -31,16 +31,15 @@ from superset.db_engine_specs import BaseEngineSpec
 from superset.db_engine_specs.hive import HiveEngineSpec
 from superset.db_engine_specs.presto import PrestoEngineSpec
 from superset.errors import ErrorLevel, SupersetError, SupersetErrorType
-from superset.exceptions import SupersetErrorException
+from superset.exceptions import SupersetErrorException, SupersetInvalidCVASException
 from superset.models.sql_lab import Query
 from superset.result_set import SupersetResultSet
 from superset.sqllab.limiting_factor import LimitingFactor
+from superset.sql.parse import CTASMethod
 from superset.sql_lab import (
     cancel_query,
     execute_sql_statements,
-    apply_limit_if_exists,
 )
-from superset.sql_parse import CtasMethod
 from superset.utils.core import backend
 from superset.utils import json
 from superset.utils.json import datetime_to_epoch  # noqa: F401
@@ -89,7 +88,7 @@ class TestSqlLab(SupersetTestCase):
         self.login(ADMIN_USERNAME)
 
         data = self.run_sql("SELECT * FROM birth_names LIMIT 10", "1")
-        self.assertLess(0, len(data["data"]))
+        assert 0 < len(data["data"])
 
         data = self.run_sql("SELECT * FROM nonexistent_table", "2")
         if backend() == "presto":
@@ -103,11 +102,11 @@ class TestSqlLab(SupersetTestCase):
                 "issue_codes": [
                     {
                         "code": 1003,
-                        "message": "Issue 1003 - There is a syntax error in the SQL query. Perhaps there was a misspelling or a typo.",
+                        "message": "Issue 1003 - There is a syntax error in the SQL query. Perhaps there was a misspelling or a typo.",  # noqa: E501
                     },
                     {
                         "code": 1005,
-                        "message": "Issue 1005 - The table was deleted or renamed in the database.",
+                        "message": "Issue 1005 - The table was deleted or renamed in the database.",  # noqa: E501
                     },
                 ],
             }
@@ -121,7 +120,7 @@ class TestSqlLab(SupersetTestCase):
                 "issue_codes": [
                     {
                         "code": 1002,
-                        "message": "Issue 1002 - The database returned an unexpected error.",
+                        "message": "Issue 1002 - The database returned an unexpected error.",  # noqa: E501
                     }
                 ],
                 "engine_name": engine_name,
@@ -132,31 +131,13 @@ class TestSqlLab(SupersetTestCase):
         self.login(ADMIN_USERNAME)
 
         data = self.run_sql("DELETE FROM birth_names", "1")
-        assert data == {
-            "errors": [
-                {
-                    "message": (
-                        "This database does not allow for DDL/DML, and the query "
-                        "could not be parsed to confirm it is a read-only query. Please "
-                        "contact your administrator for more assistance."
-                    ),
-                    "error_type": SupersetErrorType.DML_NOT_ALLOWED_ERROR,
-                    "level": ErrorLevel.ERROR,
-                    "extra": {
-                        "issue_codes": [
-                            {
-                                "code": 1022,
-                                "message": "Issue 1022 - Database does not allow data manipulation.",
-                            }
-                        ]
-                    },
-                }
-            ]
-        }
+        assert (
+            data["errors"][0]["error_type"] == SupersetErrorType.DML_NOT_ALLOWED_ERROR
+        )
 
-    @parameterized.expand([CtasMethod.TABLE, CtasMethod.VIEW])
+    @parameterized.expand([CTASMethod.TABLE, CTASMethod.VIEW])
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
-    def test_sql_json_cta_dynamic_db(self, ctas_method):
+    def test_sql_json_cta_dynamic_db(self, ctas_method: CTASMethod) -> None:
         examples_db = get_example_database()
         if examples_db.backend == "sqlite":
             # sqlite doesn't support database creation
@@ -170,7 +151,7 @@ class TestSqlLab(SupersetTestCase):
             examples_db.allow_ctas = True  # enable cta
 
             self.login(ADMIN_USERNAME)
-            tmp_table_name = f"test_target_{ctas_method.lower()}"
+            tmp_table_name = f"test_target_{ctas_method.name.lower()}"
             self.run_sql(
                 "SELECT * FROM birth_names",
                 "1",
@@ -185,17 +166,19 @@ class TestSqlLab(SupersetTestCase):
             examples_db = get_example_database()
             with examples_db.get_sqla_engine() as engine:
                 data = engine.execute(
-                    f"SELECT * FROM admin_database.{tmp_table_name}"
+                    f"SELECT * FROM admin_database.{tmp_table_name}"  # noqa: S608
                 ).fetchall()
                 names_count = engine.execute(
-                    f"SELECT COUNT(*) FROM birth_names"  # noqa: F541
+                    f"SELECT COUNT(*) FROM birth_names"  # noqa: F541, S608
                 ).first()
-                self.assertEqual(
-                    names_count[0], len(data)
+                assert names_count[0] == len(
+                    data
                 )  # SQL_MAX_ROW not applied due to the SQLLAB_CTAS_NO_LIMIT set to True
 
                 # cleanup
-                engine.execute(f"DROP {ctas_method} admin_database.{tmp_table_name}")
+                engine.execute(
+                    f"DROP {ctas_method.name} admin_database.{tmp_table_name}"
+                )
                 examples_db.allow_ctas = old_allow_ctas
                 db.session.commit()
 
@@ -208,14 +191,14 @@ class TestSqlLab(SupersetTestCase):
         SELECT * FROM birth_names LIMIT 2;
         """
         data = self.run_sql(multi_sql, "2234")
-        self.assertLess(0, len(data["data"]))
+        assert 0 < len(data["data"])
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_explain(self):
         self.login(ADMIN_USERNAME)
 
         data = self.run_sql("EXPLAIN SELECT * FROM birth_names", "1")
-        self.assertLess(0, len(data["data"]))
+        assert 0 < len(data["data"])
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_sql_json_has_access(self):
@@ -231,21 +214,21 @@ class TestSqlLab(SupersetTestCase):
         data = self.run_sql(QUERY_1, "1", username="Gagarin")
         db.session.query(Query).delete()
         db.session.commit()
-        self.assertLess(0, len(data["data"]))
+        assert 0 < len(data["data"])
 
     def test_sqllab_has_access(self):
         for username in (ADMIN_USERNAME, GAMMA_SQLLAB_USERNAME):
             self.login(username)
             for endpoint in ("/sqllab/", "/sqllab/history/"):
                 resp = self.client.get(endpoint)
-                self.assertEqual(200, resp.status_code)
+                assert 200 == resp.status_code
 
     def test_sqllab_no_access(self):
         self.login(GAMMA_USERNAME)
         for endpoint in ("/sqllab/", "/sqllab/history/"):
             resp = self.client.get(endpoint)
             # Redirects to the main page
-            self.assertEqual(302, resp.status_code)
+            assert 302 == resp.status_code
 
     def test_sql_json_schema_access(self):
         examples_db = get_example_database()
@@ -275,21 +258,23 @@ class TestSqlLab(SupersetTestCase):
 
         with examples_db.get_sqla_engine() as engine:
             engine.execute(
-                f"CREATE TABLE IF NOT EXISTS {CTAS_SCHEMA_NAME}.test_table AS SELECT 1 as c1, 2 as c2"
+                f"CREATE TABLE IF NOT EXISTS {CTAS_SCHEMA_NAME}.test_table AS SELECT 1 as c1, 2 as c2"  # noqa: E501
             )
 
         data = self.run_sql(
-            f"SELECT * FROM {CTAS_SCHEMA_NAME}.test_table", "3", username="SchemaUser"
+            f"SELECT * FROM {CTAS_SCHEMA_NAME}.test_table",  # noqa: S608
+            "3",
+            username="SchemaUser",  # noqa: S608
         )
-        self.assertEqual(1, len(data["data"]))
+        assert 1 == len(data["data"])
 
         data = self.run_sql(
-            f"SELECT * FROM {CTAS_SCHEMA_NAME}.test_table",
+            f"SELECT * FROM {CTAS_SCHEMA_NAME}.test_table",  # noqa: S608
             "4",
             username="SchemaUser",
             schema=CTAS_SCHEMA_NAME,
         )
-        self.assertEqual(1, len(data["data"]))
+        assert 1 == len(data["data"])
 
         # postgres needs a schema as a part of the table name.
         if db_backend == "mysql":
@@ -299,7 +284,7 @@ class TestSqlLab(SupersetTestCase):
                 username="SchemaUser",
                 schema=CTAS_SCHEMA_NAME,
             )
-            self.assertEqual(1, len(data["data"]))
+            assert 1 == len(data["data"])
 
         db.session.query(Query).delete()
         with get_example_database().get_sqla_engine() as engine:
@@ -319,77 +304,75 @@ class TestSqlLab(SupersetTestCase):
         data = [["a", 4, 4.0]]
         results = SupersetResultSet(data, cols, BaseEngineSpec)
 
-        self.assertEqual(len(data), results.size)
-        self.assertEqual(len(cols), len(results.columns))
+        assert len(data) == results.size
+        assert len(cols) == len(results.columns)
 
     def test_pa_conversion_tuple(self):
         cols = ["string_col", "int_col", "list_col", "float_col"]
         data = [("Text", 111, [123], 1.0)]
         results = SupersetResultSet(data, cols, BaseEngineSpec)
 
-        self.assertEqual(len(data), results.size)
-        self.assertEqual(len(cols), len(results.columns))
+        assert len(data) == results.size
+        assert len(cols) == len(results.columns)
 
     def test_pa_conversion_dict(self):
         cols = ["string_col", "dict_col", "int_col"]
         data = [["a", {"c1": 1, "c2": 2, "c3": 3}, 4]]
         results = SupersetResultSet(data, cols, BaseEngineSpec)
 
-        self.assertEqual(len(data), results.size)
-        self.assertEqual(len(cols), len(results.columns))
+        assert len(data) == results.size
+        assert len(cols) == len(results.columns)
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_sql_limit(self):
         self.login(ADMIN_USERNAME)
         test_limit = 1
         data = self.run_sql("SELECT * FROM birth_names", client_id="sql_limit_1")
-        self.assertGreater(len(data["data"]), test_limit)
+        assert len(data["data"]) > test_limit
         data = self.run_sql(
             "SELECT * FROM birth_names", client_id="sql_limit_2", query_limit=test_limit
         )
-        self.assertEqual(len(data["data"]), test_limit)
+        assert len(data["data"]) == test_limit
 
         data = self.run_sql(
-            f"SELECT * FROM birth_names LIMIT {test_limit}",
+            f"SELECT * FROM birth_names LIMIT {test_limit}",  # noqa: S608
             client_id="sql_limit_3",
             query_limit=test_limit + 1,
         )
-        self.assertEqual(len(data["data"]), test_limit)
-        self.assertEqual(data["query"]["limitingFactor"], LimitingFactor.QUERY)
+        assert len(data["data"]) == test_limit
+        assert data["query"]["limitingFactor"] == LimitingFactor.QUERY
 
         data = self.run_sql(
-            f"SELECT * FROM birth_names LIMIT {test_limit + 1}",
+            f"SELECT * FROM birth_names LIMIT {test_limit + 1}",  # noqa: S608
             client_id="sql_limit_4",
             query_limit=test_limit,
         )
-        self.assertEqual(len(data["data"]), test_limit)
-        self.assertEqual(data["query"]["limitingFactor"], LimitingFactor.DROPDOWN)
+        assert len(data["data"]) == test_limit
+        assert data["query"]["limitingFactor"] == LimitingFactor.DROPDOWN
 
         data = self.run_sql(
-            f"SELECT * FROM birth_names LIMIT {test_limit}",
+            f"SELECT * FROM birth_names LIMIT {test_limit}",  # noqa: S608
             client_id="sql_limit_5",
             query_limit=test_limit,
         )
-        self.assertEqual(len(data["data"]), test_limit)
-        self.assertEqual(
-            data["query"]["limitingFactor"], LimitingFactor.QUERY_AND_DROPDOWN
-        )
+        assert len(data["data"]) == test_limit
+        assert data["query"]["limitingFactor"] == LimitingFactor.QUERY_AND_DROPDOWN
 
         data = self.run_sql(
             "SELECT * FROM birth_names",
             client_id="sql_limit_6",
             query_limit=10000,
         )
-        self.assertEqual(len(data["data"]), 1200)
-        self.assertEqual(data["query"]["limitingFactor"], LimitingFactor.NOT_LIMITED)
+        assert len(data["data"]) == 1200
+        assert data["query"]["limitingFactor"] == LimitingFactor.NOT_LIMITED
 
         data = self.run_sql(
             "SELECT * FROM birth_names",
             client_id="sql_limit_7",
             query_limit=1200,
         )
-        self.assertEqual(len(data["data"]), 1200)
-        self.assertEqual(data["query"]["limitingFactor"], LimitingFactor.NOT_LIMITED)
+        assert len(data["data"]) == 1200
+        assert data["query"]["limitingFactor"] == LimitingFactor.NOT_LIMITED
 
     @pytest.mark.usefixtures("load_birth_names_data")
     def test_query_api_filter(self) -> None:
@@ -404,7 +387,7 @@ class TestSqlLab(SupersetTestCase):
         data = self.get_json_resp(url)
         admin = security_manager.find_user("admin")
         gamma_sqllab = security_manager.find_user("gamma_sqllab")
-        self.assertEqual(3, len(data["result"]))
+        assert 3 == len(data["result"])
         user_queries = [
             result.get("user").get("first_name") for result in data["result"]
         ]
@@ -431,7 +414,7 @@ class TestSqlLab(SupersetTestCase):
         self.login(GAMMA_SQLLAB_USERNAME)
         url = "/api/v1/query/"
         data = self.get_json_resp(url)
-        self.assertEqual(3, len(data["result"]))
+        assert 3 == len(data["result"])
 
         # Remove all_query_access from gamma sqllab
         all_queries_view = security_manager.find_permission_view_menu(
@@ -491,10 +474,9 @@ class TestSqlLab(SupersetTestCase):
             ]
         }
         url = f"/api/v1/query/?q={prison.dumps(arguments)}"
-        self.assertEqual(
-            {"SELECT 1", "SELECT 2"},
-            {r.get("sql") for r in self.get_json_resp(url)["result"]},
-        )
+        assert {"SELECT 1", "SELECT 2"} == {
+            r.get("sql") for r in self.get_json_resp(url)["result"]
+        }
 
     @pytest.mark.usefixtures("load_birth_names_data")
     def test_query_admin_can_access_all_queries(self) -> None:
@@ -507,7 +489,7 @@ class TestSqlLab(SupersetTestCase):
 
         url = "/api/v1/query/"
         data = self.get_json_resp(url)
-        self.assertEqual(3, len(data["result"]))
+        assert 3 == len(data["result"])
 
     def test_api_database(self):
         self.login(ADMIN_USERNAME)
@@ -525,10 +507,9 @@ class TestSqlLab(SupersetTestCase):
         }
         url = f"api/v1/database/?q={prison.dumps(arguments)}"
 
-        self.assertEqual(
-            {"examples", "fake_db_100", "main"},
-            {r.get("database_name") for r in self.get_json_resp(url)["result"]},
-        )
+        assert {"examples", "fake_db_100", "main"} == {
+            r.get("database_name") for r in self.get_json_resp(url)["result"]
+        }
         self.delete_fake_db()
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
@@ -548,7 +529,7 @@ class TestSqlLab(SupersetTestCase):
         assert data["status"] == "success"
 
         data = self.run_sql(
-            "SELECT * FROM birth_names WHERE state = '{{ state }}' -- blabblah {{ extra1 }}\nLIMIT 10",
+            "SELECT * FROM birth_names WHERE state = '{{ state }}' -- blabblah {{ extra1 }}\nLIMIT 10",  # noqa: E501
             "3",
             template_params=json.dumps({"state": "CA", "extra1": "comment"}),
         )
@@ -564,7 +545,7 @@ class TestSqlLab(SupersetTestCase):
             "issue_codes": [
                 {
                     "code": 1006,
-                    "message": "Issue 1006 - One or more parameters specified in the query are missing.",
+                    "message": "Issue 1006 - One or more parameters specified in the query are missing.",  # noqa: E501
                 }
             ],
             "template_parameters": {"state": "CA"},
@@ -610,10 +591,10 @@ class TestSqlLab(SupersetTestCase):
 
     @mock.patch("superset.sql_lab.db")
     @mock.patch("superset.sql_lab.get_query")
-    @mock.patch("superset.sql_lab.execute_sql_statement")
+    @mock.patch("superset.sql_lab.execute_query")
     def test_execute_sql_statements(
         self,
-        mock_execute_sql_statement,
+        mock_execute_query,
         mock_get_query,
         mock_db,
     ):
@@ -625,7 +606,7 @@ class TestSqlLab(SupersetTestCase):
         """
         )
         mock_db = mock.MagicMock()  # noqa: F841
-        mock_query = mock.MagicMock()
+        mock_query = mock.MagicMock(select_as_cta=False)
         mock_query.database.allow_run_async = False
         mock_cursor = mock.MagicMock()
         mock_query.database.get_raw_connection().__enter__().cursor.return_value = (
@@ -643,30 +624,20 @@ class TestSqlLab(SupersetTestCase):
             expand_data=False,
             log_params=None,
         )
-        mock_execute_sql_statement.assert_has_calls(
+        mock_execute_query.assert_has_calls(
             [
-                mock.call(
-                    "-- comment\nSET @value = 42",
-                    mock_query,
-                    mock_cursor,
-                    None,
-                    False,
-                ),
-                mock.call(
-                    "SELECT /*+ hint */ @value AS foo",
-                    mock_query,
-                    mock_cursor,
-                    None,
-                    False,
-                ),
+                mock.call(mock_query, mock_cursor, None),
+                mock.call(mock_query, mock_cursor, None),
             ]
         )
 
     @mock.patch("superset.sql_lab.results_backend", None)
     @mock.patch("superset.sql_lab.get_query")
-    @mock.patch("superset.sql_lab.execute_sql_statement")
+    @mock.patch("superset.sql_lab.execute_query")
     def test_execute_sql_statements_no_results_backend(
-        self, mock_execute_sql_statement, mock_get_query
+        self,
+        mock_execute_query,
+        mock_get_query,
     ):
         sql = dedent(
             """
@@ -714,10 +685,10 @@ class TestSqlLab(SupersetTestCase):
 
     @mock.patch("superset.sql_lab.db")
     @mock.patch("superset.sql_lab.get_query")
-    @mock.patch("superset.sql_lab.execute_sql_statement")
+    @mock.patch("superset.sql_lab.execute_query")
     def test_execute_sql_statements_ctas(
         self,
-        mock_execute_sql_statement,
+        mock_execute_query,
         mock_get_query,
         mock_db,
     ):
@@ -729,7 +700,13 @@ class TestSqlLab(SupersetTestCase):
         """
         )
         mock_db = mock.MagicMock()  # noqa: F841
-        mock_query = mock.MagicMock()
+        mock_query = mock.MagicMock(
+            select_as_cta=True,
+            ctas_method=CTASMethod.TABLE.name,
+            tmp_table_name="table",
+            tmp_schema_name="schema",
+            catalog="catalog",
+        )
         mock_query.database.allow_run_async = False
         mock_cursor = mock.MagicMock()
         mock_query.database.get_raw_connection().__enter__().cursor.return_value = (
@@ -740,7 +717,7 @@ class TestSqlLab(SupersetTestCase):
 
         # set the query to CTAS
         mock_query.select_as_cta = True
-        mock_query.ctas_method = CtasMethod.TABLE
+        mock_query.ctas_method = CTASMethod.TABLE.name
 
         execute_sql_statements(
             query_id=1,
@@ -751,22 +728,10 @@ class TestSqlLab(SupersetTestCase):
             expand_data=False,
             log_params=None,
         )
-        mock_execute_sql_statement.assert_has_calls(
+        mock_execute_query.assert_has_calls(
             [
-                mock.call(
-                    "-- comment\nSET @value = 42",
-                    mock_query,
-                    mock_cursor,
-                    None,
-                    False,
-                ),
-                mock.call(
-                    "SELECT /*+ hint */ @value AS foo",
-                    mock_query,
-                    mock_cursor,
-                    None,
-                    True,  # apply_ctas
-                ),
+                mock.call(mock_query, mock_cursor, None),
+                mock.call(mock_query, mock_cursor, None),
             ]
         )
 
@@ -783,21 +748,21 @@ class TestSqlLab(SupersetTestCase):
                 log_params=None,
             )
         assert excinfo.value.error == SupersetError(
-            message="CTAS (create table as select) can only be run with a query where the last statement is a SELECT. Please make sure your query has a SELECT as its last statement. Then, try running your query again.",
+            message="CTAS (create table as select) can only be run with a query where the last statement is a SELECT. Please make sure your query has a SELECT as its last statement. Then, try running your query again.",  # noqa: E501
             error_type=SupersetErrorType.INVALID_CTAS_QUERY_ERROR,
             level=ErrorLevel.ERROR,
             extra={
                 "issue_codes": [
                     {
                         "code": 1023,
-                        "message": "Issue 1023 - The CTAS (create table as select) doesn't have a SELECT statement at the end. Please make sure your query has a SELECT as its last statement. Then, try running your query again.",
+                        "message": "Issue 1023 - The CTAS (create table as select) doesn't have a SELECT statement at the end. Please make sure your query has a SELECT as its last statement. Then, try running your query again.",  # noqa: E501
                     }
                 ]
             },
         )
 
         # try invalid CVAS
-        mock_query.ctas_method = CtasMethod.VIEW
+        mock_query.ctas_method = CTASMethod.VIEW.name
         sql = dedent(
             """
             -- comment
@@ -805,7 +770,7 @@ class TestSqlLab(SupersetTestCase):
             SELECT /*+ hint */ @value AS foo;
         """
         )
-        with pytest.raises(SupersetErrorException) as excinfo:
+        with pytest.raises(SupersetInvalidCVASException) as excinfo:
             execute_sql_statements(
                 query_id=1,
                 rendered_query=sql,
@@ -816,18 +781,18 @@ class TestSqlLab(SupersetTestCase):
                 log_params=None,
             )
         assert excinfo.value.error == SupersetError(
-            message="CVAS (create view as select) can only be run with a query with a single SELECT statement. Please make sure your query has only a SELECT statement. Then, try running your query again.",
+            message="CVAS (create view as select) can only be run with a query with a single SELECT statement. Please make sure your query has only a SELECT statement. Then, try running your query again.",  # noqa: E501
             error_type=SupersetErrorType.INVALID_CVAS_QUERY_ERROR,
             level=ErrorLevel.ERROR,
             extra={
                 "issue_codes": [
                     {
                         "code": 1024,
-                        "message": "Issue 1024 - CVAS (create view as select) query has more than one statement.",
+                        "message": "Issue 1024 - CVAS (create view as select) query has more than one statement.",  # noqa: E501
                     },
                     {
                         "code": 1025,
-                        "message": "Issue 1025 - CVAS (create view as select) query is not a SELECT statement.",
+                        "message": "Issue 1025 - CVAS (create view as select) query is not a SELECT statement.",  # noqa: E501
                     },
                 ]
             },
@@ -851,7 +816,7 @@ class TestSqlLab(SupersetTestCase):
             "errors": [
                 {
                     "message": (
-                        "The query was killed after 21600 seconds. It might be too complex, "
+                        "The query was killed after 21600 seconds. It might be too complex, "  # noqa: E501
                         "or the database might be under heavy load."
                     ),
                     "error_type": SupersetErrorType.SQLLAB_TIMEOUT_ERROR,
@@ -860,11 +825,11 @@ class TestSqlLab(SupersetTestCase):
                         "issue_codes": [
                             {
                                 "code": 1026,
-                                "message": "Issue 1026 - Query is too complex and takes too long to run.",
+                                "message": "Issue 1026 - Query is too complex and takes too long to run.",  # noqa: E501
                             },
                             {
                                 "code": 1027,
-                                "message": "Issue 1027 - The database is currently running too many queries.",
+                                "message": "Issue 1027 - The database is currently running too many queries.",  # noqa: E501
                             },
                         ]
                     },
@@ -872,29 +837,6 @@ class TestSqlLab(SupersetTestCase):
             ]
         }
 
-    def test_apply_limit_if_exists_when_incremented_limit_is_none(self):
-        sql = """
-                   SET @value = 42;
-                   SELECT @value AS foo;
-               """
-        database = get_example_database()
-        mock_query = mock.MagicMock()
-        mock_query.limit = 300
-        final_sql = apply_limit_if_exists(database, None, mock_query, sql)
-
-        assert final_sql == sql
-
-    def test_apply_limit_if_exists_when_increased_limit(self):
-        sql = """
-                   SET @value = 42;
-                   SELECT @value AS foo;
-               """
-        database = get_example_database()
-        mock_query = mock.MagicMock()
-        mock_query.limit = 300
-        final_sql = apply_limit_if_exists(database, 1000, mock_query, sql)
-        assert "LIMIT 1000" in final_sql
-
 
 @pytest.mark.parametrize("spec", [HiveEngineSpec, PrestoEngineSpec])
 def test_cancel_query_implicit(spec: BaseEngineSpec) -> None:
