@@ -14,33 +14,33 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-# isort:skip_file
 """Unit tests for Superset"""
 
-import prison
 from datetime import datetime
-
-from flask import g  # noqa: F401
-import pytest
-import prison  # noqa: F811
-from freezegun import freeze_time
-from sqlalchemy.sql import func
-from sqlalchemy import and_  # noqa: F401
-from superset.models.dashboard import Dashboard
-from superset.models.slice import Slice
-from superset.models.sql_lab import SavedQuery  # noqa: F401
-from superset.tags.models import user_favorite_tag_table  # noqa: F401
 from unittest.mock import patch
 from urllib import parse
 
+import prison
+import pytest
+from freezegun import freeze_time
+from markupsafe import Markup
+from sqlalchemy import and_
+from sqlalchemy.sql import func
 
-import tests.integration_tests.test_app  # noqa: F401
-from superset import db, security_manager  # noqa: F401
-from superset.common.db_query_status import QueryStatus  # noqa: F401
-from superset.models.core import Database  # noqa: F401
-from superset.utils.database import get_example_database, get_main_database  # noqa: F401
+from superset import db
+from superset.connectors.sqla.models import SqlaTable
+from superset.daos.tag import TagDAO
+from superset.models.dashboard import Dashboard
+from superset.models.slice import Slice
+from superset.tags.models import (
+    ObjectType,
+    Tag,
+    TaggedObject,
+    TagType,
+    user_favorite_tag_table,
+)
 from superset.utils import json
-from superset.tags.models import ObjectType, Tag, TagType, TaggedObject
+from tests.integration_tests.base_tests import SupersetTestCase
 from tests.integration_tests.constants import ADMIN_USERNAME, ALPHA_USERNAME
 from tests.integration_tests.fixtures.birth_names_dashboard import (
     load_birth_names_dashboard_with_slices,  # noqa: F401
@@ -50,10 +50,7 @@ from tests.integration_tests.fixtures.world_bank_dashboard import (
     load_world_bank_dashboard_with_slices,  # noqa: F401
     load_world_bank_data,  # noqa: F401
 )
-from tests.integration_tests.fixtures.tags import with_tagging_system_feature  # noqa: F401
-from tests.integration_tests.base_tests import SupersetTestCase
-from superset.daos.tag import TagDAO
-from superset.tags.models import ObjectType  # noqa: F811
+from tests.integration_tests.insert_chart_mixin import InsertChartMixin
 
 TAGS_FIXTURE_COUNT = 10
 
@@ -71,7 +68,7 @@ TAGS_LIST_COLUMNS = [
 ]
 
 
-class TestTagApi(SupersetTestCase):
+class TestTagApi(InsertChartMixin, SupersetTestCase):
     def insert_tag(
         self,
         name: str,
@@ -100,7 +97,7 @@ class TestTagApi(SupersetTestCase):
         db.session.commit()
         return tagged_object
 
-    @pytest.fixture()
+    @pytest.fixture
     def create_tags(self):
         with self.create_app().app_context():
             # clear tags table
@@ -135,7 +132,7 @@ class TestTagApi(SupersetTestCase):
             self.login(ADMIN_USERNAME)
             uri = f"api/v1/tag/{tag.id}"
             rv = self.client.get(uri)
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         expected_result = {
             "changed_by": None,
             "changed_on_delta_humanized": "now",
@@ -146,11 +143,51 @@ class TestTagApi(SupersetTestCase):
         }
         data = json.loads(rv.data.decode("utf-8"))
         for key, value in expected_result.items():
-            self.assertEqual(value, data["result"][key])
+            assert value == data["result"][key]
         # rollback changes
         db.session.delete(tag)
         db.session.commit()
 
+    def test_get_tag_user_fields(self):
+        """
+        Query API: Test get tag only returns first_name and last_name for
+        created_by and changed_by fields
+        """
+        self.login(ADMIN_USERNAME)
+        # Create tag via API to ensure created_by is set
+        uri = "api/v1/tag/"
+        rv = self.client.post(
+            uri,
+            json={"name": "test_user_fields_tag", "objects_to_tag": []},
+        )
+        assert rv.status_code == 201
+
+        # Get the created tag
+        tag = db.session.query(Tag).filter(Tag.name == "test_user_fields_tag").first()
+        assert tag is not None
+
+        # Fetch the tag via GET API
+        uri = f"api/v1/tag/{tag.id}"
+        rv = self.client.get(uri)
+        assert rv.status_code == 200
+
+        data = json.loads(rv.data.decode("utf-8"))
+        result = data["result"]
+
+        # Verify created_by only contains first_name and last_name
+        assert result["created_by"] is not None
+        assert set(result["created_by"].keys()) == {"first_name", "last_name"}
+        assert result["created_by"]["first_name"] is not None
+        assert result["created_by"]["last_name"] is not None
+
+        # Verify changed_by only contains first_name and last_name (or is None)
+        if result["changed_by"] is not None:
+            assert set(result["changed_by"].keys()) == {"first_name", "last_name"}
+
+        # Cleanup
+        db.session.delete(tag)
+        db.session.commit()
+
     def test_get_tag_not_found(self):
         """
         Query API: Test get query not found
@@ -160,7 +197,7 @@ class TestTagApi(SupersetTestCase):
         self.login(ADMIN_USERNAME)
         uri = f"api/v1/tag/{max_id + 1}"
         rv = self.client.get(uri)
-        self.assertEqual(rv.status_code, 404)
+        assert rv.status_code == 404
         # cleanup
         db.session.delete(tag)
         db.session.commit()
@@ -173,7 +210,7 @@ class TestTagApi(SupersetTestCase):
         self.login(ADMIN_USERNAME)
         uri = "api/v1/tag/"
         rv = self.client.get(uri)
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         data = json.loads(rv.data.decode("utf-8"))
         assert data["count"] == TAGS_FIXTURE_COUNT
         # check expected columns
@@ -211,7 +248,7 @@ class TestTagApi(SupersetTestCase):
         }
         uri = f"api/v1/tag/?{parse.urlencode({'q': prison.dumps(query)})}"
         rv = self.client.get(uri)
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         data = json.loads(rv.data.decode("utf-8"))
         assert data["count"] == 2
 
@@ -219,7 +256,7 @@ class TestTagApi(SupersetTestCase):
         query["filters"][0]["value"] = False
         uri = f"api/v1/tag/?{parse.urlencode({'q': prison.dumps(query)})}"
         rv = self.client.get(uri)
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         data = json.loads(rv.data.decode("utf-8"))
         assert data["count"] == 3
 
@@ -249,10 +286,10 @@ class TestTagApi(SupersetTestCase):
         data = {"properties": {"tags": example_tag_names}}
         rv = self.client.post(uri, json=data, follow_redirects=True)
         # successful request
-        self.assertEqual(rv.status_code, 201)
+        assert rv.status_code == 201
         # check that tags were created in database
         tags = db.session.query(Tag).filter(Tag.name.in_(example_tag_names))
-        self.assertEqual(tags.count(), 2)
+        assert tags.count() == 2
         # check that tagged objects were created
         tag_ids = [tags[0].id, tags[1].id]
         tagged_objects = db.session.query(TaggedObject).filter(
@@ -308,7 +345,7 @@ class TestTagApi(SupersetTestCase):
         uri = f"api/v1/tag/{dashboard_type.value}/{dashboard_id}/{tags.first().name}"
         rv = self.client.delete(uri, follow_redirects=True)
         # successful request
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         # ensure that tagged object no longer exists
         tagged_object = (
             db.session.query(TaggedObject)
@@ -358,14 +395,14 @@ class TestTagApi(SupersetTestCase):
             TaggedObject.object_id == dashboard_id,
             TaggedObject.object_type == dashboard_type.name,
         )
-        self.assertEqual(tagged_objects.count(), 2)
-        uri = f'api/v1/tag/get_objects/?tags={",".join(tag_names)}'
+        assert tagged_objects.count() == 2
+        uri = f"api/v1/tag/get_objects/?tags={','.join(tag_names)}"
         rv = self.client.get(uri)
         # successful request
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         fetched_objects = rv.json["result"]
-        self.assertEqual(len(fetched_objects), 1)
-        self.assertEqual(fetched_objects[0]["id"], dashboard_id)
+        assert len(fetched_objects) == 1
+        assert fetched_objects[0]["id"] == dashboard_id
         # clean up tagged object
         tagged_objects.delete()
 
@@ -394,18 +431,108 @@ class TestTagApi(SupersetTestCase):
             TaggedObject.object_id == dashboard_id,
             TaggedObject.object_type == dashboard_type.name,
         )
-        self.assertEqual(tagged_objects.count(), 2)
-        self.assertEqual(tagged_objects.first().object_id, dashboard_id)
+        assert tagged_objects.count() == 2
+        assert tagged_objects.first().object_id == dashboard_id
         uri = "api/v1/tag/get_objects/"
         rv = self.client.get(uri)
         # successful request
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         fetched_objects = rv.json["result"]
         # check that the dashboard object was fetched
         assert dashboard_id in [obj["id"] for obj in fetched_objects]
         # clean up tagged object
         tagged_objects.delete()
 
+    def test_get_tagged_objects_restricted(self):
+        """
+        Test that the get_objects endpoint returns only assets
+        the user has access to.
+        """
+        owner = self.get_user(ADMIN_USERNAME)
+
+        # Create a tag
+        tag = self.insert_tag(
+            name="test_tagged_objects_visibility",
+            tag_type="custom",
+        )
+
+        # Create a chart
+        chart_first_dataset = self.insert_chart("first_chart", [owner.id], 1)
+        first_tag_relation = self.insert_tagged_object(
+            tag_id=tag.id,
+            object_id=chart_first_dataset.id,
+            object_type=ObjectType.chart,
+        )
+
+        # Create another chart and add it to a dashboard
+        chart_second_dataset = self.insert_chart("second_chart", [owner.id], 2)
+        second_tag_relation = self.insert_tagged_object(
+            tag_id=tag.id,
+            object_id=chart_second_dataset.id,
+            object_type=ObjectType.chart,
+        )
+        dashboard = self.insert_dashboard(
+            "test_dashboard",
+            "test_dashboard",
+            [owner.id],
+            slices=[chart_second_dataset],
+            published=True,
+        )
+        dashboard_tag_relation = self.insert_tagged_object(
+            tag_id=tag.id,
+            object_id=dashboard.id,
+            object_type=ObjectType.dashboard,
+        )
+
+        # Create a user without access to these items
+        user = self.create_user_with_roles(
+            "test_restricted_user",
+            ["testing_new_role"],
+            should_create_roles=True,
+        )
+        self.login("test_restricted_user")
+
+        uri = f"api/v1/tag/get_objects/?tagIds={tag.id}"
+        rv = self.client.get(uri)
+        assert rv.status_code == 200
+        assert rv.json["result"] == []
+
+        # grant access to dataset ID 1
+        first_dataset = db.session.query(SqlaTable).filter(SqlaTable.id == 1).first()
+        self.grant_role_access_to_table(first_dataset, "testing_new_role")
+
+        rv = self.client.get(uri)
+        assert rv.status_code == 200
+        result = rv.json["result"]
+        assert len(result) == 1
+        assert result[0]["id"] == chart_first_dataset.id
+
+        # grant access to dataset ID 2
+        second_dataset = db.session.query(SqlaTable).filter(SqlaTable.id == 2).first()
+        self.grant_role_access_to_table(second_dataset, "testing_new_role")
+
+        rv = self.client.get(uri)
+        assert rv.status_code == 200
+        result = rv.json["result"]
+        assert len(result) == 3
+        assert sorted([res["id"] for res in result]) == sorted(
+            [chart_first_dataset.id, chart_second_dataset.id, dashboard.id]
+        )
+
+        # Clean up
+        db.session.delete(dashboard_tag_relation)
+        db.session.delete(dashboard)
+        db.session.delete(second_tag_relation)
+        db.session.delete(chart_second_dataset)
+        db.session.delete(first_tag_relation)
+        db.session.delete(chart_first_dataset)
+        db.session.delete(tag)
+        self.revoke_role_access_to_table("testing_new_role", first_dataset)
+        self.revoke_role_access_to_table("testing_new_role", second_dataset)
+        db.session.delete(user.roles[0])
+        db.session.delete(user)
+        db.session.commit()
+
     # test delete tags
     @pytest.mark.usefixtures("create_tags")
     def test_delete_tags(self):
@@ -413,25 +540,25 @@ class TestTagApi(SupersetTestCase):
         # check that tags exist in the database
         example_tag_names = ["example_tag_1", "example_tag_2", "example_tag_3"]
         tags = db.session.query(Tag).filter(Tag.name.in_(example_tag_names))
-        self.assertEqual(tags.count(), 3)
+        assert tags.count() == 3
         # delete the first tag
         uri = f"api/v1/tag/?q={prison.dumps(example_tag_names[:1])}"
         rv = self.client.delete(uri, follow_redirects=True)
         # successful request
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         # check that tag does not exist in the database
         tag = db.session.query(Tag).filter(Tag.name == example_tag_names[0]).first()
         assert tag is None
         tags = db.session.query(Tag).filter(Tag.name.in_(example_tag_names))
-        self.assertEqual(tags.count(), 2)
+        assert tags.count() == 2
         # delete multiple tags
         uri = f"api/v1/tag/?q={prison.dumps(example_tag_names[1:])}"
         rv = self.client.delete(uri, follow_redirects=True)
         # successful request
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         # check that tags are all gone
         tags = db.session.query(Tag).filter(Tag.name.in_(example_tag_names))
-        self.assertEqual(tags.count(), 0)
+        assert tags.count() == 0
 
     @pytest.mark.usefixtures("create_tags")
     def test_delete_favorite_tag(self):
@@ -442,10 +569,7 @@ class TestTagApi(SupersetTestCase):
         tag = db.session.query(Tag).first()
         rv = self.client.post(uri, follow_redirects=True)
 
-        self.assertEqual(rv.status_code, 200)
-        from sqlalchemy import and_  # noqa: F811
-        from superset.tags.models import user_favorite_tag_table  # noqa: F811
-        from flask import g  # noqa: F401, F811
+        assert rv.status_code == 200
 
         association_row = (
             db.session.query(user_favorite_tag_table)
@@ -463,7 +587,7 @@ class TestTagApi(SupersetTestCase):
         uri = f"api/v1/tag/{tag.id}/favorites/"
         rv = self.client.delete(uri, follow_redirects=True)
 
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         association_row = (
             db.session.query(user_favorite_tag_table)
             .filter(
@@ -483,15 +607,26 @@ class TestTagApi(SupersetTestCase):
         uri = "api/v1/tag/123/favorites/"  # noqa: F541
         rv = self.client.post(uri, follow_redirects=True)
 
-        self.assertEqual(rv.status_code, 404)
+        assert rv.status_code == 404
 
     @pytest.mark.usefixtures("create_tags")
     def test_delete_favorite_tag_not_found(self):
+        """
+        Tag API: Test trying to remove an unexisting tag from the list
+        of user favorites returns 404.
+        """
         self.login(ADMIN_USERNAME)
-        uri = "api/v1/tag/123/favorites/"  # noqa: F541
+
+        # Fetch all existing tag IDs
+        existing_ids = [tag_id for (tag_id,) in db.session.query(Tag.id).all()]
+
+        # Get an ID not in use
+        non_existent_id = max(existing_ids, default=0) + 1
+
+        uri = f"api/v1/tag/{non_existent_id}/favorites/"  # noqa: F541
         rv = self.client.delete(uri, follow_redirects=True)
 
-        self.assertEqual(rv.status_code, 404)
+        assert rv.status_code == 404
 
     @pytest.mark.usefixtures("create_tags")
     @patch("superset.daos.tag.g")
@@ -501,7 +636,7 @@ class TestTagApi(SupersetTestCase):
         uri = "api/v1/tag/123/favorites/"  # noqa: F541
         rv = self.client.post(uri, follow_redirects=True)
 
-        self.assertEqual(rv.status_code, 422)
+        assert rv.status_code == 422
 
     @pytest.mark.usefixtures("create_tags")
     @patch("superset.daos.tag.g")
@@ -511,7 +646,7 @@ class TestTagApi(SupersetTestCase):
         uri = "api/v1/tag/123/favorites/"  # noqa: F541
         rv = self.client.delete(uri, follow_redirects=True)
 
-        self.assertEqual(rv.status_code, 422)
+        assert rv.status_code == 422
 
     @pytest.mark.usefixtures("load_world_bank_dashboard_with_slices")
     def test_post_tag(self):
@@ -527,7 +662,7 @@ class TestTagApi(SupersetTestCase):
             json={"name": "my_tag", "objects_to_tag": [["dashboard", dashboard.id]]},
         )
 
-        self.assertEqual(rv.status_code, 201)
+        assert rv.status_code == 201
         self.get_user(username="admin").get_id()  # noqa: F841
         tag = (
             db.session.query(Tag)
@@ -550,7 +685,7 @@ class TestTagApi(SupersetTestCase):
             json={"name": "", "objects_to_tag": [["dashboard", dashboard.id]]},
         )
 
-        self.assertEqual(rv.status_code, 400)
+        assert rv.status_code == 400
 
     @pytest.mark.usefixtures("load_world_bank_dashboard_with_slices")
     @pytest.mark.usefixtures("create_tags")
@@ -563,7 +698,7 @@ class TestTagApi(SupersetTestCase):
             uri, json={"name": "new_name", "description": "new description"}
         )
 
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
 
         tag = (
             db.session.query(Tag)
@@ -581,7 +716,7 @@ class TestTagApi(SupersetTestCase):
         uri = f"api/v1/tag/{tag_to_update.id}"
         rv = self.client.put(uri, json={"foo": "bar"})
 
-        self.assertEqual(rv.status_code, 400)
+        assert rv.status_code == 400
 
     @pytest.mark.usefixtures("load_world_bank_dashboard_with_slices")
     def test_post_bulk_tag(self):
@@ -617,12 +752,12 @@ class TestTagApi(SupersetTestCase):
             },
         )
 
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
 
-        result = TagDAO.get_tagged_objects_for_tags(tags, ["dashboard"])
+        result = TagDAO.get_tagged_objects_by_tag_names(tags, ["dashboard"])
         assert len(result) == 1
 
-        result = TagDAO.get_tagged_objects_for_tags(tags, ["chart"])
+        result = TagDAO.get_tagged_objects_by_tag_names(tags, ["chart"])
         assert len(result) == 1
 
         tagged_objects = (
@@ -686,7 +821,51 @@ class TestTagApi(SupersetTestCase):
             },
         )
 
-        self.assertEqual(rv.status_code, 200)
+        assert rv.status_code == 200
         result = rv.json["result"]
         assert len(result["objects_tagged"]) == 2
         assert len(result["objects_skipped"]) == 1
+
+    def test_create_tag_mysql_compatibility(self) -> None:
+        """
+        Test creating a tag via API to ensure MySQL compatibility.
+
+        This test verifies the fix for issue #32484 where tag creation
+        failed with MySQL due to Markup objects being used instead of strings.
+        """
+
+        self.login(ADMIN_USERNAME)
+
+        tag_name = "mysql-fix-verification-20251111"
+        uri = "api/v1/tag/"
+
+        # Create a tag via the API (tags can only be created with objects_to_tag)
+        # So we'll create a simple tag and verify it in the database
+        data = {
+            "name": tag_name,
+            "description": "Test tag for MySQL compatibility verification",
+            "objects_to_tag": [],  # Empty list is acceptable
+        }
+
+        rv = self.client.post(uri, json=data)
+
+        # Should succeed without SQL errors (201 for created or 200 for success)
+        assert rv.status_code in [200, 201], (
+            f"Tag creation should succeed, got {rv.status_code}"
+        )
+
+        # Query the database to verify the tag was created correctly
+        created_tag = db.session.query(Tag).filter_by(name=tag_name).first()
+        assert created_tag is not None, "Tag should exist in database"
+
+        # Critical check: ensure the tag name is a plain string, not Markup
+        assert isinstance(created_tag.name, str), "Tag name should be a plain string"
+        assert not isinstance(created_tag.name, Markup), (
+            "Tag name should NOT be a Markup object"
+        )
+        assert created_tag.name.__class__ is str, "Tag name should be exactly str type"
+        assert created_tag.name == tag_name, "Tag name should match the input"
+
+        # Cleanup
+        db.session.delete(created_tag)
+        db.session.commit()
