@@ -29,7 +29,13 @@ def test_csrf_not_exempt(app_context: None) -> None:
     Test that REST API is not exempt from CSRF.
     """
     assert {blueprint.name for blueprint in csrf._exempt_blueprints} == {
+        "GroupApi",
         "MenuApi",
         "SecurityApi",
         "OpenApi",
+        "PermissionViewMenuApi",
+        "SupersetRoleApi",
+        "SupersetUserApi",
+        "PermissionApi",
+        "ViewMenuApi",
     }
