@@ -19,6 +19,7 @@ from datetime import date, datetime, timedelta
 from typing import Optional
 from unittest.mock import Mock, patch
 
+import freezegun
 import pytest
 from dateutil.relativedelta import relativedelta
 
@@ -38,7 +39,7 @@ from superset.utils.date_parser import (
 from tests.unit_tests.conftest import with_feature_flags
 
 
-def mock_parse_human_datetime(s: str) -> Optional[datetime]:
+def mock_parse_human_datetime(s: str) -> Optional[datetime]:  # noqa: C901
     if s == "now":
         return datetime(2016, 11, 7, 9, 30, 10)
     elif s == "2018":
@@ -92,6 +93,46 @@ def test_get_since_until() -> None:
     expected = datetime(2016, 11, 6), datetime(2016, 11, 8)
     assert result == expected
 
+    result = get_since_until(" : now")
+    expected = None, datetime(2016, 11, 7, 9, 30, 10)
+    assert result == expected
+
+    result = get_since_until(" : last 2 minutes")
+    expected = None, datetime(2016, 11, 7, 9, 28, 10)
+    assert result == expected
+
+    result = get_since_until(" : prior 2 minutes")
+    expected = None, datetime(2016, 11, 7, 9, 28, 10)
+    assert result == expected
+
+    result = get_since_until(" : next 2 minutes")
+    expected = None, datetime(2016, 11, 7, 9, 32, 10)
+    assert result == expected
+
+    result = get_since_until("start of this month : ")
+    expected = datetime(2016, 11, 1), None
+    assert result == expected
+
+    result = get_since_until("start of next month : ")
+    expected = datetime(2016, 12, 1), None
+    assert result == expected
+
+    result = get_since_until("end of this month : ")
+    expected = datetime(2016, 11, 30), None
+    assert result == expected
+
+    result = get_since_until("end of next month : ")
+    expected = datetime(2016, 12, 31), None
+    assert result == expected
+
+    result = get_since_until("beginning of next year : ")
+    expected = datetime(2017, 1, 1), None
+    assert result == expected
+
+    result = get_since_until("beginning of last year : ")
+    expected = datetime(2015, 1, 1), None
+    assert result == expected
+
     result = get_since_until("2018-01-01T00:00:00 : 2018-12-31T23:59:59")
     expected = datetime(2018, 1, 1), datetime(2018, 12, 31, 23, 59, 59)
     assert result == expected
@@ -230,7 +271,16 @@ def test_get_since_until() -> None:
     expected = datetime(1999, 12, 25), datetime(2017, 12, 25)
     assert result == expected
 
-    with pytest.raises(ValueError):
+    # Test time_shift with date range format (contains ' : ')
+    result = get_since_until(
+        time_range="today : tomorrow",
+        time_shift="yesterday : today",
+    )
+    # When time_shift contains ' : ', it should be parsed as a new time range
+    expected = datetime(2016, 11, 6), datetime(2016, 11, 7)
+    assert result == expected
+
+    with pytest.raises(ValueError):  # noqa: PT011
         get_since_until(time_range="tomorrow : yesterday")
 
 
@@ -276,6 +326,33 @@ def test_get_since_until_instant_time_comparison_enabled() -> None:
     assert result == expected
 
 
+def test_previous_calendar_quarter():
+    with freezegun.freeze_time("2023-01-15"):
+        result = get_since_until("previous calendar quarter")
+        expected = (datetime(2022, 10, 1), datetime(2023, 1, 1))
+        assert result == expected
+
+    with freezegun.freeze_time("2023, 4, 15"):
+        result = get_since_until("previous calendar quarter")
+        expected = (datetime(2023, 1, 1), datetime(2023, 4, 1))
+        assert result == expected
+
+    with freezegun.freeze_time("2023, 8, 15"):
+        result = get_since_until("previous calendar quarter")
+        expected = (datetime(2023, 4, 1), datetime(2023, 7, 1))
+        assert result == expected
+
+    with freezegun.freeze_time("2023, 10, 15"):
+        result = get_since_until("previous calendar quarter")
+        expected = (datetime(2023, 7, 1), datetime(2023, 10, 1))
+        assert result == expected
+
+    with freezegun.freeze_time("2024, 1, 1"):
+        result = get_since_until("previous calendar quarter")
+        expected = (datetime(2023, 10, 1), datetime(2024, 1, 1))
+        assert result == expected
+
+
 @patch("superset.utils.date_parser.parse_human_datetime", mock_parse_human_datetime)
 def test_datetime_eval() -> None:
     result = datetime_eval("datetime('now')")
@@ -379,11 +456,22 @@ def test_datetime_eval() -> None:
     expected = datetime(2018, 9, 3, 0, 0, 0)
     assert result == expected
 
-    result = datetime_eval(
-        "holiday('Eid al-Fitr', datetime('2000-01-01T00:00:00'), 'SA')"
-    )
-    expected = datetime(2000, 1, 8, 0, 0, 0)
-    assert result == expected
+    # Saudi Arabia holidays - try both English and Arabic names as the default
+    # language varies by environment (ar in some envs, en_US in CI)
+    sa_holiday_test_passed = False
+    for holiday_name in ["Eid al-Fitr", "عطلة عيد الفطر"]:
+        try:
+            result = datetime_eval(
+                f"holiday('{holiday_name}', datetime('2000-01-01T00:00:00'), 'SA')"
+            )
+            expected = datetime(2000, 1, 8, 0, 0, 0)
+            assert result == expected
+            sa_holiday_test_passed = True
+            break
+        except ValueError:
+            continue
+
+    assert sa_holiday_test_passed
 
     result = datetime_eval(
         "holiday('Boxing day', datetime('2018-01-01T00:00:00'), 'UK')"
@@ -420,12 +508,12 @@ def test_datetime_eval() -> None:
     assert result == -9
 
     result = datetime_eval(
-        "datediff(datetime('2018-01-01T00:00:00'), datetime('2018-01-10T00:00:00'), day)"  # pylint: disable=line-too-long,useless-suppression
+        "datediff(datetime('2018-01-01T00:00:00'), datetime('2018-01-10T00:00:00'), day)"  # pylint: disable=line-too-long,useless-suppression  # noqa: E501
     )
     assert result == 9
 
     result = datetime_eval(
-        "datediff(datetime('2018-01-01T00:00:00'), datetime('2018-01-10T00:00:00'), year)"  # pylint: disable=line-too-long,useless-suppression
+        "datediff(datetime('2018-01-01T00:00:00'), datetime('2018-01-10T00:00:00'), year)"  # pylint: disable=line-too-long,useless-suppression  # noqa: E501
     )
     assert result == 0
 
